/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 04146
 |        NATIONAL DRUG ABUSE TREATMENT SYSTEM SURVEY, WAVES II-IV
 |                     (DATASET 0003: WAVE IV, 1995)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\04146-0003-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE v10004ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10005ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10006ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10007ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10008ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10009ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10010ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10011ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10012ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10013ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10014ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10015ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10016ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10017ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10018ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10019ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10020ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10021ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10022ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10023ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10024ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10025ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10026ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10027ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10028ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10029ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10030ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10031ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Increased a great deal'
                  2='2. Increased some' 3='3. Remained the same'
                  4='4. Decreased some' 5='5. Decreased a great deal' ;
  VALUE v10032ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10033ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10034ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10035ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10036ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10037ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10038ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10039ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10040ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10041ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10042ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10043ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10044ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10045ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10046ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10047ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10048ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10049ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10050ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10051ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10052ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10053ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10054ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10055ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10056ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10057ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10058ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10059ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes'
                  2='2. Yes to B1 but no B2-B47 info' ;
  VALUE v10060ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10061ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10062ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10063ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10064ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10065ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10066ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10067ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10068ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10069ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10070ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10071ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10072ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10073ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10074ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10075ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10076ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10077ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10078ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10079ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10080ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10081ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10082ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10083ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10084ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10085ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10086ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10087ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10088ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10089ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. # visits'
                  2='02. # clients' 3='03. TIME SPENT' 4='04. GRANT'
                  5='05. EXPENSES' 6='06. any combin 01,02,03'
                  10='10. fee by wk or mon' 11='11. Per diem'
                  12='12. Per intervention' 13='13. Per meth dose'
                  14='14. Per unit cost' 15='15. Per tx course'
                  23='23. Contract' 25='25. Donations' 26='26. Tax or fee'
                  29='29. Govt payments' 61='61. Interest'
                  62='62. Sales Revenue' 63='63. Solicitation'
                  96='96. Sliding scale' 97='97. Other' ;
  VALUE v10090ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10091ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10092ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10093ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10094ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. # visits'
                  2='02. # clients' 3='03. TIME SPENT' 4='04. GRANT'
                  5='05. EXPENSES' 6='06. any combin 01,02,03'
                  10='10. fee by wk or mon' 11='11. Per diem'
                  12='12. Per intervention' 13='13. Per meth dose'
                  14='14. Per unit cost' 15='15. Per tx course'
                  23='23. Contract' 25='25. Donations' 26='26. Tax or fee'
                  29='29. Govt payments' 61='61. Interest'
                  62='62. Sales Revenue' 63='63. Solicitation'
                  96='96. Sliding scale' 97='97. Other' ;
  VALUE v10095ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10096ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10097ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. # visits'
                  2='02. # clients' 3='03. TIME SPENT' 4='04. GRANT'
                  5='05. EXPENSES' 6='06. any combin 01,02,03'
                  10='10. fee by wk or mon' 11='11. Per diem'
                  12='12. Per intervention' 13='13. Per meth dose'
                  14='14. Per unit cost' 15='15. Per tx course'
                  23='23. Contract' 25='25. Donations' 26='26. Tax or fee'
                  29='29. Govt payments' 61='61. Interest'
                  62='62. Sales Revenue' 63='63. Solicitation'
                  96='96. Sliding scale' 97='97. Other' ;
  VALUE v10098ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10099ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10100ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. # visits'
                  2='02. # clients' 3='03. TIME SPENT' 4='04. GRANT'
                  5='05. EXPENSES' 6='06. any combin 01,02,03'
                  10='10. fee by wk or mon' 11='11. Per diem'
                  12='12. Per intervention' 13='13. Per meth dose'
                  14='14. Per unit cost' 15='15. Per tx course'
                  23='23. Contract' 25='25. Donations' 26='26. Tax or fee'
                  29='29. Govt payments' 61='61. Interest'
                  62='62. Sales Revenue' 63='63. Solicitation'
                  96='96. Sliding scale' 97='97. Other' ;
  VALUE v10101ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10102ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10103ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. # visits'
                  2='02. # clients' 3='03. TIME SPENT' 4='04. GRANT'
                  5='05. EXPENSES' 6='06. any combin 01,02,03'
                  10='10. fee by wk or mon' 11='11. Per diem'
                  12='12. Per intervention' 13='13. Per meth dose'
                  14='14. Per unit cost' 15='15. Per tx course'
                  23='23. Contract' 25='25. Donations' 26='26. Tax or fee'
                  29='29. Govt payments' 61='61. Interest'
                  62='62. Sales Revenue' 63='63. Solicitation'
                  96='96. Sliding scale' 97='97. Other' ;
  VALUE v10104ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10105ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10106ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10107ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. # visits'
                  2='02. # clients' 3='03. TIME SPENT' 4='04. GRANT'
                  5='05. EXPENSES' 6='06. any combin 01,02,03'
                  10='10. fee by wk or mon' 11='11. Per diem'
                  12='12. Per intervention' 13='13. Per meth dose'
                  14='14. Per unit cost' 15='15. Per tx course'
                  23='23. Contract' 25='25. Donations' 26='26. Tax or fee'
                  29='29. Govt payments' 61='61. Interest'
                  62='62. Sales Revenue' 63='63. Solicitation'
                  96='96. Sliding scale' 97='97. Other' ;
  VALUE v10108ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10109ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10110ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. # visits'
                  2='02. # clients' 3='03. TIME SPENT' 4='04. GRANT'
                  5='05. EXPENSES' 6='06. any combin 01,02,03'
                  10='10. fee by wk or mon' 11='11. Per diem'
                  12='12. Per intervention' 13='13. Per meth dose'
                  14='14. Per unit cost' 15='15. Per tx course'
                  23='23. Contract' 25='25. Donations' 26='26. Tax or fee'
                  29='29. Govt payments' 61='61. Interest'
                  62='62. Sales Revenue' 63='63. Solicitation'
                  96='96. Sliding scale' 97='97. Other' ;
  VALUE v10111ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10112ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10113ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10114ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10115ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10116ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10117ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10118ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10119ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10120ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10121ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10122ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10123ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10124ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10125ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10126ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10127ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10128ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10129ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10130ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10131ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10132ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10133ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10134ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10135ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10136ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10137ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10138ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10139ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10140ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10141ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10142ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10143ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10144ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10145ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10146ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10147ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10148ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10149ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10150ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10151ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10152ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10153ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10154ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10155ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10156ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10157ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10158ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v10159ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10160ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10161ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10162ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10163ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10164ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10165ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10166ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10167ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10168ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10169ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10170ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10171ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10172ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10173ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10174ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10175ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10176ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10177ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10178ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10179ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10180ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10181ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10182ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10183ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10184ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10185ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10186ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10187ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10188ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10189ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. RENT' 2='2. OWN'
                  3='3. PARENT ORG OWNS' 4='4. OTHER' ;
  VALUE v10190ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10191ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10192ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10193ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10194ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10195ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10196ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10197ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10198ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10199ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10200ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10201ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10202ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10203ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10204ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10205ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10206ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10207ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10208ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10209ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10210ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10211ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10212ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10213ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10214ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 950='950. 95 per wk+' ;
  VALUE v10215ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10216ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10217ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10218ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10219ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10220ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10221ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10222ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10223ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10224ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10225ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10226ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10227ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10228ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10229ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10230ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10231ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10232ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10233ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10234ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10235ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10236ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10237ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10238ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10239ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10240ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10241ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10242ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10243ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10244ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10245ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10246ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10247ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10248ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10249ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10250ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10251ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10252ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. MD (exc Psychiatry)'
                  2='02. RN-nurse--NFS' 3='03. LPN-practical nurse'
                  7='07. Other HC professional'
                  9='09. Health care professional-NA type'
                  11='11. PhD social work' 17='17. Other PhDs (exc psych)'
                  19='19. PhDs-NA type'
                  27='27. Otr Masters level (exc SW/psych/counsel)'
                  29='29. Masters--NA speciality'
                  41='41. Any field or NA field'
                  51='51. Alcohol,drug/alcohol counsel-CAC'
                  57='57. Other certif or license'
                  59='59. Certif or license--NA type'
                  61='61. HS or less-no degree-NFS'
                  81='81. Counselor--NA level educ or type' 97='97. Other' ;
  VALUE v10253ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10254ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10255ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10256ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10257ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10258ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10259ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10260ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10261ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10262ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10263ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10264ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Private For-Profit'
                  2='2. Private Not-For-Profit' 3='3. Public' ;
  VALUE v10265ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10266ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10267ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10268ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10269ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10270ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10271ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10272ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHER' 1='1. YES TO C1' ;
  VALUE v10273ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Public'
                  2='2. Private For-Profit' 3='3. Private Not-For-Profit' ;
  VALUE v10274ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v10275ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Hospital'
                  2='2. Mental health center' 3='3. Other kind organizatn' ;
  VALUE v10276ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GENERAL HOSPITAL'
                  2='2. PSYCHIATRIC HOSPITAL' ;
  VALUE v10277ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NON-HOSP RES FAC'
                  2='2. A CORRECTIONAL FAC' 3='3. AN HMO FAC'
                  4='4. OTHER OUTPATIENT FAC' ;
  VALUE v10278ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10279ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10280ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10281ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. R ANSWERED YES TO C6'
                  2='2. R ANSWERED YES AT C1' 3='3. ALL OTHERS' ;
  VALUE v10282ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Public'
                  2='2. Private For-Profit' 3='3. Private Not-For-Profit' ;
  VALUE v10283ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v10284ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Hospital'
                  2='2. Mental health center' 3='3. Other kind organizatn' ;
  VALUE v10285ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GENERAL HOSPITAL'
                  2='2. PSYCHIATRIC HOSPITAL' ;
  VALUE v10286ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NON-HOSP RES FAC'
                  2='2. A CORRECTIONAL FAC' 3='3. AN HMO FAC'
                  4='4. OTHER OUTPATIENT FAC' ;
  VALUE v10287ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10288ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10289ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10290ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10291ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10292ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10293ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10294ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10295ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10296ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10297ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10298ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10299ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10300ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10301ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10302ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10303ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10304ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10305ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10306ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10307ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10308ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10309ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10310ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10311ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10312ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10313ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10314ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 4='4. Staff train/devlpmt'
                  5='5. (Clerical) Support functions' 6='6. Building maint'
                  7='7. Administrative' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/ nutrition info' 36='36. Treatment access'
                  41='41. AA/NA' 42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy' 50='50. TB testing'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 58='58. LAAM'
                  59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  97='97. Other' ;
  VALUE v10315ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10316ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10317ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10318ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10319ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10320ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10321ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10322ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10323ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10324ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10325ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10326ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10327ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10328ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10329ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10330ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10331ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10332ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10333ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10334ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. EVERY THREE YEARS'
                  2='02. EVERY TWO YEARS' 3='03. ANNUALLY'
                  4='04. SEMI-ANNUALLY' 5='05. QUARTERLY' 6='06. MONTHLY'
                  7='07. RANDOMLY' 8='08. 4 years' 9='09. 5 years'
                  97='97. OTHER' ;
  VALUE v10335ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10336ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. EVERY THREE YEARS'
                  2='02. EVERY TWO YEARS' 3='03. ANNUALLY'
                  4='04. SEMI-ANNUALLY' 5='05. QUARTERLY' 6='06. MONTHLY'
                  7='07. RANDOMLY' 8='08. 4 years' 9='09. 5 years'
                  97='97. OTHER' ;
  VALUE v10337ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10338ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. EVERY THREE YEARS'
                  2='02. EVERY TWO YEARS' 3='03. ANNUALLY'
                  4='04. SEMI-ANNUALLY' 5='05. QUARTERLY' 6='06. MONTHLY'
                  7='07. RANDOMLY' 8='08. 4 years' 9='09. 5 years'
                  97='97. OTHER' ;
  VALUE v10339ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10340ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. EVERY THREE YEARS'
                  2='02. EVERY TWO YEARS' 3='03. ANNUALLY'
                  4='04. SEMI-ANNUALLY' 5='05. QUARTERLY' 6='06. MONTHLY'
                  7='07. RANDOMLY' 8='08. 4 years' 9='09. 5 years'
                  97='97. OTHER' ;
  VALUE v10341ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10342ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. EVERY THREE YEARS'
                  2='02. EVERY TWO YEARS' 3='03. ANNUALLY'
                  4='04. SEMI-ANNUALLY' 5='05. QUARTERLY' 6='06. MONTHLY'
                  7='07. RANDOMLY' 8='08. 4 years' 9='09. 5 years'
                  97='97. OTHER' ;
  VALUE v10343ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10344ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. EVERY THREE YEARS'
                  2='02. EVERY TWO YEARS' 3='03. ANNUALLY'
                  4='04. SEMI-ANNUALLY' 5='05. QUARTERLY' 6='06. MONTHLY'
                  7='07. RANDOMLY' 8='08. 4 years' 9='09. 5 years'
                  97='97. OTHER' ;
  VALUE v10345ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10346ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  30='30. HHS' 31='31. ADAMHA' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. CITY/COUNTY/LOCAL CRT' 54='54. LOC ALC AGCY'
                  55='55. COUNTY' 56='56. CITY' 58='58. LOCAL-NA LEVEL'
                  59='59. OTR LOC AGY INC REG' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP' 76='76. COMM ORG'
                  77='77. PROF ORG' 79='79. OTR NONGOV ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  89='89. OTR OWN EFFORT' 96='96. NONE/NO OTR MENT'
                  97='97. OTHER FUND SRC' ;
  VALUE v10347ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. EVERY THREE YEARS'
                  2='02. EVERY TWO YEARS' 3='03. ANNUALLY'
                  4='04. SEMI-ANNUALLY' 5='05. QUARTERLY' 6='06. MONTHLY'
                  7='07. RANDOMLY' 8='08. 4 years' 9='09. 5 years'
                  97='97. OTHER' ;
  VALUE v10348ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10349ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10350ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10351ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10352ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10353ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10354ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10355ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10356ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10357ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10358ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10359ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10360ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10361ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10362ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10363ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10364ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 10='10 or less' ;
  VALUE v10365ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10366ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10367ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10368ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10369ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10370ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10371ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10372ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10373ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10374ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10375ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10376ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10377ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10378ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10379ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10380ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10381ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10382ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10383ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10384ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10385ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10386ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 97='97. Other' ;
  VALUE v10387ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10388ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10389ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10390ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10391ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10392ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10393ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10394ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10395ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10396ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10397ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10398ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10399ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10400ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10401ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10402ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10403ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10404ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. Staffing and supervising issues'
                  2='2. Clerical chores' 3='3. Patient manag & case review'
                  4='4. Administration' 5='5. Trouble-shooting'
                  6='6. Upgrading skills/info in SAT'
                  7='7. Marketing/Public Relations' 8='8. Quality Assurance'
                  97='97. Other' ;
  VALUE v10405ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. Staffing and supervising issues'
                  2='2. Clerical chores' 3='3. Patient manag & case review'
                  4='4. Administration' 5='5. Trouble-shooting'
                  6='6. Upgrading skills/info in SAT'
                  7='7. Marketing/Public Relations' 8='8. Quality Assurance'
                  97='97. Other' ;
  VALUE v10406ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. Staffing and supervising issues'
                  2='2. Clerical chores' 3='3. Patient manag & case review'
                  4='4. Administration' 5='5. Trouble-shooting'
                  6='6. Upgrading skills/info in SAT'
                  7='7. Marketing/Public Relations' 8='8. Quality Assurance'
                  97='97. Other' ;
  VALUE v10407ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10408ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10409ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10410ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10411ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10412ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10413ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10414ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. Staffing and supervising issues'
                  2='2. Clerical chores' 3='3. Patient manag & case review'
                  4='4. Administration' 5='5. Trouble-shooting'
                  6='6. Upgrading skills/info in SAT'
                  7='7. Marketing/Public Relations' 8='8. Quality Assurance'
                  97='97. Other' ;
  VALUE v10415ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. Staffing and supervising issues'
                  2='2. Clerical chores' 3='3. Patient manag & case review'
                  4='4. Administration' 5='5. Trouble-shooting'
                  6='6. Upgrading skills/info in SAT'
                  7='7. Marketing/Public Relations' 8='8. Quality Assurance'
                  97='97. Other' ;
  VALUE v10416ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. Staffing and supervising issues'
                  2='2. Clerical chores' 3='3. Patient manag & case review'
                  4='4. Administration' 5='5. Trouble-shooting'
                  6='6. Upgrading skills/info in SAT'
                  7='7. Marketing/Public Relations' 8='8. Quality Assurance'
                  97='97. Other' ;
  VALUE v10417ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10418ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10419ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10420ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10421ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10422ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10423ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10424ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10425ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10426ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10427ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10428ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10429ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10430ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10431ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10432ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10433ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10434ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10435ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10436ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10437ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10438ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10439ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10440ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10441ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10442ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10443ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10444ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10445ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10446ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10447ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10448ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10449ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10450ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10451ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10452ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. CERT-ADDICTN/DRUG AB/CHEM DEP-CADC'
                  2='2. CERT-OTR COUNSEL/SOC WK EXC 01' 7='7. CERTIFIED--NFS'
                  11='11. LIC-ADDICTN/DRUG AB/CHEM DEP'
                  12='12. LIC-OTR LICENSE LCSW-D104 LPC'
                  17='17. LICENSED--NFS' 21='21. CRED/TRN ADDICTN/DRUG AB'
                  22='22. CRED COUNSEL/SOC WORK' 27='27. CREDENTIALS--NFS'
                  31='31. FIELD EXPERIENCE' 41='41. NO INDIC OF CERT/LIC/OTR'
                  97='97. OTHER' ;
  VALUE v10453ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION'
                  1='1. CERT-ADDICTN/DRUG AB/CHEM DEP-CADC'
                  2='2. CERT-OTR COUNSEL/SOC WK EXC 01' 7='7. CERTIFIED--NFS'
                  11='11. LIC-ADDICTN/DRUG AB/CHEM DEP'
                  12='12. LIC-OTR LICENSE LCSW-D104 LPC'
                  17='17. LICENSED--NFS' 21='21. CRED/TRN ADDICTN/DRUG AB'
                  22='22. CRED COUNSEL/SOC WORK' 27='27. CREDENTIALS--NFS'
                  31='31. FIELD EXPERIENCE' 41='41. NO INDIC OF CERT/LIC/OTR'
                  97='97. OTHER' ;
  VALUE v10454ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10455ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10456ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10457ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10458ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10459ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10460ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10461ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10462ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10463ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10464ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10465ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10466ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10467ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10468ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10469ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10470ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10471ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10472ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10473ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10474ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10475ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10476ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10477ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10478ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10479ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10480ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10481ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10482ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10483ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10484ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10485ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10486ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10487ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10488ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10489ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10490ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10491ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10492ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10493ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10494ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10495ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10496ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10497ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10498ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10499ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10500ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10501ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10502ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10503ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10504ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10505ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10506ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10507ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10508ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10509ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10510ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10511ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10512ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10513ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10514ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10515ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10516ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. HAVE OTHER DUTIES'
                  1='1. ONLY ON AIDS PREVENTION' ;
  VALUE v10517ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10518ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v10519ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10520ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10521ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10522ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10523ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10524ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10525ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10526ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10527ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10528ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10529ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10530ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR'
                  2='2. LISTED AT 1a DIRECTOR COVERSHEET' 3='3. PROXY #1'
                  4='4. PROXY #2' 5='5. PROXY #3' ;
  VALUE v10531ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10532ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10533ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10534ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10535ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10536ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. ASSOCDIR'
                  3='3. FINANDIR' 4='4. PLANNER' 5='5. ADMNASST'
                  6='6. OFFICMGR' 7='7. CLERK' 9='9. PUBRELAT'
                  10='10. LEGALSRV' 19='19. OTHADMIN' 21='21. OUTPTDIR'
                  22='22. ASSTHEAD' 23='23. CCLINSUP' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICAN' 42='42. NURSE' 43='43. OTHPRO'
                  44='44. PSYCHGST' 45='45. SOCWORKR' 71='71. VOLUNTER'
                  72='72. STUDENT' 73='73. PUBOFFCL' 74='74. PROFESOR'
                  95='95. NONE' 97='97. OTHER' ;
  VALUE v10537ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10538ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10539ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 29 YEARS OLD OR YOUNGER'
                  2='2. 30-34 YEARS OLD' 3='3. 35-39 YEARS OLD'
                  4='4. 40-44 YEARS OLD' 5='5. 45-49 YEARS OLD'
                  6='6. 50-54 YEARS OLD' 7='7. 55-59 YEARS OLD'
                  8='8. 60 YEARS OLD OR OLDER' ;
  VALUE v10540ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Female' 1='1. Male' ;
  VALUE v10541ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. WHITE' 2='2. BLACK'
                  5='5. OTHER' ;
  VALUE v10542ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10543ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10544ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10545ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10546ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v10547ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10548ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v10549ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v10550ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v10551ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v10552ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v10553ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v10554ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v10555ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v10556ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v10557ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11004ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11005ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v11006ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11007ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11008ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v11009ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11010ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11011ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11012ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11013ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11014ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11015ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11016ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11017ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11018ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11019ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11020ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11021ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11022ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11023ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11024ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11025ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11026ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11027ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11028ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11029ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11030ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11031ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11032ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11033ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11034ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11035ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11036ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11037ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11038ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11039ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11040ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11041ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11042ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11043ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11044ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11045ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11046ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11047ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11048ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11049ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11050ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11051ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11052ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11053ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11054ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11055ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11056ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11057ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11058ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11059ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11060ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11061ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11062ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11063ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11064ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11065ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11066ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11067ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11068ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11069ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11070ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11071ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11072ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11073ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11074ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11075ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11076ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11077ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11078ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11079ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11080ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11081ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11082ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11083ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11084ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11085ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11086ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11087ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11088ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11089ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11090ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11091ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11092ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11093ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11094ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11095ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11096ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11097ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11098ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11099ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11100ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Not Done/Never'
                  1='1. LT Once/Yr' 2='2. Annual' 3='3. Semi-annual'
                  4='4. Quarterly' 5='5. Monthly' ;
  VALUE v11101ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Much Too Low'
                  2='2. Too Low' 3='3. About Right' 4='4. Too High'
                  5='5. Much Too High' ;
  VALUE v11102ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11103ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11104ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11105ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Spanish' 2='02. French'
                  3='03. Greek' 4='04. Polish' 17='17. Other Eur'
                  21='21. Arabic' 22='22. East Indian, Hindi' 23='23. Hebrew'
                  24='24. Native American' 25='25. African Languages'
                  31='31. All Asian/Pac Island langs'
                  51='51. Am. Sign Language' 97='97. Other' ;
  VALUE v11106ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Spanish' 2='02. French'
                  3='03. Greek' 4='04. Polish' 17='17. Other Eur'
                  21='21. Arabic' 22='22. East Indian, Hindi' 23='23. Hebrew'
                  24='24. Native American' 25='25. African Languages'
                  31='31. All Asian/Pac Island langs'
                  51='51. Am. Sign Language' 97='97. Other' ;
  VALUE v11107ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Spanish' 2='02. French'
                  3='03. Greek' 4='04. Polish' 17='17. Other Eur'
                  21='21. Arabic' 22='22. East Indian, Hindi' 23='23. Hebrew'
                  24='24. Native American' 25='25. African Languages'
                  31='31. All Asian/Pac Island langs'
                  51='51. Am. Sign Language' 97='97. Other' ;
  VALUE v11108ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11109ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11110ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. On-Site Only'
                  2='2. Off-Site Only' 3='3. Both On-Site/Off-Site' ;
  VALUE v11111ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11112ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11113ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11114ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. On-Site Only'
                  2='2. Off-Site Only' 3='3. Both On-Site/Off-Site' ;
  VALUE v11115ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11116ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v11117ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11118ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11119ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v11120ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11121ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11122ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11123ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11124ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11125ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11126ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11127ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11128ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11129ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11130ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11131ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11132ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11133ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11134ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11135ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11136ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11137ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11138ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11139ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11140ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11141ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11142ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11143ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11144ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11145ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11146ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11147ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11148ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11149ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11150ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11151ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11152ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11153ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11154ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11155ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11156ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11157ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11158ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Alcohol'
                  2='02. Barbiturates' 3='03. Tranquilizers'
                  4='04. Other sedatives' 5='05. Hypnotics'
                  6='06. Combo of 02-05' 7='07. Amphetamines, including ice'
                  8='08. OTC meds' 9='09. Rx drugs (incl. Rx meth)'
                  10='10. Hallucinogens, LSD or PCP'
                  11='11. Inhalants/glue/gasoline' 12='12. Non-Rx methadone'
                  13='13. Synthetics' 14='14. Crank' 15='15. Combo of 07-13'
                  16='16. Combo of 01 or 02 and 07-09'
                  97='97. Other (including combo of drugs as primary abuse' ;
  VALUE v11159ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11160ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Alcohol'
                  2='02. Barbiturates' 3='03. Tranquilizers'
                  4='04. Other sedatives' 5='05. Hypnotics'
                  6='06. Combo of 02-05' 7='07. Amphetamines, including ice'
                  8='08. OTC meds' 9='09. Rx drugs (incl. Rx meth)'
                  10='10. Hallucinogens, LSD or PCP'
                  11='11. Inhalants/glue/gasoline' 12='12. Non-Rx methadone'
                  13='13. Synthetics' 14='14. Crank' 15='15. Combo of 07-13'
                  16='16. Combo of 01 or 02 and 07-09'
                  97='97. Other (including combo of drugs as primary abuse' ;
  VALUE v11161ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11162ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11163ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11164ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11165ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11166ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11167ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11168ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11169ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11170ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11171ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11172ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11173ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11174ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11175ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11176ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11177ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11178ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11179ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11180ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11181ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11182ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11183ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11184ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11185ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11186ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11187ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11188ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11189ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11190ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11191ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11192ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11193ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11194ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11195ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11196ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11197ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11198ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11199ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11200ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11201ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11202ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11203ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11204ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11205ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11206ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11207ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11208ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11209ff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v11210ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11211ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Alcohol'
                  2='02. Barbiturates' 3='03. Tranquilizers'
                  4='04. Other sedatives' 5='05. Hypnotics'
                  6='06. Combo of 02-05' 7='07. Amphetamines, including ice'
                  8='08. OTC meds' 9='09. Rx drugs (incl. Rx meth)'
                  10='10. Hallucinogens, LSD or PCP'
                  11='11. Inhalants/glue/gasoline' 12='12. Non-Rx methadone'
                  13='13. Synthetics' 14='14. Crank' 15='15. Combo of 07-13'
                  16='16. Combo of 01 or 02 and 07-09'
                  97='97. Other (including combo of drugs as primary abuse' ;
  VALUE v11212ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11213ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Alcohol'
                  2='02. Barbiturates' 3='03. Tranquilizers'
                  4='04. Other sedatives' 5='05. Hypnotics'
                  6='06. Combo of 02-05' 7='07. Amphetamines, including ice'
                  8='08. OTC meds' 9='09. Rx drugs (incl. Rx meth)'
                  10='10. Hallucinogens, LSD or PCP'
                  11='11. Inhalants/glue/gasoline' 12='12. Non-Rx methadone'
                  13='13. Synthetics' 14='14. Crank' 15='15. Combo of 07-13'
                  16='16. Combo of 01 or 02 and 07-09'
                  97='97. Other (including combo of drugs as primary abuse' ;
  VALUE v11214ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11215ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11216ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11217ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11218ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11219ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11220ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11221ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11222ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11223ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11224ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Native American'
                  2='02. Cent Eur/Scand' 3='03. Eastern Eur/Rus'
                  4='04. Middle Eastern' 5='05. Carribbean'
                  11='11. Pacific Islander' 12='12. East Indian/Pak'
                  13='13. Far East' 14='14. Portugese' 15='15. Jewish'
                  16='16. Appalachian' 17='17. Gay/Lesbian'
                  19='19. Asian NFS' 91='91. White NFS' 97='97. Other' ;
  VALUE v11225ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11226ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11227ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11228ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11229ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11230ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11231ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11232ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11233ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11234ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11235ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11236ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11237ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11238ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11239ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11240ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11241ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11242ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11243ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11244ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11245ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11246ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11247ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11248ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11249ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11250ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11251ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11252ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11253ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11254ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11255ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11256ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v11257ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v11258ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Under 3 mos'
                  2='2. 3 to 6 mos' 3='3. 7 to 12 mos' 4='4. 13 to 18 mos'
                  5='5. 19 to 24 mos' 6='6. 25 to 36 mos'
                  7='7. 37 mos or more' ;
  VALUE v11259ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11260ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11261ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11262ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11263ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11264ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. FDA'
                  7='07. Other Fed org/agency specified'
                  9='09. Fed--NFS/federal guidelines/policy'
                  11='11. Other state agency or office (except C and D above)'
                  12='12. Ref any local agcy'
                  51='51. Client needs/patient history'
                  52='52. Own unit/agency policy' 97='97. Other' ;
  VALUE v11265ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. FDA'
                  7='07. Other Fed org/agency specified'
                  9='09. Fed--NFS/federal guidelines/policy'
                  11='11. Other state agency or office (except C and D above)'
                  12='12. Ref any local agcy'
                  51='51. Client needs/patient history'
                  52='52. Own unit/agency policy' 97='97. Other' ;
  VALUE v11266ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11267ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11268ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11269ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11270ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11271ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11272ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION - NO METH' ;
  VALUE v11273ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11274ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11275ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11276ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11277ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11278ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. FDA'
                  7='07. Other Fed org/agency specified'
                  9='09. Fed--NFS/federal guidelines/policy'
                  11='11. Other state agency or office (except C and D above)'
                  12='12. Ref any local agcy'
                  51='51. Client needs/patient history'
                  52='52. Own unit/agency policy' 97='97. Other' ;
  VALUE v11279ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. FDA'
                  7='07. Other Fed org/agency specified'
                  9='09. Fed--NFS/federal guidelines/policy'
                  11='11. Other state agency or office (except C and D above)'
                  12='12. Ref any local agcy'
                  51='51. Client needs/patient history'
                  52='52. Own unit/agency policy' 97='97. Other' ;
  VALUE v11280ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. >1 Agency' 2='2. Only One' ;
  VALUE v11281ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11282ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11283ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11284ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11285ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11286ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v11287ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. FDA'
                  7='07. Other Fed org/agency specified'
                  9='09. Fed--NFS/federal guidelines/policy'
                  11='11. Other state agency or office (except C and D above)'
                  12='12. Ref any local agcy'
                  51='51. Client needs/patient history'
                  52='52. Own unit/agency policy' 97='97. Other' ;
  VALUE v11288ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. FDA'
                  7='07. Other Fed org/agency specified'
                  9='09. Fed--NFS/federal guidelines/policy'
                  11='11. Other state agency or office (except C and D above)'
                  12='12. Ref any local agcy'
                  51='51. Client needs/patient history'
                  52='52. Own unit/agency policy' 97='97. Other' ;
  VALUE v11289ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Do not admit'
                  2='02. Admit on priority'
                  3='03. Admit on priority/do not detoxify'
                  11='11. Contd in program--NFS'
                  12='12. Contd in program on priority basis'
                  51='51. Get into prenatal care program'
                  52='52. Get into prenatal/follow up after delivery'
                  53='53. Lower dosage' 54='54. Transfer to another program'
                  55='55. Determined by physician' 97='97. Other' ;
  VALUE v11290ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. Do not admit'
                  2='02. Admit on priority'
                  3='03. Admit on priority/do not detoxify'
                  11='11. Contd in program--NFS'
                  12='12. Contd in program on priority basis'
                  51='51. Get into prenatal care program'
                  52='52. Get into prenatal/follow up after delivery'
                  53='53. Lower dosage' 54='54. Transfer to another program'
                  55='55. Determined by physician' 97='97. Other' ;
  VALUE v11291ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11292ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11293ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11294ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11295ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11296ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11297ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11298ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11299ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11300ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11301ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11302ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11303ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11304ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11305ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11306ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11307ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11308ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11309ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11310ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11311ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11312ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHERS'
                  1='1. R ANSWERED No or None' ;
  VALUE v11313ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11314ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11315ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11316ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11317ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11318ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11319ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11320ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11321ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11322ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11323ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11324ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11325ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11326ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11327ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11328ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11329ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11330ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11331ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11332ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11333ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11334ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11335ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11336ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11337ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11338ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11339ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11340ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11341ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11342ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11343ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11344ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11345ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11346ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11347ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11348ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11349ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11350ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11351ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11352ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11353ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11354ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11355ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11356ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11357ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11358ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11359ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11360ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11361ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11362ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11363ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11364ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11365ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11366ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11367ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11368ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11369ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11370ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11371ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11372ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11373ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11374ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11375ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11376ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11377ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11378ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11379ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11380ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11381ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11382ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11383ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11384ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11385ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11386ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11387ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11388ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11389ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11390ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11391ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11392ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11393ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11394ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11395ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11396ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11397ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11398ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11399ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11400ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11401ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11402ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11403ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11404ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11405ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11406ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11407ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11408ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11409ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11410ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11411ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11412ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11413ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11414ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11415ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11416ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11417ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11418ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11419ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11420ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11421ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11422ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11423ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11424ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11425ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11426ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11427ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11428ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11429ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11430ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11431ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11432ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11433ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11434ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11435ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11436ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11437ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11438ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11439ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11440ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11441ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11442ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11443ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11444ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11445ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11446ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11447ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11448ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11449ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11450ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11451ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11452ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11453ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11454ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11455ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11456ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11457ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11458ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AD HOC'
                  2='2. REFERRAL AGREEMENT' 3='3. CONTRACT'
                  4='4. JOINT PROGRAM OR VENTURE' 7='7. OTHER' ;
  VALUE v11459ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11460ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11461ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. From Unit'
                  2='2. From Outside' 3='3. Both' ;
  VALUE v11462ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11463ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11464ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11465ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11466ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11467ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11468ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11469ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11470ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11471ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11472ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11473ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11474ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11475ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11476ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11477ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11478ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11479ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11480ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11481ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11482ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11483ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11484ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v11485ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11486ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v11487ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11488ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11489ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11490ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11491ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11492ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11493ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11494ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11495ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11496ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11497ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11498ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11499ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11500ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v11501ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v11502ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VERY DIFFICULT'
                  2='2. SOMEWT DIFFICULT' 3='3. A LITTLE DIFFICULT'
                  4='4. SOMEWT EASY' 5='5. VERY EASY' ;
  VALUE v11503ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11504ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11505ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11506ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11507ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11508ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11509ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11510ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11511ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v11512ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11513ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11514ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11515ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11516ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11517ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11518ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11519ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11520ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11521ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11522ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11523ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11524ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11525ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11526ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11527ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11528ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11529ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11530ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11531ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11532ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11533ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11534ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11535ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11536ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11537ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11538ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11539ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11540ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11541ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11542ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11543ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11544ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11545ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11546ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11547ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11548ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11549ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11550ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11551ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11552ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11553ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11554ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11555ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11556ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11557ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11558ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11559ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11560ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11561ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11562ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11563ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11564ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11565ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11566ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11567ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11568ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11569ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11570ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11571ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11572ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11573ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11574ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11575ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11576ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11577ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11578ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11579ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11580ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11581ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11582ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11583ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11584ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11585ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11586ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11587ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11588ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11589ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11590ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11591ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11592ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11593ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11594ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11595ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11596ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11597ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11598ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11599ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11600ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11601ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11602ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11603ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11604ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11605ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11606ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11607ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11608ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11609ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11610ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11611ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11612ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11613ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11614ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT'
                  2='2. FORGE CHECKS/EMBEZZLE' 3='3. FORGED PRESCRIPTIONS'
                  4='4. CON GAME/FRAUD' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG GOODS' 7='7. ASSAULT/MURDER'
                  8='08. Arson' 10='10. Probation/parole viol'
                  11='11. Crim sexual conduct' 12='12. Child abuse/neglect'
                  13='13. Family court'
                  96='96. Minor/misdemeanor (non-violent)' 97='97. OTHER' ;
  VALUE v11615ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11616ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11617ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11618ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11619ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11620ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11621ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11622ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11623ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11624ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11625ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11626ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. ASSOCDIR'
                  3='3. FINANDIR' 4='4. PLANNER' 5='5. ADMNASST'
                  6='6. OFFICMGR' 7='7. CLERK' 9='9. PUBRELAT'
                  10='10. LEGALSRV' 19='19. OTHADMIN' 21='21. OUTPTDIR'
                  22='22. ASSTHEAD' 23='23. CCLINSUP' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICAN' 42='42. NURSE' 43='43. OTHPRO'
                  44='44. PSYCHGST' 45='45. SOCWORKR' 71='71. VOLUNTER'
                  72='72. STUDENT' 73='73. PUBOFFCL' 74='74. PROFESOR'
                  95='95. NONE' 97='97. OTHER' ;
  VALUE v11627ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11628ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11629ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 29 YEARS OLD OR YOUNGER'
                  2='2. 30-34 YEARS OLD' 3='3. 35-39 YEARS OLD'
                  4='4. 40-44 YEARS OLD' 5='5. 45-49 YEARS OLD'
                  6='6. 50-54 YEARS OLD' 7='7. 55-59 YEARS OLD'
                  8='8. 60 YEARS OLD OR OLDER' ;
  VALUE v11630ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Female' 1='1. Male' ;
  VALUE v11631ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. WHITE' 2='2. BLACK'
                  5='5. OTHER' ;
  VALUE v11632ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11633ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11634ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11635ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11636ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v11637ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11638ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v11639ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v11640ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v11641ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v11642ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v11643ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v11644ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v11645ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v11646ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v11647ff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=3861;
INPUT
        CASEID 1-3              UNITID 4-8              V10004 9-12
        V10005 13-14            V10006 15-17            V10007 18-22
        V10008 23-24            V10009 25-27            V10010 28-32
        V10011 33-36            V10012 37-39            V10013 40-44
        V10014 45-46            V10015 47-48            V10016 49-50
        V10017 51-52            V10018 53-54            V10019 55-56
        V10020 57-58            V10021 59-60            V10022 61-62
        V10023 63-64            V10024 65-66            V10025 67-68
        V10026 69-70            V10027 71-72            V10028 73-74
        V10029 75-76            V10030 77-78            V10031 79-80
        V10032 81-83            V10033 84-86            V10034 87-89
        V10035 90-92            V10036 93-95            V10037 96-98
        V10038 99-101           V10039 102-104          V10040 105-106
        V10041 107-108          V10042 109-110          V10043 111-112
        V10044 113-114          V10045 115-117          V10046 118-120
        V10047 121-123          V10048 124-126          V10049 127-128
        V10050 129-131          V10051 132-134          V10052 135-137
        V10053 138-140          V10054 141-142          V10055 143-145
        V10056 146-148          V10057 149-151          V10058 152-154
        V10059 155-156          V10060 157-158          V10061 159-161
        V10062 162-164          V10063 165-167          V10064 168-170
        V10065 171-174          V10066 175-178          V10067 179-180
        V10068 181-183          V10069 184-185          V10070 186-190
        V10071 191-193          V10072 194-196          V10073 197-201
        V10074 202-209          V10075 210-217          V10076 218-225
        V10077 226-228          V10078 229-231          V10079 232-236
        V10080 237-239          V10081 240-242          V10082 243-247
        V10083 248-255          V10084 256-263          V10085 264-271
        V10086 272-279          V10087 280-281          V10088 282-288
        V10089 289-291          V10090 292-299          V10091 300-303
        V10092 304-305          V10093 306-313          V10094 314-316
        V10095 317-318          V10096 319-325          V10097 326-328
        V10098 329-330          V10099 331-338          V10100 339-341
        V10101 342-343          V10102 344-350          V10103 351-353
        V10104 354-361          V10105 362-363          V10106 364-371
        V10107 372-374          V10108 375-376          V10109 377-384
        V10110 385-387          V10111 388-389          V10112 390-396
        V10113 397-398          V10114 399-401          V10115 402-408
        V10116 409-410          V10117 411-413          V10118 414-421
        V10119 422-423          V10120 424-431          V10121 432-433
        V10122 434-440          V10123 441-443          V10124 444-446
        V10125 447-451          V10126 452-454          V10127 455-457
        V10128 458-462          V10129 463-464          V10130 465-472
        V10131 473-475          V10132 476-478          V10133 479-483
        V10134 484-486          V10135 487-489          V10136 490-494
        V10137 495-496          V10138 497-503          V10139 504-506
        V10140 507-509          V10141 510-514          V10142 515-517
        V10143 518-520          V10144 521-525          V10145 526-527
        V10146 528-534          V10147 535-537          V10148 538-539
        V10149 540-544          V10150 545-547          V10151 548-550
        V10152 551-555          V10153 556-557          V10154 558-564
        V10155 565-567          V10156 568-569          V10157 570-574
        V10158 575-577          V10159 578-580          V10160 581-585
        V10161 586-587          V10162 588-589          V10163 590-591
        V10164 592-594          V10165 595-597          V10166 598-600
        V10167 601-603          V10168 604-607          V10169 608-611
        V10170 612-614          V10171 615-618          V10172 619-621
        V10173 622-625          V10174 626-628          V10175 629-631
        V10176 632-633          V10177 634-637          V10178 638-641
        V10179 642-645          V10180 646-649          V10181 650-653
        V10182 654-657          V10183 658-661          V10184 662-665
        V10185 666-669          V10186 670-673          V10187 674-676
        V10188 677-679          V10189 680-681          V10190 682-689
        V10191 690-694          V10192 695-699          V10193 700-701
        V10194 702-706          V10195 707-711          V10196 712-717
        V10197 718-722          V10198 723-724          V10199 725-729
        V10200 730-734          V10201 735-738          V10202 739-743
        V10203 744-747          V10204 748-751          V10205 752-755
        V10206 756-759          V10207 760-763          V10208 764-766
        V10209 767-770          V10210 771-773          V10211 774-777
        V10212 778-780          V10213 781-783          V10214 784-787
        V10215 788-791          V10216 792-793          V10217 794-797
        V10218 798-801          V10219 802-805          V10220 806-810
        V10221 811-814          V10222 815-817          V10223 818-820
        V10224 821-824          V10225 825-828          V10226 829-831
        V10227 832-834          V10228 835-837          V10229 838-841
        V10230 842-844          V10231 845-847          V10232 848-850
        V10233 851-853          V10234 854-857          V10235 858-861
        V10236 862-863          V10237 864-867          V10238 868-871
        V10239 872-875          V10240 876-880          V10241 881-884
        V10242 885-887          V10243 888-889          V10244 890-893
        V10245 894-897          V10246 898-901          V10247 902-904
        V10248 905-907          V10249 908-911          V10250 912-914
        V10251 915-917          V10252 918-919          V10253 920-921
        V10254 922-925          V10255 926-929          V10256 930-931
        V10257 932-933          V10258 934-938          V10259 939-944
        V10260 945-947          V10261 948-949          V10262 950-951
        V10263 952-956          V10264 957-958          V10265 959-960
        V10266 961-962          V10267 963-964          V10268 965-966
        V10269 967-968          V10270 969-970          V10271 971-972
        V10272 973-974          V10273 975-976          V10274 977-978
        V10275 979-980          V10276 981-982          V10277 983-984
        V10278 985-986          V10279 987-988          V10280 989-990
        V10281 991-992          V10282 993-994          V10283 995-996
        V10284 997-998          V10285 999-1000         V10286 1001-1002
        V10287 1003-1004        V10288 1005-1006        V10289 1007-1008
        V10290 1009-1010        V10291 1011-1012        V10292 1013-1014
        V10293 1015-1016        V10294 1017-1018        V10295 1019-1020
        V10296 1021-1023        V10297 1024-1026        V10298 1027-1028
        V10299 1029-1030        V10300 1031-1032        V10301 1033-1034
        V10302 1035-1036        V10303 1037-1038        V10304 1039-1040
        V10305 1041-1042        V10306 1043-1045        V10307 1046-1048
        V10308 1049-1050        V10309 1051-1052        V10310 1053-1054
        V10311 1055-1056        V10312 1057-1058        V10313 1059-1061
        V10314 1062-1064        V10315 1065-1066        V10316 1067-1068
        V10317 1069-1070        V10318 1071-1072        V10319 1073-1075
        V10320 1076-1078        V10321 1079-1080        V10322 1081-1082
        V10323 1083-1084        V10324 1085-1087        V10325 1088-1090
        V10326 1091-1092        V10327 1093-1094        V10328 1095-1097
        V10329 1098-1100        V10330 1101-1103        V10331 1104-1106
        V10332 1107-1108        V10333 1109-1110        V10334 1111-1113
        V10335 1114-1115        V10336 1116-1117        V10337 1118-1119
        V10338 1120-1121        V10339 1122-1123        V10340 1124-1126
        V10341 1127-1128        V10342 1129-1131        V10343 1132-1133
        V10344 1134-1136        V10345 1137-1138        V10346 1139-1141
        V10347 1142-1143        V10348 1144-1145        V10349 1146-1147
        V10350 1148-1149        V10351 1150-1151        V10352 1152-1153
        V10353 1154-1155        V10354 1156-1157        V10355 1158-1159
        V10356 1160-1161        V10357 1162-1163        V10358 1164-1165
        V10359 1166-1167        V10360 1168-1169        V10361 1170-1171
        V10362 1172-1173        V10363 1174-1177        V10364 1178-1182
        V10365 1183-1184        V10366 1185-1186        V10367 1187-1188
        V10368 1189-1190        V10369 1191-1194        V10370 1195-1198
        V10371 1199-1200        V10372 1201-1202        V10373 1203-1204
        V10374 1205-1206        V10375 1207-1208        V10376 1209-1210
        V10377 1211-1212        V10378 1213-1216        V10379 1217-1220
        V10380 1221-1222        V10381 1223-1224        V10382 1225-1226
        V10383 1227-1228        V10384 1229-1230        V10385 1231-1232
        V10386 1233-1235        V10387 1236-1239        V10388 1240-1243
        V10389 1244-1247        V10390 1248-1251        V10391 1252-1255
        V10392 1256-1259        V10393 1260-1263        V10394 1264-1267
        V10395 1268-1271        V10396 1272-1275        V10397 1276-1279
        V10398 1280-1283        V10399 1284-1286        V10400 1287-1290
        V10401 1291-1294        V10402 1295-1298        V10403 1299-1302
        V10404 1303-1305        V10405 1306-1307        V10406 1308-1309
        V10407 1310-1313        V10408 1314-1317        V10409 1318-1321
        V10410 1322-1325        V10411 1326-1329        V10412 1330-1332
        V10413 1333-1336        V10414 1337-1339        V10415 1340-1341
        V10416 1342-1343        V10417 1344-1348        V10418 1349-1352
        V10419 1353-1356        V10420 1357-1360        V10421 1361-1364
        V10422 1365-1368        V10423 1369-1372        V10424 1373-1376
        V10425 1377-1380        V10426 1381-1384        V10427 1385-1388
        V10428 1389-1392        V10429 1393-1396        V10430 1397-1400
        V10431 1401-1404        V10432 1405-1407        V10433 1408-1411
        V10434 1412-1415        V10435 1416-1418        V10436 1419-1422
        V10437 1423-1426        V10438 1427-1430        V10439 1431-1434
        V10440 1435-1438        V10441 1439-1442        V10442 1443-1446
        V10443 1447-1450        V10444 1451-1454        V10445 1455-1456
        V10446 1457-1458        V10447 1459-1460        V10448 1461-1462
        V10449 1463-1464        V10450 1465-1466        V10451 1467-1468
        V10452 1469-1471        V10453 1472-1474        V10454 1475-1478
        V10455 1479-1482        V10456 1483-1486        V10457 1487-1490
        V10458 1491-1494        V10459 1495-1498        V10460 1499-1502
        V10461 1503-1506        V10462 1507-1510        V10463 1511-1514
        V10464 1515-1518        V10465 1519-1522        V10466 1523-1526
        V10467 1527-1530        V10468 1531-1534        V10469 1535-1538
        V10470 1539-1542        V10471 1543-1546        V10472 1547-1550
        V10473 1551-1554        V10474 1555-1558        V10475 1559-1562
        V10476 1563-1566        V10477 1567-1570        V10478 1571-1574
        V10479 1575-1578        V10480 1579-1582        V10481 1583-1586
        V10482 1587-1588        V10483 1589-1590        V10484 1591-1592
        V10485 1593-1594        V10486 1595-1596        V10487 1597-1598
        V10488 1599-1600        V10489 1601-1602        V10490 1603-1604
        V10491 1605-1606        V10492 1607-1608        V10493 1609-1610
        V10494 1611-1612        V10495 1613-1614        V10496 1615-1616
        V10497 1617-1618        V10498 1619-1620        V10499 1621-1622
        V10500 1623-1626        V10501 1627-1630        V10502 1631-1632
        V10503 1633-1634        V10504 1635-1636        V10505 1637-1638
        V10506 1639-1640        V10507 1641-1642        V10508 1643-1644
        V10509 1645-1646        V10510 1647-1648        V10511 1649-1650
        V10512 1651-1652        V10513 1653-1654        V10514 1655-1656
        V10515 1657-1660        V10516 1661-1662        V10517 1663-1664
        V10518 1665-1666        V10519 1667-1670        V10520 1671-1672
        V10521 1673-1674        V10522 1675-1676        V10523 1677-1678
        V10524 1679-1680        V10525 1681-1682        V10526 1683-1684
        V10527 1685-1686        V10528 1687-1688        V10529 1689-1690
        V10530 1691-1692        V10531 1693-1694        V10532 1695-1697
        V10533 1698-1700        V10534 1701-1703        V10535 1704-1706
        V10536 1707-1709        V10537 1710-1712        V10538 1713-1715
        V10539 1716-1718        V10540 1719-1720        V10541 1721-1722
        V10542 1723-1724        V10543 1725-1727        V10544 1728-1730
        V10545 1731-1733        V10546 1734-1736        V10547 1737-1738
        V10548 1739-1740        V10549 1741-1742        V10550 1743-1745
        V10551 1746-1747        V10552 1748-1750        V10553 1751-1752
        V10554 1753-1755        V10555 1756-1757        V10556 1758-1760
        V10557 1761-1762        V11004 1763-1766        V11005 1767-1768
        V11006 1769-1771        V11007 1772-1776        V11008 1777-1778
        V11009 1779-1781        V11010 1782-1786        V11011 1787-1790
        V11012 1791-1794        V11013 1795-1797        V11014 1798-1800
        V11015 1801-1803        V11016 1804-1806        V11017 1807-1809
        V11018 1810-1812        V11019 1813-1816        V11020 1817-1820
        V11021 1821-1824        V11022 1825-1827        V11023 1828-1831
        V11024 1832-1835        V11025 1836-1838        V11026 1839-1841
        V11027 1842-1844        V11028 1845-1848        V11029 1849-1852
        V11030 1853-1856        V11031 1857-1860        V11032 1861-1864
        V11033 1865-1868        V11034 1869-1872        V11035 1873-1876
        V11036 1877-1880        V11037 1881-1884        V11038 1885-1888
        V11039 1889-1892        V11040 1893-1896        V11041 1897-1900
        V11042 1901-1902        V11043 1903-1904        V11044 1905-1906
        V11045 1907-1908        V11046 1909-1910        V11047 1911-1912
        V11048 1913-1914        V11049 1915-1918        V11050 1919-1923
        V11051 1924-1926        V11052 1927-1929        V11053 1930-1933
        V11054 1934-1936        V11055 1937-1939        V11056 1940-1942
        V11057 1943-1945        V11058 1946-1950        V11059 1951-1953
        V11060 1954-1956        V11061 1957-1958        V11062 1959-1960
        V11063 1961-1963        V11064 1964-1966        V11065 1967-1969
        V11066 1970-1973        V11067 1974-1977        V11068 1978-1981
        V11069 1982-1986        V11070 1987-1989        V11071 1990-1991
        V11072 1992-1994        V11073 1995-1996        V11074 1997-1999
        V11075 2000-2002        V11076 2003-2005        V11077 2006-2009
        V11078 2010-2012        V11079 2013-2015        V11080 2016-2018
        V11081 2019-2022        V11082 2023-2026        V11083 2027-2029
        V11084 2030-2033        V11085 2034-2036        V11086 2037-2039
        V11087 2040-2042        V11088 2043-2045        V11089 2046-2048
        V11090 2049-2052        V11091 2053-2056        V11092 2057-2060
        V11093 2061-2064        V11094 2065-2068        V11095 2069-2072
        V11096 2073-2075        V11097 2076-2077        V11098 2078-2079
        V11099 2080-2082        V11100 2083-2084        V11101 2085-2086
        V11102 2087-2090        V11103 2091-2094        V11104 2095-2098
        V11105 2099-2101        V11106 2102-2104        V11107 2105-2107
        V11108 2108-2111        V11109 2112-2115        V11110 2116-2117
        V11111 2118-2119        V11112 2120-2123        V11113 2124-2127
        V11114 2128-2129        V11115 2130-2131        V11116 2132-2134
        V11117 2135-2137        V11118 2138-2142        V11119 2143-2145
        V11120 2146-2148        V11121 2149-2153        V11122 2154-2158
        V11123 2159-2163        V11124 2164-2169        V11125 2170-2174
        V11126 2175-2178        V11127 2179-2183        V11128 2184-2188
        V11129 2189-2192        V11130 2193-2196        V11131 2197-2199
        V11132 2200-2203        V11133 2204-2206        V11134 2207-2209
        V11135 2210-2212        V11136 2213-2216        V11137 2217-2220
        V11138 2221-2224        V11139 2225-2228        V11140 2229-2232
        V11141 2233-2236        V11142 2237-2240        V11143 2241-2244
        V11144 2245-2248        V11145 2249-2252        V11146 2253-2255
        V11147 2256-2259        V11148 2260-2263        V11149 2264-2267
        V11150 2268-2271        V11151 2272-2275        V11152 2276-2278
        V11153 2279-2282        V11154 2283-2286        V11155 2287-2290
        V11156 2291-2294        V11157 2295-2298        V11158 2299-2301
        V11159 2302-2305        V11160 2306-2308        V11161 2309-2311
        V11162 2312-2315        V11163 2316-2319        V11164 2320-2323
        V11165 2324-2326        V11166 2327-2330        V11167 2331-2334
        V11168 2335-2337        V11169 2338-2340        V11170 2341-2343
        V11171 2344-2346        V11172 2347-2349        V11173 2350-2353
        V11174 2354-2357        V11175 2358-2361        V11176 2362-2364
        V11177 2365-2367        V11178 2368-2370        V11179 2371-2373
        V11180 2374-2376        V11181 2377-2380        V11182 2381-2384
        V11183 2385-2387        V11184 2388-2391        V11185 2392-2395
        V11186 2396-2398        V11187 2399-2402        V11188 2403-2406
        V11189 2407-2410        V11190 2411-2414        V11191 2415-2418
        V11192 2419-2421        V11193 2422-2425        V11194 2426-2429
        V11195 2430-2433        V11196 2434-2437        V11197 2438-2441
        V11198 2442-2445        V11199 2446-2449        V11200 2450-2453
        V11201 2454-2457        V11202 2458-2461        V11203 2462-2465
        V11204 2466-2469        V11205 2470-2473        V11206 2474-2476
        V11207 2477-2480        V11208 2481-2484        V11209 2485-2488
        V11210 2489-2492        V11211 2493-2495        V11212 2496-2499
        V11213 2500-2502        V11214 2503-2505        V11215 2506-2509
        V11216 2510-2513        V11217 2514-2517        V11218 2518-2520
        V11219 2521-2524        V11220 2525-2528        V11221 2529-2532
        V11222 2533-2536        V11223 2537-2539        V11224 2540-2542
        V11225 2543-2544        V11226 2545-2548        V11227 2549-2551
        V11228 2552-2554        V11229 2555-2557        V11230 2558-2560
        V11231 2561-2563        V11232 2564-2567        V11233 2568-2571
        V11234 2572-2575        V11235 2576-2577        V11236 2578-2582
        V11237 2583-2587        V11238 2588-2591        V11239 2592-2596
        V11240 2597-2600        V11241 2601-2603        V11242 2604-2607
        V11243 2608-2611        V11244 2612-2613        V11245 2614-2616
        V11246 2617-2619        V11247 2620-2622        V11248 2623-2625
        V11249 2626-2629        V11250 2630-2632        V11251 2633-2635
        V11252 2636-2638        V11253 2639-2641        V11254 2642-2644
        V11255 2645-2648        V11256 2649-2650        V11257 2651-2652
        V11258 2653-2654        V11259 2655-2656        V11260 2657-2658
        V11261 2659-2660        V11262 2661-2662        V11263 2663-2664
        V11264 2665-2667        V11265 2668-2670        V11266 2671-2674
        V11267 2675-2676        V11268 2677-2680        V11269 2681-2684
        V11270 2685-2688        V11271 2689-2692        V11272 2693-2696
        V11273 2697-2698        V11274 2699-2700        V11275 2701-2702
        V11276 2703-2704        V11277 2705-2706        V11278 2707-2709
        V11279 2710-2712        V11280 2713-2714        V11281 2715-2716
        V11282 2717-2718        V11283 2719-2720        V11284 2721-2722
        V11285 2723-2724        V11286 2725-2726        V11287 2727-2729
        V11288 2730-2731        V11289 2732-2734        V11290 2735-2737
        V11291 2738-2741        V11292 2742-2745        V11293 2746-2749
        V11294 2750-2753        V11295 2754-2757        V11296 2758-2759
        V11297 2760-2763        V11298 2764-2767        V11299 2768-2771
        V11300 2772-2773        V11301 2774-2775        V11302 2776-2777
        V11303 2778-2779        V11304 2780-2783        V11305 2784-2785
        V11306 2786-2789        V11307 2790-2791        V11308 2792-2795
        V11309 2796-2799        V11310 2800-2801        V11311 2802-2803
        V11312 2804-2805        V11313 2806-2809        V11314 2810-2813
        V11315 2814-2817        V11316 2818-2820        V11317 2821-2823
        V11318 2824-2825        V11319 2826-2827        V11320 2828-2831
        V11321 2832-2835        V11322 2836-2839        V11323 2840-2841
        V11324 2842-2845        V11325 2846-2847        V11326 2848-2851
        V11327 2852-2855        V11328 2856-2858        V11329 2859-2860
        V11330 2861-2864        V11331 2865-2866        V11332 2867-2870
        V11333 2871-2874        V11334 2875-2877        V11335 2878-2879
        V11336 2880-2881        V11337 2882-2885        V11338 2886-2889
        V11339 2890-2892        V11340 2893-2894        V11341 2895-2896
        V11342 2897-2900        V11343 2901-2904        V11344 2905-2907
        V11345 2908-2909        V11346 2910-2911        V11347 2912-2915
        V11348 2916-2919        V11349 2920-2922        V11350 2923-2924
        V11351 2925-2926        V11352 2927-2930        V11353 2931-2934
        V11354 2935-2938        V11355 2939-2940        V11356 2941-2942
        V11357 2943-2944        V11358 2945-2948        V11359 2949-2952
        V11360 2953-2955        V11361 2956-2957        V11362 2958-2959
        V11363 2960-2963        V11364 2964-2967        V11365 2968-2970
        V11366 2971-2972        V11367 2973-2974        V11368 2975-2978
        V11369 2979-2982        V11370 2983-2985        V11371 2986-2987
        V11372 2988-2989        V11373 2990-2993        V11374 2994-2997
        V11375 2998-3000        V11376 3001-3002        V11377 3003-3004
        V11378 3005-3008        V11379 3009-3012        V11380 3013-3015
        V11381 3016-3017        V11382 3018-3019        V11383 3020-3021
        V11384 3022-3025        V11385 3026-3029        V11386 3030-3032
        V11387 3033-3034        V11388 3035-3036        V11389 3037-3040
        V11390 3041-3044        V11391 3045-3047        V11392 3048-3049
        V11393 3050-3051        V11394 3052-3055        V11395 3056-3059
        V11396 3060-3063        V11397 3064-3065        V11398 3066-3067
        V11399 3068-3071        V11400 3072-3075        V11401 3076-3078
        V11402 3079-3080        V11403 3081-3082        V11404 3083-3086
        V11405 3087-3090        V11406 3091-3093        V11407 3094-3095
        V11408 3096-3097        V11409 3098-3099        V11410 3100-3103
        V11411 3104-3107        V11412 3108-3110        V11413 3111-3112
        V11414 3113-3116        V11415 3117-3118        V11416 3119-3122
        V11417 3123-3126        V11418 3127-3129        V11419 3130-3131
        V11420 3132-3135        V11421 3136-3137        V11422 3138-3141
        V11423 3142-3145        V11424 3146-3148        V11425 3149-3150
        V11426 3151-3154        V11427 3155-3156        V11428 3157-3160
        V11429 3161-3164        V11430 3165-3167        V11431 3168-3169
        V11432 3170-3173        V11433 3174-3175        V11434 3176-3179
        V11435 3180-3183        V11436 3184-3186        V11437 3187-3188
        V11438 3189-3192        V11439 3193-3194        V11440 3195-3198
        V11441 3199-3202        V11442 3203-3205        V11443 3206-3207
        V11444 3208-3209        V11445 3210-3213        V11446 3214-3217
        V11447 3218-3220        V11448 3221-3222        V11449 3223-3224
        V11450 3225-3228        V11451 3229-3232        V11452 3233-3235
        V11453 3236-3237        V11454 3238-3239        V11455 3240-3243
        V11456 3244-3247        V11457 3248-3250        V11458 3251-3252
        V11459 3253-3254        V11460 3255-3258        V11461 3259-3260
        V11462 3261-3262        V11463 3263-3264        V11464 3265-3266
        V11465 3267-3268        V11466 3269-3270        V11467 3271-3272
        V11468 3273-3274        V11469 3275-3276        V11470 3277-3278
        V11471 3279-3280        V11472 3281-3282        V11473 3283-3284
        V11474 3285-3286        V11475 3287-3288        V11476 3289-3290
        V11477 3291-3292        V11478 3293-3294        V11479 3295-3296
        V11480 3297-3298        V11481 3299-3301        V11482 3302-3305
        V11483 3306-3308        V11484 3309-3310        V11485 3311-3312
        V11486 3313-3314        V11487 3315-3318        V11488 3319-3320
        V11489 3321-3322        V11490 3323-3324        V11491 3325-3326
        V11492 3327-3328        V11493 3329-3330        V11494 3331-3332
        V11495 3333-3334        V11496 3335-3336        V11497 3337-3338
        V11498 3339-3340        V11499 3341-3342        V11500 3343-3344
        V11501 3345-3346        V11502 3347-3348        V11503 3349-3352
        V11504 3353-3356        V11505 3357-3360        V11506 3361-3364
        V11507 3365-3368        V11508 3369-3372        V11509 3373-3376
        V11510 3377-3378        V11511 3379-3380        V11512 3381-3382
        V11513 3383-3384        V11514 3385-3386        V11515 3387-3388
        V11516 3389-3390        V11517 3391-3392        V11518 3393-3394
        V11519 3395-3396        V11520 3397-3398        V11521 3399-3402
        V11522 3403-3406        V11523 3407-3409        V11524 3410-3413
        V11525 3414-3416        V11526 3417-3420        V11527 3421-3424
        V11528 3425-3427        V11529 3428-3431        V11530 3432-3435
        V11531 3436-3437        V11532 3438-3441        V11533 3442-3445
        V11534 3446-3449        V11535 3450-3453        V11536 3454-3456
        V11537 3457-3460        V11538 3461-3464        V11539 3465-3468
        V11540 3469-3472        V11541 3473-3476        V11542 3477-3478
        V11543 3479-3482        V11544 3483-3486        V11545 3487-3490
        V11546 3491-3494        V11547 3495-3498        V11548 3499-3502
        V11549 3503-3506        V11550 3507-3510        V11551 3511-3514
        V11552 3515-3518        V11553 3519-3520        V11554 3521-3524
        V11555 3525-3528        V11556 3529-3532        V11557 3533-3536
        V11558 3537-3540        V11559 3541-3544        V11560 3545-3548
        V11561 3549-3551        V11562 3552-3555        V11563 3556-3559
        V11564 3560-3564        V11565 3565-3568        V11566 3569-3571
        V11567 3572-3574        V11568 3575-3578        V11569 3579-3582
        V11570 3583-3586        V11571 3587-3589        V11572 3590-3593
        V11573 3594-3596        V11574 3597-3599        V11575 3600-3602
        V11576 3603-3605        V11577 3606-3610        V11578 3611-3614
        V11579 3615-3618        V11580 3619-3622        V11581 3623-3626
        V11582 3627-3630        V11583 3631-3634        V11584 3635-3637
        V11585 3638-3641        V11586 3642-3644        V11587 3645-3647
        V11588 3648-3650        V11589 3651-3653        V11590 3654-3658
        V11591 3659-3662        V11592 3663-3666        V11593 3667-3670
        V11594 3671-3674        V11595 3675-3678        V11596 3679-3682
        V11597 3683-3685        V11598 3686-3689        V11599 3690-3692
        V11600 3693-3695        V11601 3696-3698        V11602 3699-3701
        V11603 3702-3706        V11604 3707-3710        V11605 3711-3714
        V11606 3715-3718        V11607 3719-3722        V11608 3723-3726
        V11609 3727-3730        V11610 3731-3733        V11611 3734-3737
        V11612 3738-3740        V11613 3741-3743        V11614 3744-3746
        V11615 3747-3749        V11616 3750-3753        V11617 3754-3757
        V11618 3758-3761        V11619 3762-3765        V11620 3766-3769
        V11621 3770-3771        V11622 3772-3774        V11623 3775-3777
        V11624 3778-3780        V11625 3781-3783        V11626 3784-3786
        V11627 3787-3789        V11628 3790-3792        V11629 3793-3795
        V11630 3796-3797        V11631 3798-3799        V11632 3800-3801
        V11633 3802-3804        V11634 3805-3807        V11635 3808-3810
        V11636 3811-3813        V11637 3814-3815        V11638 3816-3817
        V11639 3818-3819        V11640 3820-3822        V11641 3823-3824
        V11642 3825-3827        V11643 3828-3829        V11644 3830-3832
        V11645 3833-3834        V11646 3835-3837        V11647 3838-3839
        WGTCODA4 3840-3850 .8   WGTTODA4 3851-3861 .8   ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   UNITID  = 'ID NUMBER FOR UNIT/OSAT CENTER'
   V10004  = 'FS.INTERVIEWER ID'
   V10005  = 'FS.MONTH BEGAN INTV'
   V10006  = 'FS.DAY BEGAN INTV'
   V10007  = 'FS.YEAR BEGAN INTV'
   V10008  = 'FS.MONTH END INTV'
   V10009  = 'FS.DAY END INTV'
   V10010  = 'FS.YEAR END INTV'
   V10011  = 'FS.LENGTH INTV'
   V10012  = 'A1.MO BEGAN OSAT'
   V10013  = 'A1.YR BEGAN OSAT'
   V10014  = 'A2a.EXTNT REFERRALS COMPETN'
   V10015  = 'A2b.EXTNT FED GOVT $$ COMPETN'
   V10016  = 'A2c.EXTNT POLIT SUPPORT COMPETN'
   V10017  = 'A2d.EXTNT COMM SUPPORT COMPETN'
   V10018  = 'A2e.EXTNT PRIV INS COMPETN'
   V10019  = 'A2f.EXTNT PERSONNEL COMPETN'
   V10020  = 'A2g.EXTNT PRESTIGE COMPETN'
   V10021  = 'A3a.EXTNT B/O COST CLIENTS'
   V10022  = 'A3b.EXTNT B/O COST PAYERS'
   V10023  = 'A3c.EXTNT B/O STAFF CREDENTIALS'
   V10024  = 'A3d.EXTNT B/O ATTRACTIVE SETTING'
   V10025  = 'A3e.EXTNT B/O EASE OF ACCESS'
   V10026  = 'A3f.EXTNT B/O QUALITY OF CARE'
   V10027  = 'A3g.EXTNT B/O MARKETING'
   V10028  = 'A3h.EXTNT B/O RANGE AVAIL SERVICES'
   V10029  = 'A3i.EXTNT B/O PRICING STRAGEGIES'
   V10030  = 'A3j.EXTNT CB/O OST CONTROL'
   V10031  = 'A4.DEGREE CHANGE IN COMPETITION'
   V10032  = 'A5a.#HRS/WK NEGOTIATE'
   V10033  = 'A5b.#HRS/WK LIAISON'
   V10034  = 'A5c.#HRS/WKPUBLIC'
   V10035  = 'A5d.#HRS/WK IDENTIFY $$'
   V10036  = 'A5e.#HRS/WK INFORMATION'
   V10037  = 'A5f.#HRS/WK.POLICY MAKING'
   V10038  = 'A5g.#HRS/WK STAFF'
   V10039  = 'A5h.#HRS/WK PROFESSNAL ASSNS'
   V10040  = 'A6a.JOIN ASSNS:Y/N?'
   V10041  = 'A6b.PARTNERSHIP:Y/N?'
   V10042  = 'A6c.MERGER:Y/N?'
   V10043  = 'A6d.PLAN MERGER:Y/N?'
   V10044  = 'A7.NEW OSAT SERVICES:Y/N?'
   V10045  = 'A7a.m1.NEW OSAT SERV1'
   V10046  = 'A7a.m2.NEW OSAT SERV2'
   V10047  = 'A7a.m3.NEW OSAT SERV3'
   V10048  = 'A7a.m4.NEW OSAT SERV4'
   V10049  = 'A8.NEW OTHER SERVICES:Y/N?'
   V10050  = 'A8a.m1.NEW OTHR SERV1'
   V10051  = 'A8a.m2.NEW OTHR SERV2'
   V10052  = 'A8a.m3.NEW OTHR SERV3'
   V10053  = 'A8a.m4.NEW OTHR SERV4'
   V10054  = 'A9.STOPPED ANY SERVICES:Y/N?'
   V10055  = 'A9a.m1.STOPPED SERV1'
   V10056  = 'A9a.m2.STOPPED SERV2'
   V10057  = 'A9a.m3.STOPPED SERV3'
   V10058  = 'A9a.m4.STOPPED SERV4'
   V10059  = 'B1.CONTACT OTHER R'
   V10060  = 'B2.PROVIDE OTHER SERVICES:Y/N?'
   V10061  = 'B2a.m1.OTHR SERV1'
   V10062  = 'B2a.m2.OTHR SERV2'
   V10063  = 'B2a.m3.OTHR SERV3'
   V10064  = 'B2a.m4.OTHR SERV4'
   V10065  = 'B2b.PERC OSAT CLIENTS'
   V10066  = 'B2c.PERC OSAT REVENUE'
   V10067  = 'B3.GIVE ACCURATE #S:Y/N?'
   V10068  = 'B4.BEG MON ALL BUDGET'
   V10069  = 'B4.BEG DAY ALL BUDGET'
   V10070  = 'B4.BEG YEAR ALL BUDGET'
   V10071  = 'B4.END MON ALL BUDGET'
   V10072  = 'B4.END DAY ALL BUDGET'
   V10073  = 'B4.END YEAR ALL BUDGET'
   V10074  = 'B4a.TOT REV MRCFY'
   V10075  = 'B4b.TOT EXP MRCFY'
   V10076  = 'B4C.TOT S''&''W MRCFY'
   V10077  = 'B5.BEG MON OSAT BUDGET'
   V10078  = 'B5.BEG DAY OSAT BUDGET'
   V10079  = 'B5.BEG YEAR OSAT BUDGET'
   V10080  = 'B5.END MON  OSAT BUDGET'
   V10081  = 'B5.END DAY OSAT BUDGET'
   V10082  = 'B5.END YEAR OSAT BUDGET'
   V10083  = 'B5a.OSAT REV MRCFY'
   V10084  = 'B5b.OSAT EXP MRCFY'
   V10085  = 'B5c.OSAT S''&''W MRCFY'
   V10086  = 'B6.REV FROM FED GOVT'
   V10087  = 'B6a.ANY MEDICARE:Y/N?'
   V10088  = 'B6b.REV MEDICARE'
   V10089  = 'B6c.F/B OF MEDICARE'
   V10090  = 'B7.REV FROM STATE GOVT'
   V10091  = 'B7a.PERC BLOCK GRANTS'
   V10092  = 'B7b.ANY MEDICAID:Y/N?'
   V10093  = 'B7c.REV MEDICAID'
   V10094  = 'B7d.F/B OF MEDICAID'
   V10095  = 'B8.ANY COURT REV:Y/N?'
   V10096  = 'B8a.REV COURTS'
   V10097  = 'B8b.F/B OF COURTS'
   V10098  = 'B9.ANY COUNTY REV:Y/N?'
   V10099  = 'B9a.REV COUNTY'
   V10100  = 'B9b.F/B OF COUNTY'
   V10101  = 'B10.ANY OTH LOCAL REV:Y/N?'
   V10102  = 'B10a.REV OTHR LOCAL'
   V10103  = 'B10b.F/B OTHR LOCAL'
   V10104  = 'B11.REV FEES\INS'
   V10105  = 'B11a.ANY CLI FEE REV:Y/N?'
   V10106  = 'B11b.REV CLI FEES'
   V10107  = 'B11c.F/B CLI FEES'
   V10108  = 'B11d.ANY PRIV INSU REV:Y/N?'
   V10109  = 'B11e.REV PRIV INS'
   V10110  = 'B11f.F/B PRIV INS'
   V10111  = 'B12.ANY DONTNS REV:Y/N?'
   V10112  = 'B12a.REV DONTNS'
   V10113  = 'B13.ANY OTH SCRCS m1:Y/N?'
   V10114  = 'B13.OTH SRC m1'
   V10115  = 'B13a.REV SRC m1'
   V10116  = 'B14.ANY OTH SRC m2:Y/N?'
   V10117  = 'B14.OTH SRC m2'
   V10118  = 'B14a.REV SRC m2'
   V10119  = 'B15.ANY PARENT ORGN:Y/N?'
   V10120  = 'B15a.REV PARENT ORGN'
   V10121  = 'B16a.ANY FOR WOMEN:Y/N?'
   V10122  = 'B17a.REV WOMEN'
   V10123  = 'B18a.START MO'
   V10124  = 'B18a.START DAY'
   V10125  = 'B18a.START YEAR'
   V10126  = 'B19a.END MO'
   V10127  = 'B19a.END DAY'
   V10128  = 'B19b.END YEAR'
   V10129  = 'B16b.ANY FOR MINORITY:Y/N?'
   V10130  = 'B17b.REV MINORITIES'
   V10131  = 'B18b.START MO'
   V10132  = 'B19b.START DAY'
   V10133  = 'B18b.START YEAR'
   V10134  = 'B19b.END MO'
   V10135  = 'B19b.END DAY'
   V10136  = 'B19b.END YEAR'
   V10137  = 'B16c.ANY FOR TEENS:Y/N?'
   V10138  = 'B17c.REV TEENS'
   V10139  = 'B18c.START MO'
   V10140  = 'B18c.START DAY'
   V10141  = 'B18c.START YEAR'
   V10142  = 'B19c.END MO'
   V10143  = 'B19c.END DAY'
   V10144  = 'B19c.END YEAR'
   V10145  = 'B16d,ANY FOR HIV PREVTN:Y/N?'
   V10146  = 'B17d.REV HIV PREVTN'
   V10147  = 'B18d.START MON'
   V10148  = 'B18d.START DAY'
   V10149  = 'B18d.START YEAR'
   V10150  = 'B19d.END MON'
   V10151  = 'B19d.END DAY'
   V10152  = 'B19d.END YEAR'
   V10153  = 'B16e.ANY FOR HIV POSITV:Y/N?'
   V10154  = 'B17e.REV HIV POSITV'
   V10155  = 'B18e.START MON'
   V10156  = 'B18e.START DAY'
   V10157  = 'B18e.START YR'
   V10158  = 'B19e.END MON'
   V10159  = 'B19e.END DAY'
   V10160  = 'B19e.END YR'
   V10161  = 'B20.INTERVW CHKPT:OTHR SVCS/NOT'
   V10162  = 'B21.GIVE ACCURT #S:Y/N?'
   V10163  = 'B22.ACC OSAT INS:Y/N?'
   V10164  = 'B23.PERC ALL PRIV INS'
   V10165  = 'B24.PERC ALL MEDICAID'
   V10166  = 'B25.PERC ALL MEDICARE'
   V10167  = 'B26.PERC ALL HMO'
   V10168  = 'B27.PERC ALL PRIOR AUTH'
   V10169  = 'B28.PERC ALL CONCRNT REV'
   V10170  = 'B29.PERC ALL STATE PROG'
   V10171  = 'B30.PERC ALL PD FOR SELF'
   V10172  = 'B31.PERC ALL UNABLE PAY'
   V10173  = 'B32.PERC ALL REDUCED FEE'
   V10174  = 'B33.PERC ALL TURNED AWAY'
   V10175  = 'B34.PERC ALL SHORT TX'
   V10176  = 'B35.ACC OSAT INS:Y/N?'
   V10177  = 'B36.PERC OSAT PRIV INS'
   V10178  = 'B37.PERC OSAT MEDICAID'
   V10179  = 'B38.PERC OSAT MEDICARE'
   V10180  = 'B39.PERC OSAT HMO'
   V10181  = 'B40.PERC OSAT PRIOR AUTH'
   V10182  = 'B41.PERC OSAT CONCRNT REV'
   V10183  = 'B42.PERC OSAT STATE PROG'
   V10184  = 'B43.PERC OSAT PD FOR SELF'
   V10185  = 'B44.PERC OSAT UNABLE PAY'
   V10186  = 'B45.PERC OSAT REDUCED FEE'
   V10187  = 'B46.PERC OSAT TURNED AWAY'
   V10188  = 'B47.PERC OSAT SHORT TX'
   V10189  = 'B48.RENT/OWN/PROVIDED'
   V10190  = 'B48a.TOT RENTAL EXPENSE'
   V10191  = 'B49.#HRS/WK ALL STAFF WORK'
   V10192  = 'B49a.#HRS/WK OSAT STAFF WK'
   V10193  = 'B50.SUPPORT BY VOLUNTEERS:Y/N?'
   V10194  = 'B50a.#HRS/YR BY VOLUNTEERS'
   V10195  = 'B51a.#CLIENTS/YR GET OUTPT'
   V10196  = 'B51b.#CLIENTS/YR GET OSAT'
   V10197  = 'B52.#OSAT CLIENTS/WK'
   V10198  = 'UNIT OFFERS INDIV THERPY (DIRCTOR)'
   V10199  = '# IT SESSNS/UNIT/WEEK'
   V10200  = '# IT CLIENTS/UNIT/WEEK'
   V10201  = 'B53c.#MIN IT SESSION'
   V10202  = 'B53d.#HRS IT CLIENTS/WK'
   V10203  = 'B53e.$ CHARGE/IT SESSION'
   V10204  = 'B53f_1.PERC IT SESSNS BY BA/BS'
   V10205  = 'B53f_2.PERC IT SESSNS BY MA/MSW'
   V10206  = 'B53f_3.PERC IT SESSNS BY PHD.PSY'
   V10207  = 'B53f_4.PERC IT SESSNS BY MD.PSYCH'
   V10208  = 'B53f_5.OTH DEGR1'
   V10209  = 'B53f_5.PERC IT SESSNS BY DEGR1'
   V10210  = 'B53f_6.OTH DEGR2'
   V10211  = 'B53f_6.PERC IT SESSNS BY DEGR2'
   V10212  = 'B53f_7.OTH DEGR3'
   V10213  = 'B53f_7.PERC IT SESSNS BY DEGR3'
   V10214  = 'B53g.# IT SESSNS/CLIENT/WK'
   V10215  = 'B53h.# IT SESSNS/CLIENT/TX CRS'
   V10216  = 'B54.OSAT GROUP THERAPY:Y/N?'
   V10217  = '# GT SESSIONS/UNIT/WEEK'
   V10218  = '# GT CLIENTS/UNIT/WEEK'
   V10219  = 'B54c.# MIN GT SESSION'
   V10220  = 'B54d.# HRS GT CLIENT/WK'
   V10221  = 'B54e.$ CHARGE/GT SESSION'
   V10222  = 'B54f.# CLIENTS/GT SESSN'
   V10223  = 'B54g.# COUNSELORS/GT SESSN'
   V10224  = 'B54h_1.PERC GT SESSNS BY BA/BS'
   V10225  = 'B54h_2.PERC GT SESSNS BY MA/MSW'
   V10226  = 'B54h_3.PERC GT SESSNS BY PHD/PSY'
   V10227  = 'B54h_4.PERC GT SESSNS BY MD.PSY'
   V10228  = 'B54h_5.OTH DEGR1'
   V10229  = 'B54h_5.PERC GT SESSNS BY DEGR1'
   V10230  = 'B54h_6.OTH DEGR2'
   V10231  = 'B54h_6.PERC GT SESSNS BY DEGR2'
   V10232  = 'B54h_7.OTH DEGR3'
   V10233  = 'B54h_7.PERC GT SESSNS BY DEGR3'
   V10234  = '# GT SESSNS/CLIENT/WEEK'
   V10235  = '# GT SESSNS/CLIENT/COURSE OF TX'
   V10236  = 'OSAT FAMILY THERAPY: Y/N'
   V10237  = '# FT SESSNS/UNIT/WEEK'
   V10238  = '# FT CLIENTS/UNIT/WEEK'
   V10239  = 'B55c.# MIN FT SESSION'
   V10240  = 'B55d.# HRS FT CLIENT/WK'
   V10241  = 'B55e.$ CHARGE/FT SESSION'
   V10242  = 'B55f.# FAM MBRS/FT SESSN'
   V10243  = 'B55g.# COUN/FT SESSN'
   V10244  = 'B55h_1.PERC FT SESSNS BY BA/BS'
   V10245  = 'B55h_2.PERC FT SESSNS BY MA/MSW'
   V10246  = 'B55h_3.PERC FT SESSNS BY PHD.PSY'
   V10247  = 'B55h_4.PERC FT SESSNS BY MD.PSY'
   V10248  = 'B55h_5.OTH DEGR1'
   V10249  = 'B55h_5.PERC FT SESSNS BY DEGR1'
   V10250  = 'B55h_6.OTH DEGR2'
   V10251  = 'B55h_6.PERC FT SESSNS BY DEGR2'
   V10252  = 'B55h_7.OTH DEGR3'
   V10253  = 'B55h_7.PERC FT SESSNS BY DEGR3'
   V10254  = '# FT SESSNS/CLIENT/WEEK'
   V10255  = '# FT SESSNS/CLIENT/COURSE TX'
   V10256  = 'DOES UNIT OFFER METH (DIRECTOR): Y/N'
   V10257  = 'B56a.BEGAN IN LAST 5 YRS:Y/N?'
   V10258  = '# METHADONE CLIENTS/UNIT/WEEK'
   V10259  = 'B56c.# DOSAGES/WK OUTPT METH'
   V10260  = 'B56d.$ CHARGE/DOSE METH'
   V10261  = 'B57.STOPPED IN LAST 5 YRS:Y/N?'
   V10262  = 'B58.PROV NON_OSAT SERVICES:Y/N?'
   V10263  = 'B59.# STAFF HRS/WKK NON_OSAT SRV'
   V10264  = 'B60.PRIV_PROF/PRIV_NON/PUBLIC'
   V10265  = 'B61.CHANGE IN LAST 5 YRS:Y/N?'
   V10266  = 'B62a.EXTNT ADV INFO ON DECISIONS'
   V10267  = 'B62b.EXTNT ASK IDEAS FROM STAFF'
   V10268  = 'B62c.EXTNT MEET WITH STAFF'
   V10269  = 'B62d.EXTNT PROB SOLVE WITH STAFF'
   V10270  = 'C1.UNIT PART OF LARGER ONE:Y/N?'
   V10271  = 'C1a.CHANGE IN LAST 5 YRS:Y/N?'
   V10272  = 'C2.CHKPT.HOW ANSWERED C1:PART/NOT?'
   V10273  = 'C3.LARGER ORGN PUB/PFP/PNP'
   V10274  = 'C3a. LARGER ORGN FED/ST/LOCAL'
   V10275  = 'C4.LARGER ORGN HOSP/MHC/OTHR'
   V10276  = 'C4a.IF HOSP,GENERAL/PSYCHIATRIC'
   V10277  = 'C4b.IF OTHR,NHRES/CORR/HMO/OTHR'
   V10278  = 'C5.LARGER ORGN APPRV MAJOR DECS:Y/N?'
   V10279  = 'C6.UNIT OWNED BY ANOTHER ORGN:Y/N?'
   V10280  = 'C6a.CHANGE IN LAST 5 YRS:Y/N?'
   V10281  = 'C7.CHKPT.HOW ANSWERED C6:OWNED/NOT?'
   V10282  = 'C8.OWNING ORGN PUB/PFP/PNP'
   V10283  = 'C8a.OWNING ORGN FED/ST/LOCAL'
   V10284  = 'C9.OWNING ORGN HOSP/MHC/OTHR'
   V10285  = 'C9a.IF HOSP,GENERAL/PSYCHIATRIC'
   V10286  = 'C9b.IF OTHR,NHRES/CORR/HMO/OTHR'
   V10287  = 'C10.OWNING ORGN APPRV MAJOR DECS:Y/N?'
   V10288  = 'C11a.OWNING ORGN PROV FINAN SERV:Y/N?'
   V10289  = 'C11b.OWNING ORGN PROV PERSONNEL:Y/N?'
   V10290  = 'C11c.OWNING ORGN PROV PRICING:Y/N?'
   V10291  = 'C11d.OWNING ORGN PROV PROTOCOLS:Y/N?'
   V10292  = 'C11e.OWNING ORGN PROV WTG LISTS:Y/N?'
   V10293  = 'C11f,OWNING ORG PROV INTAKE:Y/N?'
   V10294  = 'C11g.OWNING ORGN PROV REVIEW:Y/N?'
   V10295  = 'C11h.OWNING ORGN PROV OTHER:Y/N?'
   V10296  = 'C11h_1.OTH SRVCES1'
   V10297  = 'C11h_2.OTH SRVCES2'
   V10298  = 'C12a.PROV FINAN SERV:Y/N?'
   V10299  = 'C12b.PROV PERSONNEL:Y/N?'
   V10300  = 'C12c.PROV PRICING:Y/N?'
   V10301  = 'C12d.PROV PROTOCOLS:Y/N?'
   V10302  = 'C12e.PROV WAITING LISTS:Y/N?'
   V10303  = 'C12f.PROV INTAKE/ASSMT:Y/N?'
   V10304  = 'C12g.PROV REVIEW:Y/N?'
   V10305  = 'C12h.ANY OTH SERVICES:Y/N?'
   V10306  = 'C12h_1.OTHR SERVICE1'
   V10307  = 'C12h_2.OTHR SERVICE2'
   V10308  = 'C13a.SHARE TX STAFF:Y/N?'
   V10309  = 'C13b.SHARE ADMIN STAFF:Y/N?'
   V10310  = 'C13c.SHARE TX PROTOCOLS:Y/N?'
   V10311  = 'C13d.SHARE CLIENT ASSMT PROTO:Y/N?'
   V10312  = 'C13e.SHARE OTHER SRVCES:Y/N?'
   V10313  = 'C13e_1.SERVICE1'
   V10314  = 'C13e_2.SERVICE2'
   V10315  = 'D1a.HAVE JCAHO/JCA LIC:Y/N?'
   V10316  = 'D1b.HAVE FDA LIC:Y/N?'
   V10317  = 'D1c.HAVE DEA LIC:Y/N?'
   V10318  = 'D1d.HAVE STATE LIC:Y/N?'
   V10319  = 'D1e_1.AGENCY/OFFICE1'
   V10320  = 'D1e_2.AGENCY/OFFICE2'
   V10321  = 'D1f.HAVE LOCAL LIC:Y/N?'
   V10322  = 'D1g.HAVE OTHR ORGN LIC:Y/N?'
   V10323  = 'D2.STATE REQ LIC TO OPERATE:Y/N?'
   V10324  = 'D2a_1.AGENCY/OFFICE1'
   V10325  = 'D2a_2.AGENCY/OFFICE2'
   V10326  = 'D2b.CAN SUBST OTHR LIC:Y/N?'
   V10327  = 'D3.NEED LIC TO RECEIVE PAYMT:Y/N?'
   V10328  = 'D3a_1.NEED LIC1'
   V10329  = 'D3a_2.NEED LIC2'
   V10330  = 'D3b_1.BY AGENCY/ORGN1'
   V10331  = 'D3b_2.BY AGENCY/ORGN2'
   V10332  = 'D4.PERIODIC REVIEW BY OUTSIDE:Y/N?'
   V10333  = 'D5a.BY JCAHO:Y/N?'
   V10334  = 'D5b.HOW OFTEN BY JCAHO'
   V10335  = 'D5c.BY STATE PUBLIC HEALTH:Y/N?'
   V10336  = 'D5d.HOW OFTEN BY STATE PH'
   V10337  = 'D5e.BY STATE MENTAL HEALTH:Y/N?'
   V10338  = 'D5f.HOW OFTEN BY STATE MH'
   V10339  = 'D5g.BY STATE SUBSTANCE ABUSE:Y/N?'
   V10340  = 'D5h.HOW OFTEN BY STATE SA'
   V10341  = 'D5i.BY FDA:Y/N?'
   V10342  = 'D5j.HOW OFTEN BY FDA'
   V10343  = 'D5k.BY DEA:Y/N?'
   V10344  = 'D5l.HOW OFTEN BY DEA'
   V10345  = 'D6.BY OTHER AGENCY:Y/N?'
   V10346  = 'D6a.WHICH AGENCY'
   V10347  = 'D6b.HOW OFTEN REVIEWED'
   V10348  = 'D7a.INCL FINANCIAL RECORDS:Y/N?'
   V10349  = 'D7b.INCL CONTACT CLIENTS:Y/N?'
   V10350  = 'D7c.INCL SITE VISIT:Y/N?'
   V10351  = 'D7d.INCL WRITTEN REPORT:Y/N?'
   V10352  = 'D7e.INCL RECORDS/CHARTS:Y/N?'
   V10353  = 'D7f.INCL MANUALS:Y/N?'
   V10354  = 'D7g.INCL QUALITY ASSURANCE:Y/N?'
   V10355  = 'D8a.EXTNT PROF PUBLICATIONS'
   V10356  = 'D8b.EXTNT CONFERENCE ATTENDANCE'
   V10357  = 'D8c.EXTNT TRAINING SESSIONS'
   V10358  = 'D8d.EXTNT ASSOCTN MEMBERSHIP'
   V10359  = 'D8e.EXTNT ADVISORY BOARDS'
   V10360  = 'D8f.EXTNT MARKET RESEARCH'
   V10361  = 'D8g.EXTNT TALK MEMBERS OSAT ORGNS'
   V10362  = 'E1.ANY MCA IN MRCFY:Y/N?'
   V10363  = 'E2.# MCA IN MRCFY'
   V10364  = 'E2a.# CLIENTS IN MCAS'
   V10365  = 'E3.ANY WITH OWNING ORGN:Y/N?'
   V10366  = 'E4.ANY WITH MEDICAID:Y/N?'
   V10367  = 'E4a.CONTRACTS WITH MEDICAID:Y/N?'
   V10368  = 'E5.ANY WITH OTHR GOVT PROGRAMS:Y/N?'
   V10369  = 'E6a.# WITH OTHR GOVT PROGRAMS'
   V10370  = 'E6b.# CONTRACT WITH OTH GOV PRO'
   V10371  = 'E6c_1.ANY WITH STATE SA AGENCY:Y/N?'
   V10372  = 'E6c_2.OTHER STATE AGENCIES:Y/N?'
   V10373  = 'E6c_3.COURTS,PRISONS:Y/N?'
   V10374  = 'E6c_4.OTHER LOCAL GOVT AGENCIES:Y/N?'
   V10375  = 'E6c_5.WITH MEDICARE:Y/N?'
   V10376  = 'E6c_6.OTHR FEDERAL PROGRAMS:Y/N?'
   V10377  = 'E7.MCA WITH PRIVATE COMPANIES:Y/N?'
   V10378  = 'E7a.# MCA WITH PRIV COMPANIES'
   V10379  = 'E7b.# CONTRACTS WITH PRIV COMP'
   V10380  = 'E7c_1.ANY WITH HMO:Y/N?'
   V10381  = 'E7c_2.ANY WITH PPO,EPO:Y/N?'
   V10382  = 'E7c_3.ANY WITH EAP:Y/N?'
   V10383  = 'E7c_4.ANY SELF_INSURING FIRMS:Y/N?'
   V10384  = 'E7c_5.ANY INSURANCE COMPANIES:Y/N?'
   V10385  = 'E7c_6.ANY OTHER ORGNS:Y/N?'
   V10386  = 'E7c_6.SPECIFY ORGN'
   V10387  = 'E8a.PERC OSAT MCA WITH LARGER ORGN'
   V10388  = 'E8b.PERC OSAT MCA WITH MEDICAID'
   V10389  = 'E8c.PERC OSAT MCA WITH OTH GOVT'
   V10390  = 'E8d.PERC OSAT MCA WITH PRIV ORGN'
   V10391  = 'CONSISTENCY CHECK E8a_d'
   V10392  = 'E9a.PERC REV BY MCA W LARGER ORGN'
   V10393  = 'E9b.PERC REV BY MCA W MEDICAID'
   V10394  = 'E9c.PERC REV BY MCA W OTHR GOVT AGNCY'
   V10395  = 'E9d.PERC REV BY MCA W PRIV ORGN'
   V10396  = 'CONSISTENCY CHECK E9a_d'
   V10397  = 'E10a_1.#HRS/WK ON ALL MCA'
   V10398  = 'E10a_2.#HRS/WK ON BILLING'
   V10399  = 'E10a_3.#HRS/WK ON NEGOTIATING'
   V10400  = 'E10a_4.#HRS/WK ON STATE REQ'
   V10401  = 'E10a_5.#HRS/WK ON FED REQ'
   V10402  = 'E10a_6.#HRS/WK ON UTIL REVIEW'
   V10403  = 'E10a_7.#HRS/WK ON OTH MCA FUNCTNS'
   V10404  = 'E10a_7.OTHR MCA FUNC1'
   V10405  = 'E10a_7.OTHR MCA FUNC2'
   V10406  = 'E10a_7.OTHR MCA FUNC3'
   V10407  = 'E10b_1.#HRS/WK ADM ON MCA'
   V10408  = 'E10b_2.#HRS/WK ADM ON BILLING'
   V10409  = 'E10b_3.#HRS/WK ADM ON NEGOTIATG'
   V10410  = 'E10b_4.#HRS/WK ADM ON STATE REQ'
   V10411  = 'E10b_5.#HRS/WK ADM ON FED REQ'
   V10412  = 'E10b_6.#HRS/WK ADM ON UTIL REVIEW'
   V10413  = 'E10b_7.#HRS/WK ADM ON OTHR MCA'
   V10414  = 'E10b_7.OTHR MCA FUNC1'
   V10415  = 'E10b_7.OTHR MCA FUNC2'
   V10416  = 'E10b_7.OTHR MCA FUNC3'
   V10417  = 'E11.YEAR FRST IN MCA'
   V10418  = 'E12a.PERC MAX # SSNS > THAN 20'
   V10419  = 'E12b.PERC MAX # SSNS 11_20'
   V10420  = 'E12c.PERC MAX # SSNS 6_10'
   V10421  = 'E12d.PERC MAX # SSNS 1_5'
   V10422  = 'E12e.PERC MAX # SSNS NO LIMIT'
   V10423  = 'CONSISTENCY CHECK E12a_e'
   V10424  = 'E13a.PERC INIT AUTHO > 5 SESSNS'
   V10425  = 'E13b.PERC INIT AUTHO 2_5 SESSNS'
   V10426  = 'E13c.PERC INIT AUTHO 1 SESSN'
   V10427  = 'E13d.PERC INIT AUTHO NO LIMIT'
   V10428  = 'CONSISTENCY CHECK E13a_e'
   V10429  = 'E14a.PERC REMAIN > 20 SESSNS'
   V10430  = 'E14b.PERC REMAIN 11_20 SESSNS'
   V10431  = 'E14c.PERC REMAIN 6_10 SESSNS'
   V10432  = 'E14d.PERC REMAIN < 5 SSNS'
   V10433  = 'CONSISTENCY CHECK E14a_e'
   V10434  = 'E15a.PERC REMAIN > 9 MONTHS'
   V10435  = 'E15b.PERC REMAIN 7_9 MONTHS'
   V10436  = 'E15c.PERC REMAIN 3_6 MONTHS'
   V10437  = 'E15d.PERC REMAIN < 3 MONTHS'
   V10438  = 'CONSISTENCY CHECK E15a_d'
   V10439  = 'E16.PERC REQ OUTPT BEF INPT'
   V10440  = 'E17a.PERC COVER INDIV THERAPY'
   V10441  = 'E17b.PERC COVER GROUP THERAPY'
   V10442  = 'E17c.PERC COVER FAMILY THERAPY'
   V10443  = 'E17d.PERC COVER SOCIAL SERVICES'
   V10444  = 'E17e.PERC COVER MEDICAL SERVICES'
   V10445  = 'E18.ANY MCA SPECIFY STAFF SKILLS:Y/N?'
   V10446  = 'E18a1.BACHELORS SPECIFIED:Y/N?'
   V10447  = 'E18a2.MASTERS SPECIFIED:Y/N?'
   V10448  = 'E18a3.DOCTORAL DEGREE SPECIFIED:Y/N?'
   V10449  = 'E18a4.MEDICAL DEGREE SPECIFIED:Y/N?'
   V10450  = 'E18a5.MCA PROVIDES SPECTRAINING:Y/N?'
   V10451  = 'E18a6.OTH CERT/TRNG/EDUC SPEC:Y/N?'
   V10452  = 'E18a7.WHICH SPECIFIED,M1'
   V10453  = 'E18a7.WHICH SPECIFIED,M2'
   V10454  = 'E19a.PERC REQUIRE PRE_CERTIFICATION'
   V10455  = 'E19b.PERC USE EXPLICIT CRITERIA'
   V10456  = 'E19c.PERC REQUIRE ASAM CRITERIA'
   V10457  = 'E19d.PERC SPECIFY # VISITS'
   V10458  = 'E19e.PERC HAVE MAX # SESSIONS'
   V10459  = 'E19f.PERC SPECIFY CONTENT TX'
   V10460  = 'E19g.PERC REQUIRE TX PROTOCOLS'
   V10461  = 'E19h.PERC SPECIFY SEQUENCE TX'
   V10462  = 'E19i.PERC REQUIRE TELEPHONE PRE_CERT'
   V10463  = 'E19j.PERC REQUIRE WRITTEN PRE_CERT'
   V10464  = 'E19k.PERC PROVIDE FORMS PRE_CERT'
   V10465  = 'E20a.PERC REQUIRE ONGOING REVIEW'
   V10466  = 'E20b.PERC USE EXPLICIT CRITERIA REVW'
   V10467  = 'E20c.PERC SPEICIFY CONTENT REVW'
   V10468  = 'E20d.PERC CHANGE THERAPIST PLAN'
   V10469  = 'E20e.PERC NOT REIMB IF RECERT LATE'
   V10470  = 'E20f.PERC REQ PHONE AUTHORIZATION'
   V10471  = 'E20g.PERC REQ WRITTEN AUTHORIZATION'
   V10472  = 'E20h.PERC SPEC CONTACT WITH CLINICIAN'
   V10473  = 'E20i.PERC SPEC CONT WITH PRIM CLINCN'
   V10474  = 'E20j.PERC REQUIRE COPAYMENT'
   V10475  = 'E21a.PERC REQ INFORM OF DISCHARGE'
   V10476  = 'E21b.PERC REQ FOLLOWUP AFTER DISCH'
   V10477  = 'E21c.PERC STOP PAYMT AGST STAFF WISH'
   V10478  = 'E21d.PERC INFORM UNIT OF OUTCOME'
   V10479  = 'E21e.PERC PERFORM RETROSPECTV REVW'
   V10480  = 'E21f.PERC REIMB AT LESS THAN COST'
   V10481  = 'E21g.PERC DISALLOW CLAIMS POST FACT'
   V10482  = 'E22a.EXTNT REQUIRE WRITTEN COMMUNICTN'
   V10483  = 'E22b.EXTNT ENHANCE UNIT EFFICIENCY'
   V10484  = 'E22c.EXTNT REQUIRE COORDINATE CARE'
   V10485  = 'E22d.EXTNT IMPROVE TX PRACTICES UNIT'
   V10486  = 'E22e.EXTNT RESULT NEW SOP IN UNIT'
   V10487  = 'E22f.EXTNT IMPROVE ABILITY MONITOR'
   V10488  = 'E22g.EXTNT REQUIRE NEW QA PROCEDURES'
   V10489  = 'E22h.EXTNT RESULT SMOOTHR TRANSITIONS'
   V10490  = 'E22i.EXTNT HINDER DAILY FUNCTIONS'
   V10491  = 'E22j.EXTNT HELP KEEP TO BUDGET'
   V10492  = 'E22k.EXTNT RESULT COMPUTR/TECHN EQUIP'
   V10493  = 'E22l.EXTNT HELP ASSURE INTENSITY TX'
   V10494  = 'E22m.EXTNT HELP UNIT BETTER SERVE'
   V10495  = 'E22n.EXTNT HINDER COORDINATION TX'
   V10496  = 'E22o.EXTNT IMPRVE AWARENESS PRACTICES'
   V10497  = 'E22p.EXTNT RESULT BETTER OUTCOMES'
   V10498  = 'E22q.EXTNT REQ DO MORE WITH LESS'
   V10499  = 'F1.EXTNT COLLECT FOLLOWUP DATA'
   V10500  = 'F2a.PERC EX_CLIENTS FREE FROM SA'
   V10501  = 'F2b.PERC EX_CLIENTS CONTINUE SA'
   V10502  = 'F3.EXTNT USE F_U TO CHANGE PROGRMS'
   V10503  = 'G1a.EXTNT STAFF FEAR AIDS CONTACT'
   V10504  = 'G2a.EXTNT FAVOR NEEDLE DISTRIBUTN'
   V10505  = 'G2b.EXTNT FAVOR BLEACH DISTRIBUTN'
   V10506  = 'G2c.EXTNT FAVOR CONDOM DISTRIBUTN'
   V10507  = 'G2d.EXTNT FAVOR EDUCTNL MATERIALS'
   V10508  = 'G2e.EXTNT FAVOR NEEDLE EXCHANGE'
   V10509  = 'G3a.EXTNT TALK AIDS RISKS VIA SEX'
   V10510  = 'G3b.EXTNT TALK AIDS RISKS VIA NEEDLES'
   V10511  = 'G3c.EXTNT TALK AIDS RISKS TO FETUS'
   V10512  = 'G3d.EXTNT DISTRIBUTE PREVENTV MATRL'
   V10513  = 'G3e.EXTNT USE MASS MEDIA'
   V10514  = 'G3f.EXTNT SPECIFIC AIDS STAFF'
   V10515  = 'G3f1.# HRS/WK WORK ON AIDS'
   V10516  = 'G3f2.AIDS ONLY OR NOT:ONLY/NOT?'
   V10517  = 'G4.EXTNT WORK W OTHR GROUPS'
   V10518  = 'G5.EXTNT WORK IN COMMUNITY'
   V10519  = 'G6.#TOTAL HRS/WK IN COMMUNITY'
   V10520  = 'G7.STAFF RECVD SPECIAL AIDS TRNG:Y/N?'
   V10521  = 'G8a.DISTRIB MATERL HOW STERILIZE:Y/N?'
   V10522  = 'G8b.DISTRIB MATERL USE CONDOMS:Y/N?'
   V10523  = 'G8c.DISTRIB MATERL ON PREVNT AIDS:Y/N?'
   V10524  = 'G8d.DISTRIBUTE CONDOMS:Y/N?'
   V10525  = 'G8e.DISTRIBUTE CLEAN NEEDLES:Y/N?'
   V10526  = 'G8f.DISTRIBUTE BLEACH SOLUTIONS:Y/N?'
   V10527  = 'G8g.TALK TO IV DRUG USERS ON ST:Y/N?'
   V10528  = 'G8h.TALK TO FAM/FRNDS DRUG USERS:Y/N?'
   V10529  = 'G8i.EXCHANGE NEEDLES:Y/N?'
   V10530  = 'H1.WHO RESPNDNT FOR DEMOG SECTION'
   V10531  = 'H1a.R DID SUPERVISOR DEMOG SECTN:Y/N?'
   V10532  = 'H2.# YRS EMPLOYED BY UNIT'
   V10533  = 'H2.# MOS EMPLOYED BY UNIT'
   V10534  = 'H2.# YRS IN FIELD OF SA'
   V10535  = 'H3.# MOS IN FIELD OF SA'
   V10536  = 'H4.PRESENT JOB POSITION/TITLE'
   V10537  = 'H4a.# YRS IN POSITION'
   V10538  = 'H4a,# MOS IN POSITION'
   V10539  = 'H5.# YRS OF AGE - CATEGORIZED'
   V10540  = 'H6.IS DIR R MALE OR FEMALE?'
   V10541  = 'H7 RACE - RECODED'
   V10542  = 'H8.HISPANIC ORIGIN:Y/N?'
   V10543  = 'H9.# HRS/WK ALLTOLD WRK FOR OSAT UNIT'
   V10544  = 'H10a.# HRS/WK THERAPY TO CLIENTS'
   V10545  = 'H10b.# HRS/WK SUPERVISING THERAPIST'
   V10546  = 'H11.HIGHEST GRADE OF EDUCATION'
   V10547  = 'H11a.HAVE HGH SCHL DIPLMA OR GED:Y/N?'
   V10548  = 'H11b.HAVE COLLEGE DEGREE:Y/N?'
   V10549  = 'H11c1.DEGREES HAVE,M1'
   V10550  = 'H11d1.FIELD OF DEGREE,M1'
   V10551  = 'H11c2.DEGREES HAVE,M2'
   V10552  = 'H11d2.FIELD OF DEGREE,M2'
   V10553  = 'H11c3.DEGREES HAVE,M3'
   V10554  = 'H11d3.FIELD OF DEGREE,M3'
   V10555  = 'H11c4.DEGREES HAVE,M4'
   V10556  = 'H11d4.FIELD OF DEGREE,M4'
   V10557  = 'H12.HAVE LIC/CERT AS SA COUNSLR:Y/N'
   V11004  = 'FS3. INTERVIEWER ID'
   V11005  = 'FS4. MONTH INTERVIEW BEGAN'
   V11006  = 'FS4. DAY INTERVIEW BEGAN'
   V11007  = 'FS4. YEAR INTERVIEW BEGAN'
   V11008  = 'FS5. MONTH INTERVIEW ENDED'
   V11009  = 'FS5. DAY INTERVIEW ENDED'
   V11010  = 'FS5. YEAR INTERVIEW ENDED'
   V11011  = 'FS6. LENGTH INTERVIEW IN MINUTES'
   V11012  = 'A1a. PERC CLI R/B COURTS'
   V11013  = 'A1b. PERC CLI R/B SA TX FACILITIES'
   V11014  = 'A1c. PERC CLI R/B MH PROVIDERS'
   V11015  = 'A1d. PERC CLI R/B GENERAL HC'
   V11016  = 'A1e. PERC CLI R/B VOC REHAB PROV'
   V11017  = 'A1f. PERC CLI R/B SCHOOLS'
   V11018  = 'A1g. PERC CLI R/B EMP ASST PROGMS'
   V11019  = 'A1h. PERC CLI R/B OTHER/SELF'
   V11020  = 'SUMMARY A1a-A1h'
   V11021  = 'A2a. PERC FEM CLI R/B COURTS'
   V11022  = 'A2b. PERC FEM CLI R/B SA TX FAC'
   V11023  = 'A2c. PERC FEM CLI R/B MH PROVIDERS'
   V11024  = 'A2d. PERC FEM CLI R/B GENERAL HC'
   V11025  = 'A2e. PERC FEM CLI R/B VOC REHAB PROV'
   V11026  = 'A2f. PERC FEM CLI R/B SCHOOLS'
   V11027  = 'A2g. PERC FEM CLI R/B EAP'
   V11028  = 'A2h. PERC FEM CLI R/B OTHER/SELF'
   V11029  = 'SUMMARY A2a-A2h'
   V11030  = 'A3a. PERC OSAT CLI R/T RESID TX FAC'
   V11031  = 'A3b. PERC OSAT CLI R/T GEN HC PROV'
   V11032  = 'A3c. PERC OSAT CLI R/T MH PROVIDERS'
   V11033  = 'A3d. PERC OSAT CLI R/T OSAT TX FAC'
   V11034  = 'A3e. PERC OSAT CLI R/T VOC REHAB'
   V11035  = 'A3f. PERC OSAT CLI R/T SELF-HELP GRP'
   V11036  = 'A3g. PERC OSAT CLI R/T WOMEN CENTERS'
   V11037  = 'SUMMARY A3a-A3g'
   V11038  = 'A4a. PERC FACS UNIT SENDS WR CASE SUM'
   V11039  = 'A4b. PERC FACS UNIT SENDS COMP CHART'
   V11040  = 'A4c. PERC FACS UNIT DOES PHONE SUMM'
   V11041  = 'A4d. PERC FACS UNIT GIVES FUP CALL'
   V11042  = 'A5. UNIT HAS SPEC OUTREACH:Y/N?'
   V11043  = 'A5a. UNIT HAS PUBLIC EDUC SESSNS:Y/N?'
   V11044  = 'A5b. UNIT TRAINS POTENTL REFEREES:Y/N?'
   V11045  = 'A5c. UNIT POSTS FLIERS OR ADVERT:Y/N?'
   V11046  = 'A5d. UNIT OUTREACH FOR WOMEN:Y/N?'
   V11047  = 'A5e. UNIT OUTREACH FOR MINOR:Y/N?'
   V11048  = 'A6. UNIT AFFIL W COMM-BASED OUTR:Y/N?'
   V11049  = 'B1. # FULL-TIME PAID STAFF'
   V11050  = 'B1a. #SUM TOTAL HRS/WK BY FT PD STAFF'
   V11051  = 'B1b. # WOMEN IN FT PD STAFF'
   V11052  = 'B1c. # AFRIC-AMER FT PD STAFF'
   V11053  = 'B1d. # HISPANICS FT PD STAFF'
   V11054  = 'B1e. # OTHER MINORITIES FT PD STAFF'
   V11055  = 'B1f. MINORITY GROUP M1'
   V11056  = 'B1f. MINORITY GROUP M2'
   V11057  = 'B2. # PART-TIME PAID STAFF'
   V11058  = 'B2a. #SUM TOTAL HRS/WK BY PT PD STAFF'
   V11059  = 'B2b. # WOMEN IN PT PD STAFF'
   V11060  = 'B2c. # AFRIC-AMER PT PD STAFF'
   V11061  = 'B2d. # HISPANICS PT PD STAFF'
   V11062  = 'B2e. # OTHER MINORITIES PT PD STAFF'
   V11063  = 'B2f. MINORITY GROUP M1'
   V11064  = 'B2f. MINORITY GROUP M2'
   V11065  = 'B3. # CONSULTANTS/CONTRACTORS STAFF'
   V11066  = 'B3a. #SUM TOTAL HRS/WK BY CONS/CONT'
   V11067  = 'B4a. PERC HRS/WK ON ADMINISTRATION'
   V11068  = 'B4b. PERC HRS/WK ON CLERICAL/SUPPORT'
   V11069  = 'B5.  # HRS/WK TO OSAT CLIENTS'
   V11070  = 'B6a. # TX STAFF HAVE PH.D.'
   V11071  = 'B6b. # TX STAFF PHD PSYCHOLOGISTS'
   V11072  = 'B7a. # TX STAFF HAVE MD/DO'
   V11073  = 'B7b. # TX STAFF MD PSYCHIATRISTS'
   V11074  = 'B8a. # TX STAFF HAVE MASTERS'
   V11075  = 'B8b. # TX STAFF MASTERS IN PSYCH'
   V11076  = 'B8c. # TX STAFF MASTERS IN SOCWK'
   V11077  = 'B9.  # TX STAFF HAVE BACHELORS'
   V11078  = 'B10. # TX STAFF HAVE RN'
   V11079  = 'B11. # TX STAFF HAVE ASSOC/SOME COLL'
   V11080  = 'B12. # TX STAFF HAVE HIGH SCHOOL DEG'
   V11081  = 'B13. # TX STAFF HAVE SA TX TRAINING'
   V11082  = 'B14. # TX STAFF HAVE CERTIF IN SA TX'
   V11083  = 'B15. # TX STAFF ARE EX-ADDICTS'
   V11084  = 'B16. # TX STAFF ARE WOMEN'
   V11085  = 'B17a. # TX STAFF ARE FEM AFRIC-AMER'
   V11086  = 'B17b. # TX STAFF ARE FEM HISPANIC'
   V11087  = 'B17c. # TX STAFF ARE FEM OTHR MINOR'
   V11088  = 'B17d. MINORITY GROUP M1'
   V11089  = 'B17d. MINORITY GROUP M2'
   V11090  = 'B18a. PERC OSAT TX BY PHDS'
   V11091  = 'B18b. PERC OSAT TX BY MD/DO'
   V11092  = 'B18c. PERC OSAT TX BY MASTERS'
   V11093  = 'B18d. PERC OSAT TX BY BACHELORS'
   V11094  = 'B18e. PERC OSAT TX BY OTHER SCHOLG'
   V11095  = 'SUMMARY OF B18a-B18e'
   V11096  = 'B19. # CONS/CONTR PROVIDE SA TX'
   V11097  = 'B20a. # CONS/CONTR ARE PHYSICIANS'
   V11098  = 'B20b. # CONS/CONTR ARE PSYCHOLOGISTS'
   V11099  = 'B20c. # CONS/CONTR ARE SW/PSYCH MA'
   V11100  = 'B21. HOW OFTEN PERF EVAL OF TX STAFF'
   V11101  = 'B22. ASSESSMENT OF CASELOAD'
   V11102  = 'B23. # CLIENTS IN TYPICAL CASELOAD'
   V11103  = 'B24. # CLIENTS IN IDEAL CASELOAD'
   V11104  = 'B25. # TX STAFF ARE BILINGUAL'
   V11105  = 'B25a. LANGUAGE M1'
   V11106  = 'B25a. LANGUAGE M2'
   V11107  = 'B25a. LANGUAGE M3'
   V11108  = 'B26. PERC STAFF TRNED WORK W MINOR'
   V11109  = 'B26a. AVG # HRS TRAINED ON MINOR'
   V11110  = 'B26b. WHERE TRAINING'
   V11111  = 'B26c. DID UNIT PROVIDE TRAINING:Y/N?'
   V11112  = 'B27. PERC STAFF TRNED WORK W WOMEN'
   V11113  = 'B27a. AVG # HRS TRAINED ON WOMEN'
   V11114  = 'B27b. WHERE TRAINING'
   V11115  = 'B27c. DID UNIT PROVIDE TRAINING:Y/N?'
   V11116  = 'C1. BEGINNING MONTH MRCFY'
   V11117  = 'C1. BEGINNING DAY MRCFY'
   V11118  = 'C1. BEGINNING YEAR MRCFY'
   V11119  = 'C1. ENDING MONTH MRCFY'
   V11120  = 'C1. ENDING DAY MRCFY'
   V11121  = 'C1. ENDING YEAR MRCFY'
   V11122  = 'C2.  # TOTAL OUTPT CLIENTS MRCFY'
   V11123  = 'C2a. # WOMEN OUTPT CLIENTS MRCFY'
   V11124  = 'C3.   # TOTAL CLIENTS RECD SOME OSAT'
   V11125  = 'C3a.  # WOMEN OSAT CLIENTS MRCFY'
   V11126  = 'C3a1. # PREGNANT OSAT CLIENTS MRCFY'
   V11127  = 'C3b. # ACTIVE CLIENTS RECD OSAT NOW'
   V11128  = 'C3c. # ACTIVE WOMEN RECD OSAT NOW'
   V11129  = 'C3c1.# ACTIVE PREGNANT RECD OSAT NOW'
   V11130  = 'C4a. PERC OSAT CLI AFRIC-AMERC MRCFY'
   V11131  = 'C4b. PERC OSAT CLI HISPANIC MRCFY'
   V11132  = 'C4c. PERC OSAT CLI OTHR MINOR MRCFY'
   V11133  = 'C4d. MINORITY GROUP M1'
   V11134  = 'C4d. MINORITY GROUP M2'
   V11135  = 'C4d. MINORITY GROUP M3'
   V11136  = 'C5.PC ALC AB PROB CLI OF ALL OSAT'
   V11137  = 'C5a. PERC REQ BY EMPLOYER/COURTS MRCFY'
   V11138  = 'C5b.PC FEM ALC AB PROB CLI: AS PC OF C5.'
   V11139  = 'C5c. PERC OSAT CLI ALC ABUSE CURRENT'
   V11140  = 'C6.PC DRUG AB PROB CLI OF ALL OSAT MRCFY'
   V11141  = 'C6a. PERC REQ BY EMPLOYER/COURTS MRCFY'
   V11142  = 'C6b.PC FEM DRUG AB PROB CLI:AS PC OF C6'
   V11143  = 'C6c. PERC OSAT CLI DRUG ABUSE CURRENT'
   V11144  = 'C7a. PERC MRCFY CLI ABUSE HEROIN'
   V11145  = 'C7b. PERC MRCFY CLI ABUSE OPIATES'
   V11146  = 'C7c. PERC MRCFY CLI ABUSE BARBITURATES'
   V11147  = 'C7d. PERC MRCFY CLI ABUSE COCAINE'
   V11148  = 'C7e. PERC MRCFY CLI ABUSE CRACK'
   V11149  = 'C7f. PERC MRCFY CLI ABUSE AMPHETAM'
   V11150  = 'C7g. PERC MRCFY CLI ABUSE OVER CNTER'
   V11151  = 'C7h. PERC MRCFY CLI ABUSE HASH'
   V11152  = 'C7i. PERC MRCFY CLI ABUSE HALLUCINO'
   V11153  = 'C7j. PERC MRCFH CLI ABUSE INHALANTS'
   V11154  = 'C8a. PERC PRIMARY DRUG HEROIN'
   V11155  = 'C8b. PERC PRIMARY DRUG COCAINE'
   V11156  = 'C8c. PERC PRIMARY DRUG CRACK'
   V11157  = 'C8d. PERC PRIMARY DRUG HASH'
   V11158  = 'C8e. OTHER DRUG M1'
   V11159  = 'C8e. PERC PRIMARY DRUG M1'
   V11160  = 'C8e. OTHER DRUG M2'
   V11161  = 'C8e. PERC PRIMARY PRIMARY M2'
   V11162  = 'SUMMARY OF C8a-C8e'
   V11163  = 'C9a. PERC OSAT CLI ABUSE ONLY 1 DRUG'
   V11164  = 'C9b. PERC OSAT CLI ABUSE 2 DRUGS'
   V11165  = 'C9c. PERC OSAT CLI ABUSE 3 DRUGS'
   V11166  = 'C9d. PERC OSAT CLI ABUSE 4+ DRUGS'
   V11167  = 'C10a. PERC OSAT CLI UNDER AGE 20'
   V11168  = 'C10b. PERC OSAT CLI AGE 20-29'
   V11169  = 'C10c. PERC OSAT CLI AGE 30-39'
   V11170  = 'C10d. PERC OSAT CLI AGE 40-49'
   V11171  = 'C10e, PERC OSAT CLI AGE 50-64'
   V11172  = 'C10f. PERC OSAT CLI AGE 65 OR OVER'
   V11173  = 'SUMMARY C10a-C10f'
   V11174  = 'C11. PERC OSAT CLI USED NEEDLE MRCFY'
   V11175  = 'C12. PERC OSAT CLI INJECT MRCFY'
   V11176  = 'C13a. PERC OSAT CLI HIV+ IN MRCFY'
   V11177  = 'C13b. PERC OSAT CLI AIDS MRCFY'
   V11178  = 'C13c. PERC OSAT CLI DIED AIDS MRCFY'
   V11179  = 'C13d. PERC OSAT CLI HIV+ CURRENTLY'
   V11180  = 'C14a. PERC OSAT CLI MRCFY PROSTITUTE'
   V11181  = 'C14b. PERC OSAT CLI MRCFY BURGLAR'
   V11182  = 'C14c. PERC OSAT CLI MRCFY DEAL DRGS'
   V11183  = 'C14d. PERC OSAT CLI MRCFY VIOLENT'
   V11184  = 'C15. PERC OSAT CLI CURRENT UNEMPLOYED'
   V11185  = 'C16. PERC OSAT CLI CURRENT EMPLOYED'
   V11186  = 'C17. PERC OSAT CLI CURRENT PT EMPLOYED'
   V11187  = 'SUMMARY C15-C17'
   V11188  = 'C18a.PERC CLI PRIOR TX SA OTHER UNIT'
   V11189  = 'C18b.PERC CLI PRIOR TX SA YOUR UNIT'
   V11190  = 'C18c.PERC CLI NO PRIOR TX SA'
   V11191  = 'C18d.PERC CLI PRIOR TX MH PROBLEM'
   V11192  = 'C19a.PERC CLI PREDICT ABSTINENCE 2 YR'
   V11193  = 'C19b.PERC CLI PREDICT CONTROLLED USE'
   V11194  = 'C19c.PERC CLI PREDICT NO TROUBLE LAW'
   V11195  = 'C19d.PERC CLI PREDICT STAY EMPLOYED'
   V11196  = 'C19e.PERC CLI PREDICT ECON INDEPEND'
   V11197  = 'C20a.PERC FEM CLI ABUSE HEROIN'
   V11198  = 'C20b.PERC FEM CLI ABUSE OPIATES'
   V11199  = 'C20c.PERC FEM CLI ABUSE BARBITURATES'
   V11200  = 'C20d.PERC FEM CLI ABUSE COCAINE'
   V11201  = 'C20e.PERC FEM CLI ABUSE CRACK'
   V11202  = 'C20f.PERC FEM CLI ABUSE AMPHETAMINES'
   V11203  = 'C20g.PERC FEM CLI ABUSE OVER-COUNTER'
   V11204  = 'C20h.PERC FEM CLI ABUSE HASH'
   V11205  = 'C20i.PERC FEM CLI ABUSE HALLUCINOGENS'
   V11206  = 'C20j.PERC FEM CLI ABUSE INHALANTS'
   V11207  = 'C21a.PERC FEM CLI PDA WAS HEROIN'
   V11208  = 'C21b.PERC FEM CLI PDA WAS COCAINE'
   V11209  = 'C21c.PERC FEM CLI PDA WAS CRACK'
   V11210  = 'C21d.PERC FEM CLI PDA WAS HASH'
   V11211  = 'C21e.PDA WAS OTHER M1'
   V11212  = 'C21e.PERC FEM CLI PDA WAS M1'
   V11213  = 'C21e.PDA WAS OTHER M2'
   V11214  = 'C21e.PERC FEM CLI PDA WAS M2'
   V11215  = 'SUMMARY OF C21a-C21e'
   V11216  = 'C22a.PERC FEM CLI ABUSE ONLY 1 DRUG'
   V11217  = 'C22b.PERC FEM CLI ABUSE 2 DRUGS'
   V11218  = 'C22c.PERC FEM CLI ABUSE 3 DRUGS'
   V11219  = 'C22d.PERC FEM CLI ABUSE 4+ DRUGS'
   V11220  = 'C23a.PERC FEM OSAT CLI AFRIC-AMER'
   V11221  = 'C23b.PERC FEM OSAT CLI HISPANIC'
   V11222  = 'C23c.PERC FEM OSAT CLI OTHER MINORITY'
   V11223  = 'C23d.MINORITY GROUP M1'
   V11224  = 'C23d.MINORITY GROUP M2'
   V11225  = 'SUMMARY C23a-C23c'
   V11226  = 'C24.PERC FEM CLI MRCFY INJECT NEEDLES'
   V11227  = 'C25.PERC FEM CLI 30 DAYS INJECT STILL'
   V11228  = 'C26a.PERC FEM CLI MRCFY HIV+'
   V11229  = 'C26b.PERC FEM CLI MRCFY DX AIDS'
   V11230  = 'C26c.PERC FEM CLI MRCFY DIED AIDS'
   V11231  = 'C26d.PERC FEM CLI NOW HIV+'
   V11232  = 'C28a.PERC FEM CLI CHILDREN LIVE WITH'
   V11233  = 'C28b.PERC FEM CLI CHILDREN LIVE OTHER'
   V11234  = 'C28c.PERC FEM CLI ON WELFARE'
   V11235  = 'DOES UNIT OFFER METH (SUPERVISOR): Y/N'
   V11236  = '# METHADONE CLIENTS IN MRCFY'
   V11237  = '# WOMEN THAT GET METHADONE'
   V11238  = 'D2a1.# PREG FEM OP METH CLI MRCFY'
   V11239  = '# METHADONE CLIENTS CURRENTLY'
   V11240  = 'D3a.PERC RECEIVING PROG SMALLER DOSES'
   V11241  = 'D3b.PERC RECEIVING PROG LARAGER DOSES'
   V11242  = 'D3c.PERC RECEIVING SAME SIZE DOSES'
   V11243  = 'SUMMARY OF D3a-c'
   V11244  = 'D4a.PERC SAME SIZE IS UNDER 40 MG'
   V11245  = 'D4b.PERC SAME SIZE IS 40-59 MG'
   V11246  = 'D4c.PERC SAME SIZE IS 60-79 MG'
   V11247  = 'D4d.PERC SAME SIZE IS 80-99 MG'
   V11248  = 'D4e.PERC SAME SIZE IS 100+ MG'
   V11249  = 'SUMMARY OF D4a-e'
   V11250  = 'D5a.PERC CONT TX LESS THAN 3 MO'
   V11251  = 'D5b.PERC CONT TX 3 MO UP TO 1 YR'
   V11252  = 'D5c.PERC CONT TX 1 YR UP TO 2 YRS'
   V11253  = 'D5d.PERC CONT TX 2 YRS UP TO 3 YRS'
   V11254  = 'D5e.PERC CONT TX 3 YRS OR MORE'
   V11255  = 'SUMMARY OF D5a-e'
   V11256  = 'D6.EXT CLI INFLU DECISION DOSE LEVELS'
   V11257  = 'EXTENT STAFF URGES METH CLI DETOXIFY'
   V11258  = 'D7a.HOW LONG UNTIL ENC TO DETOXIFY'
   V11259  = 'D8a.LOCAL GOVT INFLU MAX METH TX:C/N?'
   V11260  = 'D8b.STATE GOVT INFLU MAX METH TX:C/N?'
   V11261  = 'D8c.FACILITY INFL MAX METH TX:C/N?'
   V11262  = 'D8d.CLIN NEED INFL MAX METH TX:C/N?'
   V11263  = 'D8e.SMTHG ELSE INFL MAX METH TX:C/N?'
   V11264  = 'D8e1.SMTHG ELSE M1'
   V11265  = 'D8e2.SMTHG ELSE M2'
   V11266  = 'D9.TYPICAL MAX METHADONE DOSE LEVEL'
   V11267  = 'D10.UNIT ALLOWS TAKEHOME DOSES:Y/N?'
   V11268  = 'D11a.#CLI TAKE HOME 1 DAY SUPPLY'
   V11269  = 'D11b.#CLI TAKE HOME 2-3 DAY SUPPLY'
   V11270  = 'D11c.#CLI TAKE HOME 4-6 DAY SUPPLY'
   V11271  = 'D11d.#CLI TAKE HOME 1+ WEEK SUPPLY'
   V11272  = 'D11e.#CLI NOT ALLOWED TAKE HOME SUPPLY'
   V11273  = 'D12a.DOES FDA INFLU DOSE LEVEL:Y/N?'
   V11274  = 'D12b.DOES DEA INFLU DOSE LEVEL:Y/N?'
   V11275  = 'D12c.DOES SHD INFLU DOSE LEVEL:Y/N?'
   V11276  = 'D12d.DOES SCAA INFLU DOSE LEVEL:Y/N?'
   V11277  = 'D12e.DOES OTH INFLU DOSE LEVEL:Y/N?'
   V11278  = 'D12e1.OTHER AGENCY M1'
   V11279  = 'D12e2.OTHER AGENCY M2'
   V11280  = 'D13.MORE THAN ONE AGENCY D12:Y/N?'
   V11281  = 'D14.CONFLICTS AMONG REQUIREMENTS:Y/N?'
   V11282  = 'D15a.DOES FDA REQ LOWEST LEVEL:Y/N?'
   V11283  = 'D15b.DOES DEA REQ LOWEST LEVEL:Y/N?'
   V11284  = 'D15c.DOES SHD REQ LOWEST LEVEL:Y/N?'
   V11285  = 'D15d.DOES SCAA REQ LOWEST LEVEL:Y/N?'
   V11286  = 'D15e.DOES OTHR REQ LOWEST LEVEL:Y/N?'
   V11287  = 'D15e1.OTHER AGENCY M1'
   V11288  = 'D15e2.OTHER AGENCY M2'
   V11289  = 'D16.POLICY ON METH FOR PREG WOMEN, M1'
   V11290  = 'D16.POLICY ON METH FOR PREG WOMEN, M2'
   V11291  = 'E1.PERC- OBTAIN DRUG HISTORY'
   V11292  = 'E2.PERC- OBTAIN SUPPORT NETWORK'
   V11293  = 'E3.PERC- OBTAIN PERCPTN DEPENDENCE'
   V11294  = 'E4.PERC- ASSESS PHYS/SEX ABUSE'
   V11295  = 'E5.PERC- ASSESS MENTAL HEALTH PROBLS'
   V11296  = 'E6.UNIT USES PSYCHOL TESTS:Y/N?'
   V11297  = '% ALL CLIENTS ARE DUAL DIAGNOSIS'
   V11298  = '% ALL DUAL DIAGNOSIS CLIENTS ARE FEMALE'
   V11299  = 'E8.PERC- OBTAIN DSM-IV DIAGNOSIS'
   V11300  = 'E9a.UNIT PROV WRITTEN PROC/ASSMTS:Y/N?'
   V11301  = 'E9b.UNIT COND STAFF TRNG ON PROCS:Y/N?'
   V11302  = 'E9c.UNIT COND FORMAL EVAL STAFF:Y/N?'
   V11303  = 'F1.UNIT OFFER OUTPT INDIV THER:Y/N?'
   V11304  = 'F1a.PERC CLI CURRENTLY REC IT'
   V11305  = 'F1b.CHOOSE SME GENDER THERAPST:Y/N?'
   V11306  = 'F1b1.PERC CLI CHOOSE SAME GENDER'
   V11307  = 'F1c.CHOOSE SME RACE THERAPIST:Y/N?'
   V11308  = 'F1c1.PERC CLI CHOOSE SAME RACE'
   V11309  = 'PCT CLIENTS GET GROUP THERAPY'
   V11310  = 'F2a.UNIT OFFERS SINGLE GENDER GT:Y/N?'
   V11311  = 'F2b.UNIT OFFERS SINGLE RACE GT:Y/N?'
   V11312  = 'F2c.CKPT.UNIT OFFER IT: NOT/OTHER?'
   V11313  = 'F3. PERC CLI REC BOTH IT AND G T'
   V11314  = 'F4a.PERC CLI SPEC TX FOR MULTIP DRUGS'
   V11315  = 'F4b.PERC CLI SPEC TX FOR DWI'
   V11316  = 'F4c.PERC CLI SPEC TX WITH ANTABUSE'
   V11317  = 'F4d.PERC CLI SPEC TX WITH NALTREXONE'
   V11318  = 'F5.ANY CLI REC GEN MED/MH SRVCS:Y/N?'
   V11319  = 'F6.ANY CLI REC PHYS EXAMS:Y/N?'
   V11320  = 'F6a.PERC CLI REC PHY EXAM'
   V11321  = 'F6b.PERC PE SV BY OUTSIDE SOURCE'
   V11322  = 'F6c.# EXT SOURCES PE USED PAST MONTH'
   V11323  = 'F6d.BASIS PE SERVICES PROVIDED'
   V11324  = 'F6e.PERC PE PROV VIA CONTRACT'
   V11325  = 'F7. ANY CLI REC TX FOR MH PROB:Y/N?'
   V11326  = 'F7a.PERC CLI REC MH TX'
   V11327  = 'F7b.PERC MH SV BY OUTSIDE SOURCE'
   V11328  = 'F7c.# EXT SOURCES MH USED PAST MONTH'
   V11329  = 'F7d.BASIS MH SERVICES PROVIDED'
   V11330  = 'F7e.PERC MH PROV VIA CONTRACT'
   V11331  = 'F8.ANY CLI REC ROUTINE MED CARE:Y/N?'
   V11332  = 'F8a.PERC CLI REC RMC'
   V11333  = 'F8b.PERC RMC BY OUTSIDE SOURCE'
   V11334  = 'F8c.# EXT SOURCES RMC USED PST MONTH'
   V11335  = 'F8d.BASIS RMC SERVICES PROVIDED'
   V11336  = 'F9.ANY CLI REC HIV/AIDS TESTG:Y/N?'
   V11337  = 'F9a.PERC CLI REC HIV/AIDS TSTG'
   V11338  = 'F9b.PERC HIV TSTG PROV BY OUTSIDE SRCE'
   V11339  = 'F9c.# EXT SOURCES HIV TG PAST MONTH'
   V11340  = 'F9d.BASIS HIV TSTG PROVIDED'
   V11341  = 'F10.ANY CLI REC ACUTE CARE HIV:Y/N?'
   V11342  = 'F10a.PERC CLI REC ACUTE HIV CARE'
   V11343  = 'F10b.PERC ACUTE CARE BY EXT SOURCES'
   V11344  = 'F10c.# EXT SOURCES ACUTE HIV CARE'
   V11345  = 'F10d.BASIS ACUTE HIV CARE PROVIDED'
   V11346  = 'F11.ANY CLI REC TB SCREENG:Y/N?'
   V11347  = 'F11a.PERC CLI REC TB SCRNG'
   V11348  = 'F11b.PERC TB SCRNG BY EXT SOURCES'
   V11349  = 'F11c.# EXT SOURCES TB SCRNG'
   V11350  = 'F11d.BASIS TB SCREENING PROVIDED'
   V11351  = 'F12.ANY CLI REC TB TREATMENT:Y/N?'
   V11352  = 'F12a.PERC CLI REC TB TX'
   V11353  = 'F12b.PERC TB TX BY EXT SOURCES'
   V11354  = 'F12c.# EXT SOURCES TB TX'
   V11355  = 'F12d.BASIS TB TX PROVIDED'
   V11356  = 'F13.ANY FEM CLI REC REPROD HC SV:Y/N?'
   V11357  = 'F14.ANY FEM CLI REC GYNECOL EXAM:Y/N?'
   V11358  = 'F14a.PERC FEM CLI REC GYNECOL EXAM'
   V11359  = 'F14b.PERC GYNECOL EXAM BY EXT SOURCES'
   V11360  = 'F14c.# EXT SOURCES GYNECOL EXAMS'
   V11361  = 'F14d.BASIS GYNECOL SVCS PROVIDED'
   V11362  = 'F15.ANY FEM CLI REC PREG TEST:Y/N?'
   V11363  = 'F15a.PERC FEM CLI REC PREG TEST'
   V11364  = 'F15b.PERC PREG TESTS BY EXT SOURCES'
   V11365  = 'F15c.# EXT SOURCES PROV PREG TESTS'
   V11366  = 'F15d.BASIS PREG TEST SVCES PROVIDED'
   V11367  = 'F16.ANY FEM CLI REC FAM PLNG:Y/N?'
   V11368  = 'F16a.PERC FEM CLI REC FAM PLNG'
   V11369  = 'F16b.PERC FAM PLANG BY EXT SOURCES'
   V11370  = 'F16c.# EXT SOURCES PROV FAM PLNG'
   V11371  = 'F16d.BASIS FAM PLNG SVCES PROVIDED'
   V11372  = 'F17.ANY FEM CLI REC PRENATAL CARE:Y/N?'
   V11373  = 'F17a.PERC FEM CLI REC PRE CARE'
   V11374  = 'F17b.PERC PRENATAL CARE BY EXT SRCES'
   V11375  = 'F17c.# EXT SOURCES PROV PRENATAL CARE'
   V11376  = 'F17d.BASIS PRENATAL CARE PROVIDED'
   V11377  = 'F18.ANY FEM CLI REC POSTPARTUM CR:Y/N?'
   V11378  = 'F18a.PERC FEM CLI REC POSTPARTUM'
   V11379  = 'F18b.PERC POSTPARTUM CARE BY EXT SRC'
   V11380  = 'F18c.# EXT SOURCES PROV POSTPARTUM'
   V11381  = 'F18d.BASIS POSTPARTUM PROVIDED'
   V11382  = 'F19.ANY CLI REC OTHER CLASSES:Y/N?'
   V11383  = 'F20.ANY CLI REC HEALTH EDUC:Y/N?'
   V11384  = 'F20a.PERC CLI REC HEALTH EDUC'
   V11385  = 'F20b.PERC HEALTH EDUC BY EXT SRCES'
   V11386  = 'F20c.# EXT SOURCES PROV HEALTH EDUC'
   V11387  = 'F20d.BASIS HEALTH EDUC PROVIDED'
   V11388  = 'F21.ANY CLI REC HIV PREV EDUC:Y/N?'
   V11389  = 'F21a.PERC CLI REC HIV PREV EDUC'
   V11390  = 'F21b.PERC HIV PREV EDUC BY EXT SRCES'
   V11391  = 'F21c.# EXT SOURCES PROV HIV PREV EDU'
   V11392  = 'F21d.BASIS HIV PREV EDU PROVIDED'
   V11393  = 'F22.ANY CLI REC PARENTING EDUC:Y/N?'
   V11394  = 'F22a.PERC CLI REC PARENTING EDU'
   V11395  = 'F22b.PERC PARENTING EDU BY EXT SRCES'
   V11396  = 'F22c.# EXT SOURCES PROV PARENTING EDU'
   V11397  = 'F22d.BASIS PARENTING EDUC PROVIDED'
   V11398  = 'F23.ANY CLI REC DOM VIOL COUNSLG:Y/N?'
   V11399  = 'F23a.PERC CLI REC DOM VIOL COUNSLG'
   V11400  = 'F23b.PERC DOM VIOL COUNSLG BY EXT SRC'
   V11401  = 'F23c.# EXT SOURCES PROV VIOL COUNSLG'
   V11402  = 'F23d.BASIS DOM VIOL COUNSLG PROVIDED'
   V11403  = 'F24.ANY CLI REC WOMENS ISSUES:Y/N?'
   V11404  = 'F24a.PERC CLI REC WOMEN ISSUES CLASSES'
   V11405  = 'F24b.PERC WOM ISSUES CLASSES BY EXT'
   V11406  = 'F24c.# EXT SOURCES PROV WOM ISSUES'
   V11407  = 'F24d.BASIS WOMEN ISSUES CLASSES PROV'
   V11408  = 'F25.ANY CLI REC COUNSELLING:Y/N?'
   V11409  = 'F26.ANY CLI REC EMPLOYMENT CNSL:Y/N?'
   V11410  = 'F26a.PERC CLI REC EMPLOY CNSL'
   V11411  = 'F26b.PERC EMPLOY CNSL BY EXT SRCES'
   V11412  = 'F26c.# EXT SRCES PROV EMPLOY COUSL'
   V11413  = 'F26d.BASIS EMPLOY CNSL PROVIDED'
   V11414  = 'F26e.PERC EMPLY CONSL VIA CONTRACT'
   V11415  = 'F27.ANY CLI REC LEGAL CNSL DV:Y/N?'
   V11416  = 'F27a.PERC CLI REC LEGAL CNSL DV'
   V11417  = 'F27b.PERC LEGAL CNSL DV BY EXT SRCES'
   V11418  = 'F27c.# EXT SRCES PROV LEGAL CNSL DV'
   V11419  = 'F27d.BASIS LEGAL CNSL DV PROVIDED'
   V11420  = 'F27e.PERC LEGAL CNSL DV VIA CONTRACT'
   V11421  = 'F28.ANY CLI REC LGAL CNSL CUSTODY:Y/N?'
   V11422  = 'F28a.PERC CLI REC LEGAL CUSTODY CNSL'
   V11423  = 'F28b.PERC CNSL BY EXT SOURCES'
   V11424  = 'F28c.# EXT SOURCES PROVI CUSTODY CNSL'
   V11425  = 'F28d.BASIS CUSTODY CNSLG PROVIDED'
   V11426  = 'F28e.PERC CUSTODY CNSL VIA CONTRACT'
   V11427  = 'F29.ANY CLI RECV LEG CNSL CRIME:Y/N?'
   V11428  = 'F29a.PERC CLI RECV LEG CNSL CRIME'
   V11429  = 'F29b.PERC CNSL BY EXT SOURCES'
   V11430  = 'F29c.# EXT SOURCES PROV CRIME CNSL'
   V11431  = 'F29d.BASIS CRIME CNSL PROVIDED'
   V11432  = 'F29e.PERC CRIME CNSL VIA CONTRACT'
   V11433  = 'F30.ANY CLI REC FINANCIAL CNSL:Y/N?'
   V11434  = 'F30a.PERC CLI RECV FIN COUNSL'
   V11435  = 'F30b.PERC CNSL BY EXT SOURCES'
   V11436  = 'F30c.# EXT SOURCES PROVI FIN CNSL'
   V11437  = 'F30d.BASIS FINANCL CNSL PROVIDED'
   V11438  = 'F30e.PERC FINANCL CNSL VIA CONTRACT'
   V11439  = 'F31.ANY CLI REC ENTITLEMENT AST:Y/N?'
   V11440  = 'F31a.PERC CLI REC ENTITLEMENT'
   V11441  = 'F31b.PERC SRVES BY EXT SOURCES'
   V11442  = 'F31c.# EXT SOURCES PROV ENTITLEMT AST'
   V11443  = 'F31d.BASIS ENTITLEMT ASSTCE PROVIDED'
   V11444  = 'F32.ANY CLI REC TRANSPORTN ASST:Y/N?'
   V11445  = 'F32a.PERC CLI REC TRANSPORTN ASSTNCE'
   V11446  = 'F32b.PERC TRANSPORTN SRVCES BY EXT'
   V11447  = 'F32c.# EXT SOURCES PROV TRANS SVES'
   V11448  = 'F32d.BASIS TRANSPORTN ASSTCE PROVIDED'
   V11449  = 'F33.ANY CLI RECV CHILD CARE:Y/N?'
   V11450  = 'F33a.PERC CLI RECV CHILD CARE'
   V11451  = 'F33b.PERC CHILD CARE PROV EXT SRCES'
   V11452  = 'F33c.# EXT SOURCES PROV CHILD CARE'
   V11453  = 'F33d.BASIS CHILD CARE SRVES PROVIDED'
   V11454  = 'F34.ANY CLI REC HOUSING ASSTNCE:Y/N?'
   V11455  = 'F34a.PERC CLI REC HOUSING ASSTNCE'
   V11456  = 'F34b.PERC HOUSING ASSTNCE BY EXT SRCES'
   V11457  = 'F34c.# EXT SOURCES PROV HOUSING ASST'
   V11458  = 'F34d.BASIS HOUSING ASSTNCE PROVIDED'
   V11459  = 'F35.ANY CLI REC CASE MANAGEMENT:Y/N?'
   V11460  = 'F35a.PERC CLI REC CASE MANAGEMENT'
   V11461  = 'F35b.CASE MANAGEMT FROM UNIT/OUTSIDE'
   V11462  = 'F36a.DEGR AGREE WOMEN NEED SPEC SRVS'
   V11463  = 'F36b.DEGR AGREE AFRAM NEED SPEC SRVS'
   V11464  = 'F36c.DEGR AGREE LATINOS ND SPEC SRVCS'
   V11465  = 'F37a.DEGR AGREE WOMEN ND WOMEN STAFF'
   V11466  = 'F37b.DEGR AGREE WOMEN ND SELF-ESTEEM'
   V11467  = 'F37c.DEGR AGREE WOMEN ND FAM MEMB INCL'
   V11468  = 'F37d.DEGR AGREE WOMEN ND NONCONTRONTNL'
   V11469  = 'F38a.DEGR AGREE AFRAM ND AFRAM STAFF'
   V11470  = 'F38b.DEGR AGREE AFRAM ND AFRAM HISTORY'
   V11471  = 'F38c.DEGR AGREE AFRAM ND AFRAM DIALECT'
   V11472  = 'F38d.DEGR AGREE AFRAM ND SELF-ESTEEM'
   V11473  = 'F38e.DEGR AGREE AFRAM ND FAM MEMB INCL'
   V11474  = 'F38f.DEGR AGREE AFRAM ND NONCONTRONTNL'
   V11475  = 'F39a.DEGR AGREE LATIN ND LATINO STAFF'
   V11476  = 'F39b.DEGR AGREE LATIN ND LATIN HISTORY'
   V11477  = 'F39c.DEGR AGREE LATIN ND LATIN LANGUAG'
   V11478  = 'F39d.DEGR AGREE LATIN ND SELF-ESTEEM'
   V11479  = 'F39e.DEGR AGREE LATIN ND FAM MAMB INCL'
   V11480  = 'F39f.DEGR AGREE LATIN ND NONCONFRONTL'
   V11481  = 'F40.AVG # MONTHS CLI IN OUTPT TX'
   V11482  = 'F41.# PEOPLE AWAITING TX CURRENTLY'
   V11483  = 'F41a.AVG # DAYS WAIT TO BEGIN TX'
   V11484  = 'F42.EXT 12 STEP EFFECTIVE WITH SA CLI'
   V11485  = 'F43.UNIT PARTICIPATES IN AA/NA:Y/N?'
   V11486  = 'F43a.EXT AA/NA USED BY CLI'
   V11487  = 'F44.PERC CLI WRITTEN AFTER TX PLAN'
   V11488  = 'F45.UNIT USES CHURCHES,ETC IN FU:Y/N?'
   V11489  = 'F46.UNIT SKS INPUT FR COMM LDERS:Y/N?'
   V11490  = 'F47a.AGREE ON ABSTIN AS GOAL OF TX'
   V11491  = 'F47b.AGREE ON RESP USE ALC/DRGS'
   V11492  = 'F47c.AGREE ON STEADY EMPYMENT GOAL'
   V11493  = 'F47d.AGREE ON POS PHYS HEALTH GOAL'
   V11494  = 'F47e.AGREE ON SPIRITUAL STRNGTH GOAL'
   V11495  = 'F47f.AGREE ON MEETG LEGAL REQ GOAL'
   V11496  = 'F47g.AGREE ON STAY OUT TROUBLE GOAL'
   V11497  = 'F47h.AGREE ON BECOME SELF-SUPPORTG'
   V11498  = 'F47j.AGREE ON REUNITE WITH FAMILIES'
   V11499  = 'F47k.AGREE ON STAY OFF STREETS'
   V11500  = 'F47l.AGREE ON RETAIN CUSTODY KIDS'
   V11501  = 'F48.EXT CLI HELP EST TX GOALS'
   V11502  = 'F49.HOW DIFF FOR CLI TO REACH STAFF'
   V11503  = 'F50a.PERC MONITOR W CASE RECORDS'
   V11504  = 'F50b.PERC MONITOR W CLI SELF-REPORTS'
   V11505  = 'F50c.PERC MONITOR W URINE TESTING'
   V11506  = 'F50d.PERC MONITOR W REPORTS BY SO'
   V11507  = 'F50e.PERC MONITOR W EVAL BY THERAPIST'
   V11508  = 'F50f.PERC MONITOR W REPRT BY EMPLOYER'
   V11509  = 'F50g.PERC MONITOR W LEGAL REPORT/RCRD'
   V11510  = 'F51.DOES UNIT HAVE FORMAL QAP:Y/N?'
   V11511  = 'F51a.EXT QAP BASED ON JCAHC STANDRS'
   V11512  = 'F52a.DET IF TX PLAN ALL IMPAIRMTS:Y/N?'
   V11513  = 'F52b.DET IF REFERRALS MADE:Y/N?'
   V11514  = 'F52c.DET IF CHANGE WHEN CLIN PROB:Y/N?'
   V11515  = 'F52d.DET IF TX TIME DEP CLI NEED:Y/N?'
   V11516  = 'F52e.DET IF DOCUMTN OF COMPLICTNS:Y/N?'
   V11517  = 'F52f.DET IF WRITTN DISCHARGE PLAN:Y/N?'
   V11518  = 'F52g.DET IF PATNT COMPLAINTS RESV:Y/N?'
   V11519  = 'F52h.DET IF TX PLANS ON MED PROBS:Y/N?'
   V11520  = 'F52i.DET IF TX PLANS ON MH PROBS:Y/N?'
   V11521  = 'F53a.PERC ENDED TX/COMPLTED TX'
   V11522  = 'F53b.PERC ENDED TX/FAILED COMPLY'
   V11523  = 'F53c.PERC ENDED TX/DROPPED OUT TX'
   V11524  = 'F53d.PERC ENDED TX/FREE SUBS ABUSE'
   V11525  = 'F53e.PERC ENDED TX/CONTROLLED USE'
   V11526  = 'F53f.PERC ENDED TX/CONTINUED USE'
   V11527  = 'F53g.PERC ENDED TX/FAILED PAY FOR TX'
   V11528  = 'F53h.PERC ENDED TX/EXHAUSTED INSURNCE'
   V11529  = 'F53i.PERC ENDED TX/TRANSFERRED OTHER'
   V11530  = 'F53j.PERC ENDED TX/MET GOALS OF TX'
   V11531  = 'F54.IN MRCFY ANY FEM CLI ENDED TX:Y/N?'
   V11532  = 'F55a.PERC FEM ENDED/COMPLETED TX'
   V11533  = 'F55b.PERC FEM ENDED/FAILED COMPLY'
   V11534  = 'F55c.PERC FEM ENDED/DROPPED OUT'
   V11535  = 'F55d.PERC FEM ENDED/FREE OF SUB ABUSE'
   V11536  = 'F55e.PERC FEM ENDED/CONTROLLED USE'
   V11537  = 'F55f.PERC FEM ENDED/CONTINUED USE'
   V11538  = 'F55g.PERC FEM ENDED/FAILED PAY TX'
   V11539  = 'F55h.PERC FEM ENDED/EXHAUSTED INSUR'
   V11540  = 'F55i.PERC FEM ENDED/TRANSFERED OTHER'
   V11541  = 'F55j.PERC FEM ENDED/MET GOALS OF TX'
   V11542  = 'F56.IN MRCFY ANY AA CLI ENDED TX:Y/N?'
   V11543  = 'F57a.PERC AA ENDED/COMPLETED TX'
   V11544  = 'F57b.PERC AA ENDED/FAILED COMPLY'
   V11545  = 'F57c.PERC AA ENDED/DROPPED OUT'
   V11546  = 'F57d.PERC AA ENDED/FREE OF SUB ABUSE'
   V11547  = 'F57e.PERC AA ENDED/CONTROLLED USE'
   V11548  = 'F57f.PERC AA ENDED/CONTINUED USE'
   V11549  = 'F57g.PERC AA ENDED/FAILED PAY TX'
   V11550  = 'F57h.PERC AA ENDED/EXHAUSTED INSUR'
   V11551  = 'F57i.PERC AA ENDED/TRANSFERED OTHER'
   V11552  = 'F57j.PERC AA ENDED/MET GOALS TO TX'
   V11553  = 'F58.IN MRCFY ANY LAT CLI ENDED TX:Y/N?'
   V11554  = 'F59a.PERC LAT ENDED/COMPLETED TX'
   V11555  = 'F59b.PERC LAT ENDED/FAILED COMPLY'
   V11556  = 'F59c.PERC LAT ENDED/DROPPED OUT'
   V11557  = 'F59d.PERC LAT ENDED/FREE OF SUB ABUSE'
   V11558  = 'F59e.PERC LAT ENDED/CONTROLLED USE'
   V11559  = 'F59f.PERC LAT ENDED/CONTINUED USE'
   V11560  = 'F59g.PERC LAT ENDED/FAILED PAY TX'
   V11561  = 'F59h.PERC LAT ENDED/EXHAUSTED INSUR'
   V11562  = 'F59i.PERC LAT ENDED/TRANSFERED OTHER'
   V11563  = 'F59j.PERC LAT ENDED/MET GOALS OF TX'
   V11564  = 'G1.# ALL INVOLUNTARY CLI IN MRCFY'
   V11565  = 'G2a.PERC CHARGED W DWI/DUI'
   V11566  = 'G2b.PERC CHARGED W DOMESTIC VIOLENCE'
   V11567  = 'G2c.PERC CHARGED W DRUNK/DISORDERLY'
   V11568  = 'G2d.PERC CHARGED W THEFT'
   V11569  = 'G2e.PERC CHARGED W POSSESSION DRUGS'
   V11570  = 'G2f.PERC CHARGED W DEALING DRUGS'
   V11571  = 'G2g1.OTHER OFFENCE, M1'
   V11572  = 'G2g1.PERC OTHER OFFENCE,M1'
   V11573  = 'G2g2.OTHER OFFENCE, M2'
   V11574  = 'G2g2.PERC OTHER OFFENCE, M2'
   V11575  = 'G2g3.OTHER OFFENCE,M3'
   V11576  = 'G2g3.PERC OTHER OFFENCE,M3'
   V11577  = 'G3.# FEMALE INVOLUNTARY CLIENTS MRCFY'
   V11578  = 'G4a.PERC CHARGED W DWI/DUI'
   V11579  = 'G4b.PERC CHARGED W DOMESTIC VIOLENCE'
   V11580  = 'G4c.PERC CHARGED W DRUNK/DISORDERLY'
   V11581  = 'G4d.PERC CHARGED W THEFT'
   V11582  = 'G4e.PERC CHARGED W POSSESSION DRUGS'
   V11583  = 'G4f.PERC CHARGED W DEALING DRUGS'
   V11584  = 'G4g.OTHER OFFENCE, M1'
   V11585  = 'G4g.PERC OTHER OFFENCE, M1'
   V11586  = 'G4g.OTHER OFFENCE, M2'
   V11587  = 'G4g.PERC OTHER OFFENCE, M2'
   V11588  = 'G4g.OTHER OFFENCE, M3'
   V11589  = 'G4g.PERC OTHER OFFENCE, M3'
   V11590  = 'G5.# INVOLUNTARY AFRIC-AM CLI MRCFY'
   V11591  = 'G6a.PERC CHARGED W DWI/DUI'
   V11592  = 'G6b.PERC CHARGED W DOMESTIC VIOLENCE'
   V11593  = 'G6c.PERC CHARGED W DRUNK/DISORDERLY'
   V11594  = 'G6d.PERC CHARGED W THEFT'
   V11595  = 'G6e.PERC CHARGED W POSSESSION DRUGS'
   V11596  = 'G6f.PERC CHARGED W DEALING DRUGS'
   V11597  = 'G6g.OTHER OFFENCE, M1'
   V11598  = 'G6g.PERC OTHER OFFENCE, M1'
   V11599  = 'G6g.OTHER OFFENCE, M2'
   V11600  = 'G6g.PERC OTHER OFFENCE, M2'
   V11601  = 'G6g.OTHER OFFENCE, M3'
   V11602  = 'G6g.PERC OTHER OFFENCE, M3'
   V11603  = 'G7.# INVOLUNTARY LATINO CLI MRCFY'
   V11604  = 'G8a.PERC CHARGED W DWI/DUI'
   V11605  = 'G8b.PERC CHARGED W DOMESTIC VIOLENCE'
   V11606  = 'G8b.PERC CHARGED W DRUNK/DISORDERLY'
   V11607  = 'G8c.PERC CHARGED W THEFT'
   V11608  = 'G8d.PERC CHARGED W POSSESSION DRUGS'
   V11609  = 'G8e.PERC CHARGED W DEALING DRUGS'
   V11610  = 'G8e.OTHER OFFENCE M1'
   V11611  = 'G8e.PERC OTHER OFFENCE M1'
   V11612  = 'G8e.OTHER OFFENCE M2'
   V11613  = 'G8e.PERC OTHER OFFENCE M2'
   V11614  = 'G8e.OTHER OFFENCE M3'
   V11615  = 'G8e.PERC OTHER OFFENCE M3'
   V11616  = 'G9.PERC INVOLUNTARY W ALCOHOL ABUSE'
   V11617  = 'G10.PERC INVOLUNTARY W DRUG ABUSE'
   V11618  = 'G11a.PERC INV ENDED TX/MET GOALS'
   V11619  = 'G11c.PERC INV ENDED TX/ABSTINENT'
   V11620  = 'G11d.PERC INV ENDED TX/REMANDED'
   V11621  = 'H0a.R COMPLETED DIRECTOR DEMOG:Y/N?'
   V11622  = 'H1.# YRS EMPLOYED BY THIS UNIT'
   V11623  = 'H1.# MOS EMPLOYED BY THIS UNIT'
   V11624  = 'H2.# YRS IN FIELD OF SA'
   V11625  = 'H2.# MOS IN FIELD OF SA'
   V11626  = 'H3.PRESENT JOB TITLE'
   V11627  = 'H3a.# YRS IN JOB'
   V11628  = 'H3a.# MOS IN JOB'
   V11629  = 'H4.# YRS OF AGE - CATEGORIZED'
   V11630  = 'H5. IS SUP R MALE OR FEMALE?'
   V11631  = 'H6. RACE OF R - RECODED'
   V11632  = 'H7. IS R OF HISPANIC ORIGIN:Y/N?'
   V11633  = 'H8.# HOURS/WEEK WORK TYPICALLY WORK'
   V11634  = 'H9a.# HRS/WK PROVIDE DIRECT THERAPY'
   V11635  = 'H9b.# HRS/WK SUPERVISE THERAPISTS'
   V11636  = 'H10.# YRS OF HIGHEST GRADE OF EDUC'
   V11637  = 'H10a. RECVD HI SCHL DIPLOMA/GED:Y/N?'
   V11638  = 'H10b. RECVD COLLEGE DEGRE:Y/N?'
   V11639  = 'H10c. DEGREE RECVD M1'
   V11640  = 'H10d. FIELD OF DEGREE M1'
   V11641  = 'H10c. DEGREE RECVD M2'
   V11642  = 'H10d. FIELD OF DEGREE M2'
   V11643  = 'H10c. DEGREE RECVD M3'
   V11644  = 'H10d. FIELD OF DEGREE M3'
   V11645  = 'H10c. DEGREE RECVD M4'
   V11646  = 'H10d. FIELD OF DEGREE M4'
   V11647  = 'H11. HAVE LIC/CERTIF AS SA COUN:Y/N?'
   WGTCODA4= 'WAVE4 CENTERED WEIGHT MEAN = 1.0'
   WGTTODA4= 'WAVE4 TRIMMED WEIGHT SUMMED TO 3266.927'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V10004 >= -5 AND V10004 <= -1) THEN V10004 = .;
   IF (V10005 >= -5 AND V10005 <= -1) THEN V10005 = .;
   IF (V10006 >= -5 AND V10006 <= -1) THEN V10006 = .;
   IF (V10007 >= -5 AND V10007 <= -1) THEN V10007 = .;
   IF (V10008 >= -5 AND V10008 <= -1) THEN V10008 = .;
   IF (V10009 >= -5 AND V10009 <= -1) THEN V10009 = .;
   IF (V10010 >= -5 AND V10010 <= -1) THEN V10010 = .;
   IF (V10011 >= -5 AND V10011 <= -1) THEN V10011 = .;
   IF (V10012 >= -5 AND V10012 <= -1) THEN V10012 = .;
   IF (V10013 >= -5 AND V10013 <= -1) THEN V10013 = .;
   IF (V10014 >= -5 AND V10014 <= -1) THEN V10014 = .;
   IF (V10015 >= -5 AND V10015 <= -1) THEN V10015 = .;
   IF (V10016 >= -5 AND V10016 <= -1) THEN V10016 = .;
   IF (V10017 >= -5 AND V10017 <= -1) THEN V10017 = .;
   IF (V10018 >= -5 AND V10018 <= -1) THEN V10018 = .;
   IF (V10019 >= -5 AND V10019 <= -1) THEN V10019 = .;
   IF (V10020 >= -5 AND V10020 <= -1) THEN V10020 = .;
   IF (V10021 >= -5 AND V10021 <= -1) THEN V10021 = .;
   IF (V10022 >= -5 AND V10022 <= -1) THEN V10022 = .;
   IF (V10023 >= -5 AND V10023 <= -1) THEN V10023 = .;
   IF (V10024 >= -5 AND V10024 <= -1) THEN V10024 = .;
   IF (V10025 >= -5 AND V10025 <= -1) THEN V10025 = .;
   IF (V10026 >= -5 AND V10026 <= -1) THEN V10026 = .;
   IF (V10027 >= -5 AND V10027 <= -1) THEN V10027 = .;
   IF (V10028 >= -5 AND V10028 <= -1) THEN V10028 = .;
   IF (V10029 >= -5 AND V10029 <= -1) THEN V10029 = .;
   IF (V10030 >= -5 AND V10030 <= -1) THEN V10030 = .;
   IF (V10031 >= -5 AND V10031 <= -1) THEN V10031 = .;
   IF (V10032 >= -5 AND V10032 <= -1) THEN V10032 = .;
   IF (V10033 >= -5 AND V10033 <= -1) THEN V10033 = .;
   IF (V10034 >= -5 AND V10034 <= -1) THEN V10034 = .;
   IF (V10035 >= -5 AND V10035 <= -1) THEN V10035 = .;
   IF (V10036 >= -5 AND V10036 <= -1) THEN V10036 = .;
   IF (V10037 >= -5 AND V10037 <= -1) THEN V10037 = .;
   IF (V10038 >= -5 AND V10038 <= -1) THEN V10038 = .;
   IF (V10039 >= -5 AND V10039 <= -1) THEN V10039 = .;
   IF (V10040 >= -5 AND V10040 <= -1) THEN V10040 = .;
   IF (V10041 >= -5 AND V10041 <= -1) THEN V10041 = .;
   IF (V10042 >= -5 AND V10042 <= -1) THEN V10042 = .;
   IF (V10043 >= -5 AND V10043 <= -1) THEN V10043 = .;
   IF (V10044 >= -5 AND V10044 <= -1) THEN V10044 = .;
   IF (V10045 >= -5 AND V10045 <= -1) THEN V10045 = .;
   IF (V10046 >= -5 AND V10046 <= -1) THEN V10046 = .;
   IF (V10047 >= -5 AND V10047 <= -1) THEN V10047 = .;
   IF (V10048 >= -5 AND V10048 <= -1) THEN V10048 = .;
   IF (V10049 >= -5 AND V10049 <= -1) THEN V10049 = .;
   IF (V10050 >= -5 AND V10050 <= -1) THEN V10050 = .;
   IF (V10051 >= -5 AND V10051 <= -1) THEN V10051 = .;
   IF (V10052 >= -5 AND V10052 <= -1) THEN V10052 = .;
   IF (V10053 >= -5 AND V10053 <= -1) THEN V10053 = .;
   IF (V10054 >= -5 AND V10054 <= -1) THEN V10054 = .;
   IF (V10055 >= -5 AND V10055 <= -1) THEN V10055 = .;
   IF (V10056 >= -5 AND V10056 <= -1) THEN V10056 = .;
   IF (V10057 >= -5 AND V10057 <= -1) THEN V10057 = .;
   IF (V10058 >= -5 AND V10058 <= -1) THEN V10058 = .;
   IF (V10059 >= -5 AND V10059 <= -1) THEN V10059 = .;
   IF (V10060 >= -5 AND V10060 <= -1) THEN V10060 = .;
   IF (V10061 >= -5 AND V10061 <= -1) THEN V10061 = .;
   IF (V10062 >= -5 AND V10062 <= -1) THEN V10062 = .;
   IF (V10063 >= -5 AND V10063 <= -1) THEN V10063 = .;
   IF (V10064 >= -5 AND V10064 <= -1) THEN V10064 = .;
   IF (V10065 >= -5 AND V10065 <= -1) THEN V10065 = .;
   IF (V10066 >= -5 AND V10066 <= -1) THEN V10066 = .;
   IF (V10067 >= -5 AND V10067 <= -1) THEN V10067 = .;
   IF (V10068 >= -5 AND V10068 <= -1) THEN V10068 = .;
   IF (V10069 >= -5 AND V10069 <= -1) THEN V10069 = .;
   IF (V10070 >= -5 AND V10070 <= -1) THEN V10070 = .;
   IF (V10071 >= -5 AND V10071 <= -1) THEN V10071 = .;
   IF (V10072 >= -5 AND V10072 <= -1) THEN V10072 = .;
   IF (V10073 >= -5 AND V10073 <= -1) THEN V10073 = .;
   IF (V10074 >= -5 AND V10074 <= -1) THEN V10074 = .;
   IF (V10075 >= -5 AND V10075 <= -1) THEN V10075 = .;
   IF (V10076 >= -5 AND V10076 <= -1) THEN V10076 = .;
   IF (V10077 >= -5 AND V10077 <= -1) THEN V10077 = .;
   IF (V10078 >= -5 AND V10078 <= -1) THEN V10078 = .;
   IF (V10079 >= -5 AND V10079 <= -1) THEN V10079 = .;
   IF (V10080 >= -5 AND V10080 <= -1) THEN V10080 = .;
   IF (V10081 >= -5 AND V10081 <= -1) THEN V10081 = .;
   IF (V10082 >= -5 AND V10082 <= -1) THEN V10082 = .;
   IF (V10083 >= -5 AND V10083 <= -1) THEN V10083 = .;
   IF (V10084 >= -5 AND V10084 <= -1) THEN V10084 = .;
   IF (V10085 >= -5 AND V10085 <= -1) THEN V10085 = .;
   IF (V10086 >= -5 AND V10086 <= -1) THEN V10086 = .;
   IF (V10087 >= -5 AND V10087 <= -1) THEN V10087 = .;
   IF (V10088 >= -5 AND V10088 <= -1) THEN V10088 = .;
   IF (V10089 >= -5 AND V10089 <= -1) THEN V10089 = .;
   IF (V10090 >= -5 AND V10090 <= -1) THEN V10090 = .;
   IF (V10091 >= -5 AND V10091 <= -1) THEN V10091 = .;
   IF (V10092 >= -5 AND V10092 <= -1) THEN V10092 = .;
   IF (V10093 >= -5 AND V10093 <= -1) THEN V10093 = .;
   IF (V10094 >= -5 AND V10094 <= -1) THEN V10094 = .;
   IF (V10095 >= -5 AND V10095 <= -1) THEN V10095 = .;
   IF (V10096 >= -5 AND V10096 <= -1) THEN V10096 = .;
   IF (V10097 >= -5 AND V10097 <= -1) THEN V10097 = .;
   IF (V10098 >= -5 AND V10098 <= -1) THEN V10098 = .;
   IF (V10099 >= -5 AND V10099 <= -1) THEN V10099 = .;
   IF (V10100 >= -5 AND V10100 <= -1) THEN V10100 = .;
   IF (V10101 >= -5 AND V10101 <= -1) THEN V10101 = .;
   IF (V10102 >= -5 AND V10102 <= -1) THEN V10102 = .;
   IF (V10103 >= -5 AND V10103 <= -1) THEN V10103 = .;
   IF (V10104 >= -5 AND V10104 <= -1) THEN V10104 = .;
   IF (V10105 >= -5 AND V10105 <= -1) THEN V10105 = .;
   IF (V10106 >= -5 AND V10106 <= -1) THEN V10106 = .;
   IF (V10107 >= -5 AND V10107 <= -1) THEN V10107 = .;
   IF (V10108 >= -5 AND V10108 <= -1) THEN V10108 = .;
   IF (V10109 >= -5 AND V10109 <= -1) THEN V10109 = .;
   IF (V10110 >= -5 AND V10110 <= -1) THEN V10110 = .;
   IF (V10111 >= -5 AND V10111 <= -1) THEN V10111 = .;
   IF (V10112 >= -5 AND V10112 <= -1) THEN V10112 = .;
   IF (V10113 >= -5 AND V10113 <= -1) THEN V10113 = .;
   IF (V10114 >= -5 AND V10114 <= -1) THEN V10114 = .;
   IF (V10115 >= -5 AND V10115 <= -1) THEN V10115 = .;
   IF (V10116 >= -5 AND V10116 <= -1) THEN V10116 = .;
   IF (V10117 >= -5 AND V10117 <= -1) THEN V10117 = .;
   IF (V10118 >= -5 AND V10118 <= -1) THEN V10118 = .;
   IF (V10119 >= -5 AND V10119 <= -1) THEN V10119 = .;
   IF (V10120 >= -5 AND V10120 <= -1) THEN V10120 = .;
   IF (V10121 >= -5 AND V10121 <= -1) THEN V10121 = .;
   IF (V10122 >= -5 AND V10122 <= -1) THEN V10122 = .;
   IF (V10123 >= -5 AND V10123 <= -1) THEN V10123 = .;
   IF (V10124 >= -5 AND V10124 <= -1) THEN V10124 = .;
   IF (V10125 >= -5 AND V10125 <= -1) THEN V10125 = .;
   IF (V10126 >= -5 AND V10126 <= -1) THEN V10126 = .;
   IF (V10127 >= -5 AND V10127 <= -1) THEN V10127 = .;
   IF (V10128 >= -5 AND V10128 <= -1) THEN V10128 = .;
   IF (V10129 >= -5 AND V10129 <= -1) THEN V10129 = .;
   IF (V10130 >= -5 AND V10130 <= -1) THEN V10130 = .;
   IF (V10131 >= -5 AND V10131 <= -1) THEN V10131 = .;
   IF (V10132 >= -5 AND V10132 <= -1) THEN V10132 = .;
   IF (V10133 >= -5 AND V10133 <= -1) THEN V10133 = .;
   IF (V10134 >= -5 AND V10134 <= -1) THEN V10134 = .;
   IF (V10135 >= -5 AND V10135 <= -1) THEN V10135 = .;
   IF (V10136 >= -5 AND V10136 <= -1) THEN V10136 = .;
   IF (V10137 >= -5 AND V10137 <= -1) THEN V10137 = .;
   IF (V10138 >= -5 AND V10138 <= -1) THEN V10138 = .;
   IF (V10139 >= -5 AND V10139 <= -1) THEN V10139 = .;
   IF (V10140 >= -5 AND V10140 <= -1) THEN V10140 = .;
   IF (V10141 >= -5 AND V10141 <= -1) THEN V10141 = .;
   IF (V10142 >= -5 AND V10142 <= -1) THEN V10142 = .;
   IF (V10143 >= -5 AND V10143 <= -1) THEN V10143 = .;
   IF (V10144 >= -5 AND V10144 <= -1) THEN V10144 = .;
   IF (V10145 >= -5 AND V10145 <= -1) THEN V10145 = .;
   IF (V10146 >= -5 AND V10146 <= -1) THEN V10146 = .;
   IF (V10147 >= -5 AND V10147 <= -1) THEN V10147 = .;
   IF (V10148 >= -5 AND V10148 <= -1) THEN V10148 = .;
   IF (V10149 >= -5 AND V10149 <= -1) THEN V10149 = .;
   IF (V10150 >= -5 AND V10150 <= -1) THEN V10150 = .;
   IF (V10151 >= -5 AND V10151 <= -1) THEN V10151 = .;
   IF (V10152 >= -5 AND V10152 <= -1) THEN V10152 = .;
   IF (V10153 >= -5 AND V10153 <= -1) THEN V10153 = .;
   IF (V10154 >= -5 AND V10154 <= -1) THEN V10154 = .;
   IF (V10155 >= -5 AND V10155 <= -1) THEN V10155 = .;
   IF (V10156 >= -5 AND V10156 <= -1) THEN V10156 = .;
   IF (V10157 >= -5 AND V10157 <= -1) THEN V10157 = .;
   IF (V10158 >= -5 AND V10158 <= -1) THEN V10158 = .;
   IF (V10159 >= -5 AND V10159 <= -1) THEN V10159 = .;
   IF (V10160 >= -5 AND V10160 <= -1) THEN V10160 = .;
   IF (V10161 >= -5 AND V10161 <= -1) THEN V10161 = .;
   IF (V10162 >= -5 AND V10162 <= -1) THEN V10162 = .;
   IF (V10163 >= -5 AND V10163 <= -1) THEN V10163 = .;
   IF (V10164 >= -5 AND V10164 <= -1) THEN V10164 = .;
   IF (V10165 >= -5 AND V10165 <= -1) THEN V10165 = .;
   IF (V10166 >= -5 AND V10166 <= -1) THEN V10166 = .;
   IF (V10167 >= -5 AND V10167 <= -1) THEN V10167 = .;
   IF (V10168 >= -5 AND V10168 <= -1) THEN V10168 = .;
   IF (V10169 >= -5 AND V10169 <= -1) THEN V10169 = .;
   IF (V10170 >= -5 AND V10170 <= -1) THEN V10170 = .;
   IF (V10171 >= -5 AND V10171 <= -1) THEN V10171 = .;
   IF (V10172 >= -5 AND V10172 <= -1) THEN V10172 = .;
   IF (V10173 >= -5 AND V10173 <= -1) THEN V10173 = .;
   IF (V10174 >= -5 AND V10174 <= -1) THEN V10174 = .;
   IF (V10175 >= -5 AND V10175 <= -1) THEN V10175 = .;
   IF (V10176 >= -5 AND V10176 <= -1) THEN V10176 = .;
   IF (V10177 >= -5 AND V10177 <= -1) THEN V10177 = .;
   IF (V10178 >= -5 AND V10178 <= -1) THEN V10178 = .;
   IF (V10179 >= -5 AND V10179 <= -1) THEN V10179 = .;
   IF (V10180 >= -5 AND V10180 <= -1) THEN V10180 = .;
   IF (V10181 >= -5 AND V10181 <= -1) THEN V10181 = .;
   IF (V10182 >= -5 AND V10182 <= -1) THEN V10182 = .;
   IF (V10183 >= -5 AND V10183 <= -1) THEN V10183 = .;
   IF (V10184 >= -5 AND V10184 <= -1) THEN V10184 = .;
   IF (V10185 >= -5 AND V10185 <= -1) THEN V10185 = .;
   IF (V10186 >= -5 AND V10186 <= -1) THEN V10186 = .;
   IF (V10187 >= -5 AND V10187 <= -1) THEN V10187 = .;
   IF (V10188 >= -5 AND V10188 <= -1) THEN V10188 = .;
   IF (V10189 >= -5 AND V10189 <= -1) THEN V10189 = .;
   IF (V10190 >= -5 AND V10190 <= -1) THEN V10190 = .;
   IF (V10191 >= -5 AND V10191 <= -1) THEN V10191 = .;
   IF (V10192 >= -5 AND V10192 <= -1) THEN V10192 = .;
   IF (V10193 >= -5 AND V10193 <= -1) THEN V10193 = .;
   IF (V10194 >= -5 AND V10194 <= -1) THEN V10194 = .;
   IF (V10195 >= -5 AND V10195 <= -1) THEN V10195 = .;
   IF (V10196 >= -5 AND V10196 <= -1) THEN V10196 = .;
   IF (V10197 >= -5 AND V10197 <= -1) THEN V10197 = .;
   IF (V10198 >= -5 AND V10198 <= -1) THEN V10198 = .;
   IF (V10199 >= -5 AND V10199 <= -1) THEN V10199 = .;
   IF (V10200 >= -5 AND V10200 <= -1) THEN V10200 = .;
   IF (V10201 >= -5 AND V10201 <= -1) THEN V10201 = .;
   IF (V10202 >= -5 AND V10202 <= -1) THEN V10202 = .;
   IF (V10203 >= -5 AND V10203 <= -1) THEN V10203 = .;
   IF (V10204 >= -5 AND V10204 <= -1) THEN V10204 = .;
   IF (V10205 >= -5 AND V10205 <= -1) THEN V10205 = .;
   IF (V10206 >= -5 AND V10206 <= -1) THEN V10206 = .;
   IF (V10207 >= -5 AND V10207 <= -1) THEN V10207 = .;
   IF (V10208 >= -5 AND V10208 <= -1) THEN V10208 = .;
   IF (V10209 >= -5 AND V10209 <= -1) THEN V10209 = .;
   IF (V10210 >= -5 AND V10210 <= -1) THEN V10210 = .;
   IF (V10211 >= -5 AND V10211 <= -1) THEN V10211 = .;
   IF (V10212 >= -5 AND V10212 <= -1) THEN V10212 = .;
   IF (V10213 >= -5 AND V10213 <= -1) THEN V10213 = .;
   IF (V10214 >= -5 AND V10214 <= -1) THEN V10214 = .;
   IF (V10215 >= -5 AND V10215 <= -1) THEN V10215 = .;
   IF (V10216 >= -5 AND V10216 <= -1) THEN V10216 = .;
   IF (V10217 >= -5 AND V10217 <= -1) THEN V10217 = .;
   IF (V10218 >= -5 AND V10218 <= -1) THEN V10218 = .;
   IF (V10219 >= -5 AND V10219 <= -1) THEN V10219 = .;
   IF (V10220 >= -5 AND V10220 <= -1) THEN V10220 = .;
   IF (V10221 >= -5 AND V10221 <= -1) THEN V10221 = .;
   IF (V10222 >= -5 AND V10222 <= -1) THEN V10222 = .;
   IF (V10223 >= -5 AND V10223 <= -1) THEN V10223 = .;
   IF (V10224 >= -5 AND V10224 <= -1) THEN V10224 = .;
   IF (V10225 >= -5 AND V10225 <= -1) THEN V10225 = .;
   IF (V10226 >= -5 AND V10226 <= -1) THEN V10226 = .;
   IF (V10227 >= -5 AND V10227 <= -1) THEN V10227 = .;
   IF (V10228 >= -5 AND V10228 <= -1) THEN V10228 = .;
   IF (V10229 >= -5 AND V10229 <= -1) THEN V10229 = .;
   IF (V10230 >= -5 AND V10230 <= -1) THEN V10230 = .;
   IF (V10231 >= -5 AND V10231 <= -1) THEN V10231 = .;
   IF (V10232 >= -5 AND V10232 <= -1) THEN V10232 = .;
   IF (V10233 >= -5 AND V10233 <= -1) THEN V10233 = .;
   IF (V10234 >= -5 AND V10234 <= -1) THEN V10234 = .;
   IF (V10235 >= -5 AND V10235 <= -1) THEN V10235 = .;
   IF (V10236 >= -5 AND V10236 <= -1) THEN V10236 = .;
   IF (V10237 >= -5 AND V10237 <= -1) THEN V10237 = .;
   IF (V10238 >= -5 AND V10238 <= -1) THEN V10238 = .;
   IF (V10239 >= -5 AND V10239 <= -1) THEN V10239 = .;
   IF (V10240 >= -5 AND V10240 <= -1) THEN V10240 = .;
   IF (V10241 >= -5 AND V10241 <= -1) THEN V10241 = .;
   IF (V10242 >= -5 AND V10242 <= -1) THEN V10242 = .;
   IF (V10243 >= -5 AND V10243 <= -1) THEN V10243 = .;
   IF (V10244 >= -5 AND V10244 <= -1) THEN V10244 = .;
   IF (V10245 >= -5 AND V10245 <= -1) THEN V10245 = .;
   IF (V10246 >= -5 AND V10246 <= -1) THEN V10246 = .;
   IF (V10247 >= -5 AND V10247 <= -1) THEN V10247 = .;
   IF (V10248 >= -5 AND V10248 <= -1) THEN V10248 = .;
   IF (V10249 >= -5 AND V10249 <= -1) THEN V10249 = .;
   IF (V10250 >= -5 AND V10250 <= -1) THEN V10250 = .;
   IF (V10251 >= -5 AND V10251 <= -1) THEN V10251 = .;
   IF (V10252 >= -5 AND V10252 <= -1) THEN V10252 = .;
   IF (V10253 >= -5 AND V10253 <= -1) THEN V10253 = .;
   IF (V10254 >= -5 AND V10254 <= -1) THEN V10254 = .;
   IF (V10255 >= -5 AND V10255 <= -1) THEN V10255 = .;
   IF (V10256 >= -5 AND V10256 <= -1) THEN V10256 = .;
   IF (V10257 >= -5 AND V10257 <= -1) THEN V10257 = .;
   IF (V10258 >= -5 AND V10258 <= -1) THEN V10258 = .;
   IF (V10259 >= -5 AND V10259 <= -1) THEN V10259 = .;
   IF (V10260 >= -5 AND V10260 <= -1) THEN V10260 = .;
   IF (V10261 >= -5 AND V10261 <= -1) THEN V10261 = .;
   IF (V10262 >= -5 AND V10262 <= -1) THEN V10262 = .;
   IF (V10263 >= -5 AND V10263 <= -1) THEN V10263 = .;
   IF (V10264 >= -5 AND V10264 <= -1) THEN V10264 = .;
   IF (V10265 >= -5 AND V10265 <= -1) THEN V10265 = .;
   IF (V10266 >= -5 AND V10266 <= -1) THEN V10266 = .;
   IF (V10267 >= -5 AND V10267 <= -1) THEN V10267 = .;
   IF (V10268 >= -5 AND V10268 <= -1) THEN V10268 = .;
   IF (V10269 >= -5 AND V10269 <= -1) THEN V10269 = .;
   IF (V10270 >= -5 AND V10270 <= -1) THEN V10270 = .;
   IF (V10271 >= -5 AND V10271 <= -1) THEN V10271 = .;
   IF (V10272 >= -5 AND V10272 <= -1) THEN V10272 = .;
   IF (V10273 >= -5 AND V10273 <= -1) THEN V10273 = .;
   IF (V10274 >= -5 AND V10274 <= -1) THEN V10274 = .;
   IF (V10275 >= -5 AND V10275 <= -1) THEN V10275 = .;
   IF (V10276 >= -5 AND V10276 <= -1) THEN V10276 = .;
   IF (V10277 >= -5 AND V10277 <= -1) THEN V10277 = .;
   IF (V10278 >= -5 AND V10278 <= -1) THEN V10278 = .;
   IF (V10279 >= -5 AND V10279 <= -1) THEN V10279 = .;
   IF (V10280 >= -5 AND V10280 <= -1) THEN V10280 = .;
   IF (V10281 >= -5 AND V10281 <= -1) THEN V10281 = .;
   IF (V10282 >= -5 AND V10282 <= -1) THEN V10282 = .;
   IF (V10283 >= -5 AND V10283 <= -1) THEN V10283 = .;
   IF (V10284 >= -5 AND V10284 <= -1) THEN V10284 = .;
   IF (V10285 >= -5 AND V10285 <= -1) THEN V10285 = .;
   IF (V10286 >= -5 AND V10286 <= -1) THEN V10286 = .;
   IF (V10287 >= -5 AND V10287 <= -1) THEN V10287 = .;
   IF (V10288 >= -5 AND V10288 <= -1) THEN V10288 = .;
   IF (V10289 >= -5 AND V10289 <= -1) THEN V10289 = .;
   IF (V10290 >= -5 AND V10290 <= -1) THEN V10290 = .;
   IF (V10291 >= -5 AND V10291 <= -1) THEN V10291 = .;
   IF (V10292 >= -5 AND V10292 <= -1) THEN V10292 = .;
   IF (V10293 >= -5 AND V10293 <= -1) THEN V10293 = .;
   IF (V10294 >= -5 AND V10294 <= -1) THEN V10294 = .;
   IF (V10295 >= -5 AND V10295 <= -1) THEN V10295 = .;
   IF (V10296 >= -5 AND V10296 <= -1) THEN V10296 = .;
   IF (V10297 >= -5 AND V10297 <= -1) THEN V10297 = .;
   IF (V10298 >= -5 AND V10298 <= -1) THEN V10298 = .;
   IF (V10299 >= -5 AND V10299 <= -1) THEN V10299 = .;
   IF (V10300 >= -5 AND V10300 <= -1) THEN V10300 = .;
   IF (V10301 >= -5 AND V10301 <= -1) THEN V10301 = .;
   IF (V10302 >= -5 AND V10302 <= -1) THEN V10302 = .;
   IF (V10303 >= -5 AND V10303 <= -1) THEN V10303 = .;
   IF (V10304 >= -5 AND V10304 <= -1) THEN V10304 = .;
   IF (V10305 >= -5 AND V10305 <= -1) THEN V10305 = .;
   IF (V10306 >= -5 AND V10306 <= -1) THEN V10306 = .;
   IF (V10307 >= -5 AND V10307 <= -1) THEN V10307 = .;
   IF (V10308 >= -5 AND V10308 <= -1) THEN V10308 = .;
   IF (V10309 >= -5 AND V10309 <= -1) THEN V10309 = .;
   IF (V10310 >= -5 AND V10310 <= -1) THEN V10310 = .;
   IF (V10311 >= -5 AND V10311 <= -1) THEN V10311 = .;
   IF (V10312 >= -5 AND V10312 <= -1) THEN V10312 = .;
   IF (V10313 >= -5 AND V10313 <= -1) THEN V10313 = .;
   IF (V10314 >= -5 AND V10314 <= -1) THEN V10314 = .;
   IF (V10315 >= -5 AND V10315 <= -1) THEN V10315 = .;
   IF (V10316 >= -5 AND V10316 <= -1) THEN V10316 = .;
   IF (V10317 >= -5 AND V10317 <= -1) THEN V10317 = .;
   IF (V10318 >= -5 AND V10318 <= -1) THEN V10318 = .;
   IF (V10319 >= -5 AND V10319 <= -1) THEN V10319 = .;
   IF (V10320 >= -5 AND V10320 <= -1) THEN V10320 = .;
   IF (V10321 >= -5 AND V10321 <= -1) THEN V10321 = .;
   IF (V10322 >= -5 AND V10322 <= -1) THEN V10322 = .;
   IF (V10323 >= -5 AND V10323 <= -1) THEN V10323 = .;
   IF (V10324 >= -5 AND V10324 <= -1) THEN V10324 = .;
   IF (V10325 >= -5 AND V10325 <= -1) THEN V10325 = .;
   IF (V10326 >= -5 AND V10326 <= -1) THEN V10326 = .;
   IF (V10327 >= -5 AND V10327 <= -1) THEN V10327 = .;
   IF (V10328 >= -5 AND V10328 <= -1) THEN V10328 = .;
   IF (V10329 >= -5 AND V10329 <= -1) THEN V10329 = .;
   IF (V10330 >= -5 AND V10330 <= -1) THEN V10330 = .;
   IF (V10331 >= -5 AND V10331 <= -1) THEN V10331 = .;
   IF (V10332 >= -5 AND V10332 <= -1) THEN V10332 = .;
   IF (V10333 >= -5 AND V10333 <= -1) THEN V10333 = .;
   IF (V10334 >= -5 AND V10334 <= -1) THEN V10334 = .;
   IF (V10335 >= -5 AND V10335 <= -1) THEN V10335 = .;
   IF (V10336 >= -5 AND V10336 <= -1) THEN V10336 = .;
   IF (V10337 >= -5 AND V10337 <= -1) THEN V10337 = .;
   IF (V10338 >= -5 AND V10338 <= -1) THEN V10338 = .;
   IF (V10339 >= -5 AND V10339 <= -1) THEN V10339 = .;
   IF (V10340 >= -5 AND V10340 <= -1) THEN V10340 = .;
   IF (V10341 >= -5 AND V10341 <= -1) THEN V10341 = .;
   IF (V10342 >= -5 AND V10342 <= -1) THEN V10342 = .;
   IF (V10343 >= -5 AND V10343 <= -1) THEN V10343 = .;
   IF (V10344 >= -5 AND V10344 <= -1) THEN V10344 = .;
   IF (V10345 >= -5 AND V10345 <= -1) THEN V10345 = .;
   IF (V10346 >= -5 AND V10346 <= -1) THEN V10346 = .;
   IF (V10347 >= -5 AND V10347 <= -1) THEN V10347 = .;
   IF (V10348 >= -5 AND V10348 <= -1) THEN V10348 = .;
   IF (V10349 >= -5 AND V10349 <= -1) THEN V10349 = .;
   IF (V10350 >= -5 AND V10350 <= -1) THEN V10350 = .;
   IF (V10351 >= -5 AND V10351 <= -1) THEN V10351 = .;
   IF (V10352 >= -5 AND V10352 <= -1) THEN V10352 = .;
   IF (V10353 >= -5 AND V10353 <= -1) THEN V10353 = .;
   IF (V10354 >= -5 AND V10354 <= -1) THEN V10354 = .;
   IF (V10355 >= -5 AND V10355 <= -1) THEN V10355 = .;
   IF (V10356 >= -5 AND V10356 <= -1) THEN V10356 = .;
   IF (V10357 >= -5 AND V10357 <= -1) THEN V10357 = .;
   IF (V10358 >= -5 AND V10358 <= -1) THEN V10358 = .;
   IF (V10359 >= -5 AND V10359 <= -1) THEN V10359 = .;
   IF (V10360 >= -5 AND V10360 <= -1) THEN V10360 = .;
   IF (V10361 >= -5 AND V10361 <= -1) THEN V10361 = .;
   IF (V10362 >= -5 AND V10362 <= -1) THEN V10362 = .;
   IF (V10363 >= -5 AND V10363 <= -1) THEN V10363 = .;
   IF (V10364 >= -5 AND V10364 <= -1) THEN V10364 = .;
   IF (V10365 >= -5 AND V10365 <= -1) THEN V10365 = .;
   IF (V10366 >= -5 AND V10366 <= -1) THEN V10366 = .;
   IF (V10367 >= -5 AND V10367 <= -1) THEN V10367 = .;
   IF (V10368 >= -5 AND V10368 <= -1) THEN V10368 = .;
   IF (V10369 >= -5 AND V10369 <= -1) THEN V10369 = .;
   IF (V10370 >= -5 AND V10370 <= -1) THEN V10370 = .;
   IF (V10371 >= -5 AND V10371 <= -1) THEN V10371 = .;
   IF (V10372 >= -5 AND V10372 <= -1) THEN V10372 = .;
   IF (V10373 >= -5 AND V10373 <= -1) THEN V10373 = .;
   IF (V10374 >= -5 AND V10374 <= -1) THEN V10374 = .;
   IF (V10375 >= -5 AND V10375 <= -1) THEN V10375 = .;
   IF (V10376 >= -5 AND V10376 <= -1) THEN V10376 = .;
   IF (V10377 >= -5 AND V10377 <= -1) THEN V10377 = .;
   IF (V10378 >= -5 AND V10378 <= -1) THEN V10378 = .;
   IF (V10379 >= -5 AND V10379 <= -1) THEN V10379 = .;
   IF (V10380 >= -5 AND V10380 <= -1) THEN V10380 = .;
   IF (V10381 >= -5 AND V10381 <= -1) THEN V10381 = .;
   IF (V10382 >= -5 AND V10382 <= -1) THEN V10382 = .;
   IF (V10383 >= -5 AND V10383 <= -1) THEN V10383 = .;
   IF (V10384 >= -5 AND V10384 <= -1) THEN V10384 = .;
   IF (V10385 >= -5 AND V10385 <= -1) THEN V10385 = .;
   IF (V10386 >= -5 AND V10386 <= -1) THEN V10386 = .;
   IF (V10387 >= -5 AND V10387 <= -1) THEN V10387 = .;
   IF (V10388 >= -5 AND V10388 <= -1) THEN V10388 = .;
   IF (V10389 >= -5 AND V10389 <= -1) THEN V10389 = .;
   IF (V10390 >= -5 AND V10390 <= -1) THEN V10390 = .;
   IF (V10391 >= -5 AND V10391 <= -1) THEN V10391 = .;
   IF (V10392 >= -5 AND V10392 <= -1) THEN V10392 = .;
   IF (V10393 >= -5 AND V10393 <= -1) THEN V10393 = .;
   IF (V10394 >= -5 AND V10394 <= -1) THEN V10394 = .;
   IF (V10395 >= -5 AND V10395 <= -1) THEN V10395 = .;
   IF (V10396 >= -5 AND V10396 <= -1) THEN V10396 = .;
   IF (V10397 >= -5 AND V10397 <= -1) THEN V10397 = .;
   IF (V10398 >= -5 AND V10398 <= -1) THEN V10398 = .;
   IF (V10399 >= -5 AND V10399 <= -1) THEN V10399 = .;
   IF (V10400 >= -5 AND V10400 <= -1) THEN V10400 = .;
   IF (V10401 >= -5 AND V10401 <= -1) THEN V10401 = .;
   IF (V10402 >= -5 AND V10402 <= -1) THEN V10402 = .;
   IF (V10403 >= -5 AND V10403 <= -1) THEN V10403 = .;
   IF (V10404 >= -5 AND V10404 <= -1) THEN V10404 = .;
   IF (V10405 >= -5 AND V10405 <= -1) THEN V10405 = .;
   IF (V10406 >= -5 AND V10406 <= -1) THEN V10406 = .;
   IF (V10407 >= -5 AND V10407 <= -1) THEN V10407 = .;
   IF (V10408 >= -5 AND V10408 <= -1) THEN V10408 = .;
   IF (V10409 >= -5 AND V10409 <= -1) THEN V10409 = .;
   IF (V10410 >= -5 AND V10410 <= -1) THEN V10410 = .;
   IF (V10411 >= -5 AND V10411 <= -1) THEN V10411 = .;
   IF (V10412 >= -5 AND V10412 <= -1) THEN V10412 = .;
   IF (V10413 >= -5 AND V10413 <= -1) THEN V10413 = .;
   IF (V10414 >= -5 AND V10414 <= -1) THEN V10414 = .;
   IF (V10415 >= -5 AND V10415 <= -1) THEN V10415 = .;
   IF (V10416 >= -5 AND V10416 <= -1) THEN V10416 = .;
   IF (V10417 >= -5 AND V10417 <= -1) THEN V10417 = .;
   IF (V10418 >= -5 AND V10418 <= -1) THEN V10418 = .;
   IF (V10419 >= -5 AND V10419 <= -1) THEN V10419 = .;
   IF (V10420 >= -5 AND V10420 <= -1) THEN V10420 = .;
   IF (V10421 >= -5 AND V10421 <= -1) THEN V10421 = .;
   IF (V10422 >= -5 AND V10422 <= -1) THEN V10422 = .;
   IF (V10423 >= -5 AND V10423 <= -1) THEN V10423 = .;
   IF (V10424 >= -5 AND V10424 <= -1) THEN V10424 = .;
   IF (V10425 >= -5 AND V10425 <= -1) THEN V10425 = .;
   IF (V10426 >= -5 AND V10426 <= -1) THEN V10426 = .;
   IF (V10427 >= -5 AND V10427 <= -1) THEN V10427 = .;
   IF (V10428 >= -5 AND V10428 <= -1) THEN V10428 = .;
   IF (V10429 >= -5 AND V10429 <= -1) THEN V10429 = .;
   IF (V10430 >= -5 AND V10430 <= -1) THEN V10430 = .;
   IF (V10431 >= -5 AND V10431 <= -1) THEN V10431 = .;
   IF (V10432 >= -5 AND V10432 <= -1) THEN V10432 = .;
   IF (V10433 >= -5 AND V10433 <= -1) THEN V10433 = .;
   IF (V10434 >= -5 AND V10434 <= -1) THEN V10434 = .;
   IF (V10435 >= -5 AND V10435 <= -1) THEN V10435 = .;
   IF (V10436 >= -5 AND V10436 <= -1) THEN V10436 = .;
   IF (V10437 >= -5 AND V10437 <= -1) THEN V10437 = .;
   IF (V10438 >= -5 AND V10438 <= -1) THEN V10438 = .;
   IF (V10439 >= -5 AND V10439 <= -1) THEN V10439 = .;
   IF (V10440 >= -5 AND V10440 <= -1) THEN V10440 = .;
   IF (V10441 >= -5 AND V10441 <= -1) THEN V10441 = .;
   IF (V10442 >= -5 AND V10442 <= -1) THEN V10442 = .;
   IF (V10443 >= -5 AND V10443 <= -1) THEN V10443 = .;
   IF (V10444 >= -5 AND V10444 <= -1) THEN V10444 = .;
   IF (V10445 >= -5 AND V10445 <= -1) THEN V10445 = .;
   IF (V10446 >= -5 AND V10446 <= -1) THEN V10446 = .;
   IF (V10447 >= -5 AND V10447 <= -1) THEN V10447 = .;
   IF (V10448 >= -5 AND V10448 <= -1) THEN V10448 = .;
   IF (V10449 >= -5 AND V10449 <= -1) THEN V10449 = .;
   IF (V10450 >= -5 AND V10450 <= -1) THEN V10450 = .;
   IF (V10451 >= -5 AND V10451 <= -1) THEN V10451 = .;
   IF (V10452 >= -5 AND V10452 <= -1) THEN V10452 = .;
   IF (V10453 >= -5 AND V10453 <= -1) THEN V10453 = .;
   IF (V10454 >= -5 AND V10454 <= -1) THEN V10454 = .;
   IF (V10455 >= -5 AND V10455 <= -1) THEN V10455 = .;
   IF (V10456 >= -5 AND V10456 <= -1) THEN V10456 = .;
   IF (V10457 >= -5 AND V10457 <= -1) THEN V10457 = .;
   IF (V10458 >= -5 AND V10458 <= -1) THEN V10458 = .;
   IF (V10459 >= -5 AND V10459 <= -1) THEN V10459 = .;
   IF (V10460 >= -5 AND V10460 <= -1) THEN V10460 = .;
   IF (V10461 >= -5 AND V10461 <= -1) THEN V10461 = .;
   IF (V10462 >= -5 AND V10462 <= -1) THEN V10462 = .;
   IF (V10463 >= -5 AND V10463 <= -1) THEN V10463 = .;
   IF (V10464 >= -5 AND V10464 <= -1) THEN V10464 = .;
   IF (V10465 >= -5 AND V10465 <= -1) THEN V10465 = .;
   IF (V10466 >= -5 AND V10466 <= -1) THEN V10466 = .;
   IF (V10467 >= -5 AND V10467 <= -1) THEN V10467 = .;
   IF (V10468 >= -5 AND V10468 <= -1) THEN V10468 = .;
   IF (V10469 >= -5 AND V10469 <= -1) THEN V10469 = .;
   IF (V10470 >= -5 AND V10470 <= -1) THEN V10470 = .;
   IF (V10471 >= -5 AND V10471 <= -1) THEN V10471 = .;
   IF (V10472 >= -5 AND V10472 <= -1) THEN V10472 = .;
   IF (V10473 >= -5 AND V10473 <= -1) THEN V10473 = .;
   IF (V10474 >= -5 AND V10474 <= -1) THEN V10474 = .;
   IF (V10475 >= -5 AND V10475 <= -1) THEN V10475 = .;
   IF (V10476 >= -5 AND V10476 <= -1) THEN V10476 = .;
   IF (V10477 >= -5 AND V10477 <= -1) THEN V10477 = .;
   IF (V10478 >= -5 AND V10478 <= -1) THEN V10478 = .;
   IF (V10479 >= -5 AND V10479 <= -1) THEN V10479 = .;
   IF (V10480 >= -5 AND V10480 <= -1) THEN V10480 = .;
   IF (V10481 >= -5 AND V10481 <= -1) THEN V10481 = .;
   IF (V10482 >= -5 AND V10482 <= -1) THEN V10482 = .;
   IF (V10483 >= -5 AND V10483 <= -1) THEN V10483 = .;
   IF (V10484 >= -5 AND V10484 <= -1) THEN V10484 = .;
   IF (V10485 >= -5 AND V10485 <= -1) THEN V10485 = .;
   IF (V10486 >= -5 AND V10486 <= -1) THEN V10486 = .;
   IF (V10487 >= -5 AND V10487 <= -1) THEN V10487 = .;
   IF (V10488 >= -5 AND V10488 <= -1) THEN V10488 = .;
   IF (V10489 >= -5 AND V10489 <= -1) THEN V10489 = .;
   IF (V10490 >= -5 AND V10490 <= -1) THEN V10490 = .;
   IF (V10491 >= -5 AND V10491 <= -1) THEN V10491 = .;
   IF (V10492 >= -5 AND V10492 <= -1) THEN V10492 = .;
   IF (V10493 >= -5 AND V10493 <= -1) THEN V10493 = .;
   IF (V10494 >= -5 AND V10494 <= -1) THEN V10494 = .;
   IF (V10495 >= -5 AND V10495 <= -1) THEN V10495 = .;
   IF (V10496 >= -5 AND V10496 <= -1) THEN V10496 = .;
   IF (V10497 >= -5 AND V10497 <= -1) THEN V10497 = .;
   IF (V10498 >= -5 AND V10498 <= -1) THEN V10498 = .;
   IF (V10499 >= -5 AND V10499 <= -1) THEN V10499 = .;
   IF (V10500 >= -5 AND V10500 <= -1) THEN V10500 = .;
   IF (V10501 >= -5 AND V10501 <= -1) THEN V10501 = .;
   IF (V10502 >= -5 AND V10502 <= -1) THEN V10502 = .;
   IF (V10503 >= -5 AND V10503 <= -1) THEN V10503 = .;
   IF (V10504 >= -5 AND V10504 <= -1) THEN V10504 = .;
   IF (V10505 >= -5 AND V10505 <= -1) THEN V10505 = .;
   IF (V10506 >= -5 AND V10506 <= -1) THEN V10506 = .;
   IF (V10507 >= -5 AND V10507 <= -1) THEN V10507 = .;
   IF (V10508 >= -5 AND V10508 <= -1) THEN V10508 = .;
   IF (V10509 >= -5 AND V10509 <= -1) THEN V10509 = .;
   IF (V10510 >= -5 AND V10510 <= -1) THEN V10510 = .;
   IF (V10511 >= -5 AND V10511 <= -1) THEN V10511 = .;
   IF (V10512 >= -5 AND V10512 <= -1) THEN V10512 = .;
   IF (V10513 >= -5 AND V10513 <= -1) THEN V10513 = .;
   IF (V10514 >= -5 AND V10514 <= -1) THEN V10514 = .;
   IF (V10515 >= -5 AND V10515 <= -1) THEN V10515 = .;
   IF (V10516 >= -5 AND V10516 <= -1) THEN V10516 = .;
   IF (V10517 >= -5 AND V10517 <= -1) THEN V10517 = .;
   IF (V10518 >= -5 AND V10518 <= -1) THEN V10518 = .;
   IF (V10519 >= -5 AND V10519 <= -1) THEN V10519 = .;
   IF (V10520 >= -5 AND V10520 <= -1) THEN V10520 = .;
   IF (V10521 >= -5 AND V10521 <= -1) THEN V10521 = .;
   IF (V10522 >= -5 AND V10522 <= -1) THEN V10522 = .;
   IF (V10523 >= -5 AND V10523 <= -1) THEN V10523 = .;
   IF (V10524 >= -5 AND V10524 <= -1) THEN V10524 = .;
   IF (V10525 >= -5 AND V10525 <= -1) THEN V10525 = .;
   IF (V10526 >= -5 AND V10526 <= -1) THEN V10526 = .;
   IF (V10527 >= -5 AND V10527 <= -1) THEN V10527 = .;
   IF (V10528 >= -5 AND V10528 <= -1) THEN V10528 = .;
   IF (V10529 >= -5 AND V10529 <= -1) THEN V10529 = .;
   IF (V10530 >= -5 AND V10530 <= -1) THEN V10530 = .;
   IF (V10531 >= -5 AND V10531 <= -1) THEN V10531 = .;
   IF (V10532 >= -5 AND V10532 <= -1) THEN V10532 = .;
   IF (V10533 >= -5 AND V10533 <= -1) THEN V10533 = .;
   IF (V10534 >= -5 AND V10534 <= -1) THEN V10534 = .;
   IF (V10535 >= -5 AND V10535 <= -1) THEN V10535 = .;
   IF (V10536 >= -5 AND V10536 <= -1) THEN V10536 = .;
   IF (V10537 >= -5 AND V10537 <= -1) THEN V10537 = .;
   IF (V10538 >= -5 AND V10538 <= -1) THEN V10538 = .;
   IF (V10539 >= -5 AND V10539 <= -1) THEN V10539 = .;
   IF (V10540 >= -5 AND V10540 <= -1) THEN V10540 = .;
   IF (V10541 >= -5 AND V10541 <= -1) THEN V10541 = .;
   IF (V10542 >= -5 AND V10542 <= -1) THEN V10542 = .;
   IF (V10543 >= -5 AND V10543 <= -1) THEN V10543 = .;
   IF (V10544 >= -5 AND V10544 <= -1) THEN V10544 = .;
   IF (V10545 >= -5 AND V10545 <= -1) THEN V10545 = .;
   IF (V10546 >= -5 AND V10546 <= -1) THEN V10546 = .;
   IF (V10547 >= -5 AND V10547 <= -1) THEN V10547 = .;
   IF (V10548 >= -5 AND V10548 <= -1) THEN V10548 = .;
   IF (V10549 >= -5 AND V10549 <= -1) THEN V10549 = .;
   IF (V10550 >= -5 AND V10550 <= -1) THEN V10550 = .;
   IF (V10551 >= -5 AND V10551 <= -1) THEN V10551 = .;
   IF (V10552 >= -5 AND V10552 <= -1) THEN V10552 = .;
   IF (V10553 >= -5 AND V10553 <= -1) THEN V10553 = .;
   IF (V10554 >= -5 AND V10554 <= -1) THEN V10554 = .;
   IF (V10555 >= -5 AND V10555 <= -1) THEN V10555 = .;
   IF (V10556 >= -5 AND V10556 <= -1) THEN V10556 = .;
   IF (V10557 >= -5 AND V10557 <= -1) THEN V10557 = .;
   IF (V11004 >= -5 AND V11004 <= -1) THEN V11004 = .;
   IF (V11005 >= -5 AND V11005 <= -1) THEN V11005 = .;
   IF (V11006 >= -5 AND V11006 <= -1) THEN V11006 = .;
   IF (V11007 >= -5 AND V11007 <= -1) THEN V11007 = .;
   IF (V11008 >= -5 AND V11008 <= -1) THEN V11008 = .;
   IF (V11009 >= -5 AND V11009 <= -1) THEN V11009 = .;
   IF (V11010 >= -5 AND V11010 <= -1) THEN V11010 = .;
   IF (V11011 >= -5 AND V11011 <= -1) THEN V11011 = .;
   IF (V11012 >= -5 AND V11012 <= -1) THEN V11012 = .;
   IF (V11013 >= -5 AND V11013 <= -1) THEN V11013 = .;
   IF (V11014 >= -5 AND V11014 <= -1) THEN V11014 = .;
   IF (V11015 >= -5 AND V11015 <= -1) THEN V11015 = .;
   IF (V11016 >= -5 AND V11016 <= -1) THEN V11016 = .;
   IF (V11017 >= -5 AND V11017 <= -1) THEN V11017 = .;
   IF (V11018 >= -5 AND V11018 <= -1) THEN V11018 = .;
   IF (V11019 >= -5 AND V11019 <= -1) THEN V11019 = .;
   IF (V11020 >= -5 AND V11020 <= -1) THEN V11020 = .;
   IF (V11021 >= -5 AND V11021 <= -1) THEN V11021 = .;
   IF (V11022 >= -5 AND V11022 <= -1) THEN V11022 = .;
   IF (V11023 >= -5 AND V11023 <= -1) THEN V11023 = .;
   IF (V11024 >= -5 AND V11024 <= -1) THEN V11024 = .;
   IF (V11025 >= -5 AND V11025 <= -1) THEN V11025 = .;
   IF (V11026 >= -5 AND V11026 <= -1) THEN V11026 = .;
   IF (V11027 >= -5 AND V11027 <= -1) THEN V11027 = .;
   IF (V11028 >= -5 AND V11028 <= -1) THEN V11028 = .;
   IF (V11029 >= -5 AND V11029 <= -1) THEN V11029 = .;
   IF (V11030 >= -5 AND V11030 <= -1) THEN V11030 = .;
   IF (V11031 >= -5 AND V11031 <= -1) THEN V11031 = .;
   IF (V11032 >= -5 AND V11032 <= -1) THEN V11032 = .;
   IF (V11033 >= -5 AND V11033 <= -1) THEN V11033 = .;
   IF (V11034 >= -5 AND V11034 <= -1) THEN V11034 = .;
   IF (V11035 >= -5 AND V11035 <= -1) THEN V11035 = .;
   IF (V11036 >= -5 AND V11036 <= -1) THEN V11036 = .;
   IF (V11037 >= -5 AND V11037 <= -1) THEN V11037 = .;
   IF (V11038 >= -5 AND V11038 <= -1) THEN V11038 = .;
   IF (V11039 >= -5 AND V11039 <= -1) THEN V11039 = .;
   IF (V11040 >= -5 AND V11040 <= -1) THEN V11040 = .;
   IF (V11041 >= -5 AND V11041 <= -1) THEN V11041 = .;
   IF (V11042 >= -5 AND V11042 <= -1) THEN V11042 = .;
   IF (V11043 >= -5 AND V11043 <= -1) THEN V11043 = .;
   IF (V11044 >= -5 AND V11044 <= -1) THEN V11044 = .;
   IF (V11045 >= -5 AND V11045 <= -1) THEN V11045 = .;
   IF (V11046 >= -5 AND V11046 <= -1) THEN V11046 = .;
   IF (V11047 >= -5 AND V11047 <= -1) THEN V11047 = .;
   IF (V11048 >= -5 AND V11048 <= -1) THEN V11048 = .;
   IF (V11049 >= -5 AND V11049 <= -1) THEN V11049 = .;
   IF (V11050 >= -5 AND V11050 <= -1) THEN V11050 = .;
   IF (V11051 >= -5 AND V11051 <= -1) THEN V11051 = .;
   IF (V11052 >= -5 AND V11052 <= -1) THEN V11052 = .;
   IF (V11053 >= -5 AND V11053 <= -1) THEN V11053 = .;
   IF (V11054 >= -5 AND V11054 <= -1) THEN V11054 = .;
   IF (V11055 >= -5 AND V11055 <= -1) THEN V11055 = .;
   IF (V11056 >= -5 AND V11056 <= -1) THEN V11056 = .;
   IF (V11057 >= -5 AND V11057 <= -1) THEN V11057 = .;
   IF (V11058 >= -5 AND V11058 <= -1) THEN V11058 = .;
   IF (V11059 >= -5 AND V11059 <= -1) THEN V11059 = .;
   IF (V11060 >= -5 AND V11060 <= -1) THEN V11060 = .;
   IF (V11061 >= -5 AND V11061 <= -1) THEN V11061 = .;
   IF (V11062 >= -5 AND V11062 <= -1) THEN V11062 = .;
   IF (V11063 >= -5 AND V11063 <= -1) THEN V11063 = .;
   IF (V11064 >= -5 AND V11064 <= -1) THEN V11064 = .;
   IF (V11065 >= -5 AND V11065 <= -1) THEN V11065 = .;
   IF (V11066 >= -5 AND V11066 <= -1) THEN V11066 = .;
   IF (V11067 >= -5 AND V11067 <= -1) THEN V11067 = .;
   IF (V11068 >= -5 AND V11068 <= -1) THEN V11068 = .;
   IF (V11069 >= -5 AND V11069 <= -1) THEN V11069 = .;
   IF (V11070 >= -5 AND V11070 <= -1) THEN V11070 = .;
   IF (V11071 >= -5 AND V11071 <= -1) THEN V11071 = .;
   IF (V11072 >= -5 AND V11072 <= -1) THEN V11072 = .;
   IF (V11073 >= -5 AND V11073 <= -1) THEN V11073 = .;
   IF (V11074 >= -5 AND V11074 <= -1) THEN V11074 = .;
   IF (V11075 >= -5 AND V11075 <= -1) THEN V11075 = .;
   IF (V11076 >= -5 AND V11076 <= -1) THEN V11076 = .;
   IF (V11077 >= -5 AND V11077 <= -1) THEN V11077 = .;
   IF (V11078 >= -5 AND V11078 <= -1) THEN V11078 = .;
   IF (V11079 >= -5 AND V11079 <= -1) THEN V11079 = .;
   IF (V11080 >= -5 AND V11080 <= -1) THEN V11080 = .;
   IF (V11081 >= -5 AND V11081 <= -1) THEN V11081 = .;
   IF (V11082 >= -5 AND V11082 <= -1) THEN V11082 = .;
   IF (V11083 >= -5 AND V11083 <= -1) THEN V11083 = .;
   IF (V11084 >= -5 AND V11084 <= -1) THEN V11084 = .;
   IF (V11085 >= -5 AND V11085 <= -1) THEN V11085 = .;
   IF (V11086 >= -5 AND V11086 <= -1) THEN V11086 = .;
   IF (V11087 >= -5 AND V11087 <= -1) THEN V11087 = .;
   IF (V11088 >= -5 AND V11088 <= -1) THEN V11088 = .;
   IF (V11089 >= -5 AND V11089 <= -1) THEN V11089 = .;
   IF (V11090 >= -5 AND V11090 <= -1) THEN V11090 = .;
   IF (V11091 >= -5 AND V11091 <= -1) THEN V11091 = .;
   IF (V11092 >= -5 AND V11092 <= -1) THEN V11092 = .;
   IF (V11093 >= -5 AND V11093 <= -1) THEN V11093 = .;
   IF (V11094 >= -5 AND V11094 <= -1) THEN V11094 = .;
   IF (V11095 >= -5 AND V11095 <= -1) THEN V11095 = .;
   IF (V11096 >= -5 AND V11096 <= -1) THEN V11096 = .;
   IF (V11097 >= -5 AND V11097 <= -1) THEN V11097 = .;
   IF (V11098 >= -5 AND V11098 <= -1) THEN V11098 = .;
   IF (V11099 >= -5 AND V11099 <= -1) THEN V11099 = .;
   IF (V11100 >= -5 AND V11100 <= -1) THEN V11100 = .;
   IF (V11101 >= -5 AND V11101 <= -1) THEN V11101 = .;
   IF (V11102 >= -5 AND V11102 <= -1) THEN V11102 = .;
   IF (V11103 >= -5 AND V11103 <= -1) THEN V11103 = .;
   IF (V11104 >= -5 AND V11104 <= -1) THEN V11104 = .;
   IF (V11105 >= -5 AND V11105 <= -1) THEN V11105 = .;
   IF (V11106 >= -5 AND V11106 <= -1) THEN V11106 = .;
   IF (V11107 >= -5 AND V11107 <= -1) THEN V11107 = .;
   IF (V11108 >= -5 AND V11108 <= -1) THEN V11108 = .;
   IF (V11109 >= -5 AND V11109 <= -1) THEN V11109 = .;
   IF (V11110 >= -5 AND V11110 <= -1) THEN V11110 = .;
   IF (V11111 >= -5 AND V11111 <= -1) THEN V11111 = .;
   IF (V11112 >= -5 AND V11112 <= -1) THEN V11112 = .;
   IF (V11113 >= -5 AND V11113 <= -1) THEN V11113 = .;
   IF (V11114 >= -5 AND V11114 <= -1) THEN V11114 = .;
   IF (V11115 >= -5 AND V11115 <= -1) THEN V11115 = .;
   IF (V11116 >= -5 AND V11116 <= -1) THEN V11116 = .;
   IF (V11117 >= -5 AND V11117 <= -1) THEN V11117 = .;
   IF (V11118 >= -5 AND V11118 <= -1) THEN V11118 = .;
   IF (V11119 >= -5 AND V11119 <= -1) THEN V11119 = .;
   IF (V11120 >= -5 AND V11120 <= -1) THEN V11120 = .;
   IF (V11121 >= -5 AND V11121 <= -1) THEN V11121 = .;
   IF (V11122 >= -5 AND V11122 <= -1) THEN V11122 = .;
   IF (V11123 >= -5 AND V11123 <= -1) THEN V11123 = .;
   IF (V11124 >= -5 AND V11124 <= -1) THEN V11124 = .;
   IF (V11125 >= -5 AND V11125 <= -1) THEN V11125 = .;
   IF (V11126 >= -5 AND V11126 <= -1) THEN V11126 = .;
   IF (V11127 >= -5 AND V11127 <= -1) THEN V11127 = .;
   IF (V11128 >= -5 AND V11128 <= -1) THEN V11128 = .;
   IF (V11129 >= -5 AND V11129 <= -1) THEN V11129 = .;
   IF (V11130 >= -5 AND V11130 <= -1) THEN V11130 = .;
   IF (V11131 >= -5 AND V11131 <= -1) THEN V11131 = .;
   IF (V11132 >= -5 AND V11132 <= -1) THEN V11132 = .;
   IF (V11133 >= -5 AND V11133 <= -1) THEN V11133 = .;
   IF (V11134 >= -5 AND V11134 <= -1) THEN V11134 = .;
   IF (V11135 >= -5 AND V11135 <= -1) THEN V11135 = .;
   IF (V11136 >= -5 AND V11136 <= -1) THEN V11136 = .;
   IF (V11137 >= -5 AND V11137 <= -1) THEN V11137 = .;
   IF (V11138 >= -5 AND V11138 <= -1) THEN V11138 = .;
   IF (V11139 >= -5 AND V11139 <= -1) THEN V11139 = .;
   IF (V11140 >= -5 AND V11140 <= -1) THEN V11140 = .;
   IF (V11141 >= -5 AND V11141 <= -1) THEN V11141 = .;
   IF (V11142 >= -5 AND V11142 <= -1) THEN V11142 = .;
   IF (V11143 >= -5 AND V11143 <= -1) THEN V11143 = .;
   IF (V11144 >= -5 AND V11144 <= -1) THEN V11144 = .;
   IF (V11145 >= -5 AND V11145 <= -1) THEN V11145 = .;
   IF (V11146 >= -5 AND V11146 <= -1) THEN V11146 = .;
   IF (V11147 >= -5 AND V11147 <= -1) THEN V11147 = .;
   IF (V11148 >= -6 AND V11148 <= -1) THEN V11148 = .;
   IF (V11149 >= -5 AND V11149 <= -1) THEN V11149 = .;
   IF (V11150 >= -5 AND V11150 <= -1) THEN V11150 = .;
   IF (V11151 >= -5 AND V11151 <= -1) THEN V11151 = .;
   IF (V11152 >= -5 AND V11152 <= -1) THEN V11152 = .;
   IF (V11153 >= -5 AND V11153 <= -1) THEN V11153 = .;
   IF (V11154 >= -5 AND V11154 <= -1) THEN V11154 = .;
   IF (V11155 >= -5 AND V11155 <= -1) THEN V11155 = .;
   IF (V11156 >= -6 AND V11156 <= -1) THEN V11156 = .;
   IF (V11157 >= -5 AND V11157 <= -1) THEN V11157 = .;
   IF (V11158 >= -5 AND V11158 <= -1) THEN V11158 = .;
   IF (V11159 >= -5 AND V11159 <= -1) THEN V11159 = .;
   IF (V11160 >= -5 AND V11160 <= -1) THEN V11160 = .;
   IF (V11161 >= -5 AND V11161 <= -1) THEN V11161 = .;
   IF (V11162 >= -5 AND V11162 <= -1) THEN V11162 = .;
   IF (V11163 >= -5 AND V11163 <= -1) THEN V11163 = .;
   IF (V11164 >= -5 AND V11164 <= -1) THEN V11164 = .;
   IF (V11165 >= -5 AND V11165 <= -1) THEN V11165 = .;
   IF (V11166 >= -5 AND V11166 <= -1) THEN V11166 = .;
   IF (V11167 >= -5 AND V11167 <= -1) THEN V11167 = .;
   IF (V11168 >= -5 AND V11168 <= -1) THEN V11168 = .;
   IF (V11169 >= -5 AND V11169 <= -1) THEN V11169 = .;
   IF (V11170 >= -5 AND V11170 <= -1) THEN V11170 = .;
   IF (V11171 >= -5 AND V11171 <= -1) THEN V11171 = .;
   IF (V11172 >= -5 AND V11172 <= -1) THEN V11172 = .;
   IF (V11173 >= -5 AND V11173 <= -1) THEN V11173 = .;
   IF (V11174 >= -5 AND V11174 <= -1) THEN V11174 = .;
   IF (V11175 >= -5 AND V11175 <= -1) THEN V11175 = .;
   IF (V11176 >= -5 AND V11176 <= -1) THEN V11176 = .;
   IF (V11177 >= -5 AND V11177 <= -1) THEN V11177 = .;
   IF (V11178 >= -5 AND V11178 <= -1) THEN V11178 = .;
   IF (V11179 >= -5 AND V11179 <= -1) THEN V11179 = .;
   IF (V11180 >= -5 AND V11180 <= -1) THEN V11180 = .;
   IF (V11181 >= -5 AND V11181 <= -1) THEN V11181 = .;
   IF (V11182 >= -5 AND V11182 <= -1) THEN V11182 = .;
   IF (V11183 >= -5 AND V11183 <= -1) THEN V11183 = .;
   IF (V11184 >= -5 AND V11184 <= -1) THEN V11184 = .;
   IF (V11185 >= -5 AND V11185 <= -1) THEN V11185 = .;
   IF (V11186 >= -5 AND V11186 <= -1) THEN V11186 = .;
   IF (V11187 >= -5 AND V11187 <= -1) THEN V11187 = .;
   IF (V11188 >= -5 AND V11188 <= -1) THEN V11188 = .;
   IF (V11189 >= -5 AND V11189 <= -1) THEN V11189 = .;
   IF (V11190 >= -5 AND V11190 <= -1) THEN V11190 = .;
   IF (V11191 >= -5 AND V11191 <= -1) THEN V11191 = .;
   IF (V11192 >= -5 AND V11192 <= -1) THEN V11192 = .;
   IF (V11193 >= -5 AND V11193 <= -1) THEN V11193 = .;
   IF (V11194 >= -5 AND V11194 <= -1) THEN V11194 = .;
   IF (V11195 >= -5 AND V11195 <= -1) THEN V11195 = .;
   IF (V11196 >= -5 AND V11196 <= -1) THEN V11196 = .;
   IF (V11197 >= -5 AND V11197 <= -1) THEN V11197 = .;
   IF (V11198 >= -5 AND V11198 <= -1) THEN V11198 = .;
   IF (V11199 >= -5 AND V11199 <= -1) THEN V11199 = .;
   IF (V11200 >= -5 AND V11200 <= -1) THEN V11200 = .;
   IF (V11201 >= -6 AND V11201 <= -1) THEN V11201 = .;
   IF (V11202 >= -5 AND V11202 <= -1) THEN V11202 = .;
   IF (V11203 >= -5 AND V11203 <= -1) THEN V11203 = .;
   IF (V11204 >= -5 AND V11204 <= -1) THEN V11204 = .;
   IF (V11205 >= -5 AND V11205 <= -1) THEN V11205 = .;
   IF (V11206 >= -5 AND V11206 <= -1) THEN V11206 = .;
   IF (V11207 >= -5 AND V11207 <= -1) THEN V11207 = .;
   IF (V11208 >= -5 AND V11208 <= -1) THEN V11208 = .;
   IF (V11209 >= -6 AND V11209 <= -1) THEN V11209 = .;
   IF (V11210 >= -5 AND V11210 <= -1) THEN V11210 = .;
   IF (V11211 >= -5 AND V11211 <= -1) THEN V11211 = .;
   IF (V11212 >= -5 AND V11212 <= -1) THEN V11212 = .;
   IF (V11213 >= -5 AND V11213 <= -1) THEN V11213 = .;
   IF (V11214 >= -5 AND V11214 <= -1) THEN V11214 = .;
   IF (V11215 >= -5 AND V11215 <= -1) THEN V11215 = .;
   IF (V11216 >= -5 AND V11216 <= -1) THEN V11216 = .;
   IF (V11217 >= -5 AND V11217 <= -1) THEN V11217 = .;
   IF (V11218 >= -5 AND V11218 <= -1) THEN V11218 = .;
   IF (V11219 >= -5 AND V11219 <= -1) THEN V11219 = .;
   IF (V11220 >= -5 AND V11220 <= -1) THEN V11220 = .;
   IF (V11221 >= -5 AND V11221 <= -1) THEN V11221 = .;
   IF (V11222 >= -5 AND V11222 <= -1) THEN V11222 = .;
   IF (V11223 >= -5 AND V11223 <= -1) THEN V11223 = .;
   IF (V11224 >= -5 AND V11224 <= -1) THEN V11224 = .;
   IF (V11225 >= -5 AND V11225 <= -1) THEN V11225 = .;
   IF (V11226 >= -5 AND V11226 <= -1) THEN V11226 = .;
   IF (V11227 >= -5 AND V11227 <= -1) THEN V11227 = .;
   IF (V11228 >= -5 AND V11228 <= -1) THEN V11228 = .;
   IF (V11229 >= -5 AND V11229 <= -1) THEN V11229 = .;
   IF (V11230 >= -5 AND V11230 <= -1) THEN V11230 = .;
   IF (V11231 >= -5 AND V11231 <= -1) THEN V11231 = .;
   IF (V11232 >= -5 AND V11232 <= -1) THEN V11232 = .;
   IF (V11233 >= -5 AND V11233 <= -1) THEN V11233 = .;
   IF (V11234 >= -5 AND V11234 <= -1) THEN V11234 = .;
   IF (V11235 >= -5 AND V11235 <= -1) THEN V11235 = .;
   IF (V11236 >= -5 AND V11236 <= -1) THEN V11236 = .;
   IF (V11237 >= -5 AND V11237 <= -1) THEN V11237 = .;
   IF (V11238 >= -5 AND V11238 <= -1) THEN V11238 = .;
   IF (V11239 >= -5 AND V11239 <= -1) THEN V11239 = .;
   IF (V11240 >= -5 AND V11240 <= -1) THEN V11240 = .;
   IF (V11241 >= -5 AND V11241 <= -1) THEN V11241 = .;
   IF (V11242 >= -5 AND V11242 <= -1) THEN V11242 = .;
   IF (V11243 >= -5 AND V11243 <= -1) THEN V11243 = .;
   IF (V11244 >= -5 AND V11244 <= -1) THEN V11244 = .;
   IF (V11245 >= -5 AND V11245 <= -1) THEN V11245 = .;
   IF (V11246 >= -5 AND V11246 <= -1) THEN V11246 = .;
   IF (V11247 >= -5 AND V11247 <= -1) THEN V11247 = .;
   IF (V11248 >= -5 AND V11248 <= -1) THEN V11248 = .;
   IF (V11249 >= -5 AND V11249 <= -1) THEN V11249 = .;
   IF (V11250 >= -5 AND V11250 <= -1) THEN V11250 = .;
   IF (V11251 >= -5 AND V11251 <= -1) THEN V11251 = .;
   IF (V11252 >= -5 AND V11252 <= -1) THEN V11252 = .;
   IF (V11253 >= -5 AND V11253 <= -1) THEN V11253 = .;
   IF (V11254 >= -5 AND V11254 <= -1) THEN V11254 = .;
   IF (V11255 >= -5 AND V11255 <= -1) THEN V11255 = .;
   IF (V11256 >= -5 AND V11256 <= -1) THEN V11256 = .;
   IF (V11257 >= -5 AND V11257 <= -1) THEN V11257 = .;
   IF (V11258 >= -5 AND V11258 <= -1) THEN V11258 = .;
   IF (V11259 >= -5 AND V11259 <= -1) THEN V11259 = .;
   IF (V11260 >= -5 AND V11260 <= -1) THEN V11260 = .;
   IF (V11261 >= -5 AND V11261 <= -1) THEN V11261 = .;
   IF (V11262 >= -5 AND V11262 <= -1) THEN V11262 = .;
   IF (V11263 >= -5 AND V11263 <= -1) THEN V11263 = .;
   IF (V11264 >= -5 AND V11264 <= -1) THEN V11264 = .;
   IF (V11265 >= -5 AND V11265 <= -1) THEN V11265 = .;
   IF (V11266 >= -5 AND V11266 <= -1) THEN V11266 = .;
   IF (V11267 >= -5 AND V11267 <= -1) THEN V11267 = .;
   IF (V11268 >= -5 AND V11268 <= -1) THEN V11268 = .;
   IF (V11269 >= -5 AND V11269 <= -1) THEN V11269 = .;
   IF (V11270 >= -5 AND V11270 <= -1) THEN V11270 = .;
   IF (V11271 >= -5 AND V11271 <= -1) THEN V11271 = .;
   IF (V11272 >= -5 AND V11272 <= -1) THEN V11272 = .;
   IF (V11273 >= -5 AND V11273 <= -1) THEN V11273 = .;
   IF (V11274 >= -5 AND V11274 <= -1) THEN V11274 = .;
   IF (V11275 >= -5 AND V11275 <= -1) THEN V11275 = .;
   IF (V11276 >= -5 AND V11276 <= -1) THEN V11276 = .;
   IF (V11277 >= -5 AND V11277 <= -1) THEN V11277 = .;
   IF (V11278 >= -5 AND V11278 <= -1) THEN V11278 = .;
   IF (V11279 >= -5 AND V11279 <= -1) THEN V11279 = .;
   IF (V11280 >= -5 AND V11280 <= -1) THEN V11280 = .;
   IF (V11281 >= -5 AND V11281 <= -1) THEN V11281 = .;
   IF (V11282 >= -5 AND V11282 <= -1) THEN V11282 = .;
   IF (V11283 >= -5 AND V11283 <= -1) THEN V11283 = .;
   IF (V11284 >= -5 AND V11284 <= -1) THEN V11284 = .;
   IF (V11285 >= -5 AND V11285 <= -1) THEN V11285 = .;
   IF (V11286 >= -5 AND V11286 <= -1) THEN V11286 = .;
   IF (V11287 >= -5 AND V11287 <= -1) THEN V11287 = .;
   IF (V11288 >= -5 AND V11288 <= -1) THEN V11288 = .;
   IF (V11289 >= -5 AND V11289 <= -1) THEN V11289 = .;
   IF (V11290 >= -5 AND V11290 <= -1) THEN V11290 = .;
   IF (V11291 >= -5 AND V11291 <= -1) THEN V11291 = .;
   IF (V11292 >= -5 AND V11292 <= -1) THEN V11292 = .;
   IF (V11293 >= -5 AND V11293 <= -1) THEN V11293 = .;
   IF (V11294 >= -5 AND V11294 <= -1) THEN V11294 = .;
   IF (V11295 >= -5 AND V11295 <= -1) THEN V11295 = .;
   IF (V11296 >= -5 AND V11296 <= -1) THEN V11296 = .;
   IF (V11297 >= -5 AND V11297 <= -1) THEN V11297 = .;
   IF (V11298 >= -5 AND V11298 <= -1) THEN V11298 = .;
   IF (V11299 >= -5 AND V11299 <= -1) THEN V11299 = .;
   IF (V11300 >= -5 AND V11300 <= -1) THEN V11300 = .;
   IF (V11301 >= -5 AND V11301 <= -1) THEN V11301 = .;
   IF (V11302 >= -5 AND V11302 <= -1) THEN V11302 = .;
   IF (V11303 >= -5 AND V11303 <= -1) THEN V11303 = .;
   IF (V11304 >= -5 AND V11304 <= -1) THEN V11304 = .;
   IF (V11305 >= -5 AND V11305 <= -1) THEN V11305 = .;
   IF (V11306 >= -5 AND V11306 <= -1) THEN V11306 = .;
   IF (V11307 >= -5 AND V11307 <= -1) THEN V11307 = .;
   IF (V11308 >= -5 AND V11308 <= -1) THEN V11308 = .;
   IF (V11309 >= -5 AND V11309 <= -1) THEN V11309 = .;
   IF (V11310 >= -5 AND V11310 <= -1) THEN V11310 = .;
   IF (V11311 >= -5 AND V11311 <= -1) THEN V11311 = .;
   IF (V11312 >= -5 AND V11312 <= -1) THEN V11312 = .;
   IF (V11313 >= -5 AND V11313 <= -1) THEN V11313 = .;
   IF (V11314 >= -5 AND V11314 <= -1) THEN V11314 = .;
   IF (V11315 >= -5 AND V11315 <= -1) THEN V11315 = .;
   IF (V11316 >= -5 AND V11316 <= -1) THEN V11316 = .;
   IF (V11317 >= -5 AND V11317 <= -1) THEN V11317 = .;
   IF (V11318 >= -5 AND V11318 <= -1) THEN V11318 = .;
   IF (V11319 >= -5 AND V11319 <= -1) THEN V11319 = .;
   IF (V11320 >= -5 AND V11320 <= -1) THEN V11320 = .;
   IF (V11321 >= -5 AND V11321 <= -1) THEN V11321 = .;
   IF (V11322 >= -5 AND V11322 <= -1) THEN V11322 = .;
   IF (V11323 >= -5 AND V11323 <= -1) THEN V11323 = .;
   IF (V11324 >= -5 AND V11324 <= -1) THEN V11324 = .;
   IF (V11325 >= -5 AND V11325 <= -1) THEN V11325 = .;
   IF (V11326 >= -5 AND V11326 <= -1) THEN V11326 = .;
   IF (V11327 >= -5 AND V11327 <= -1) THEN V11327 = .;
   IF (V11328 >= -5 AND V11328 <= -1) THEN V11328 = .;
   IF (V11329 >= -5 AND V11329 <= -1) THEN V11329 = .;
   IF (V11330 >= -5 AND V11330 <= -1) THEN V11330 = .;
   IF (V11331 >= -5 AND V11331 <= -1) THEN V11331 = .;
   IF (V11332 >= -5 AND V11332 <= -1) THEN V11332 = .;
   IF (V11333 >= -5 AND V11333 <= -1) THEN V11333 = .;
   IF (V11334 >= -5 AND V11334 <= -1) THEN V11334 = .;
   IF (V11335 >= -5 AND V11335 <= -1) THEN V11335 = .;
   IF (V11336 >= -5 AND V11336 <= -1) THEN V11336 = .;
   IF (V11337 >= -5 AND V11337 <= -1) THEN V11337 = .;
   IF (V11338 >= -5 AND V11338 <= -1) THEN V11338 = .;
   IF (V11339 >= -5 AND V11339 <= -1) THEN V11339 = .;
   IF (V11340 >= -5 AND V11340 <= -1) THEN V11340 = .;
   IF (V11341 >= -5 AND V11341 <= -1) THEN V11341 = .;
   IF (V11342 >= -5 AND V11342 <= -1) THEN V11342 = .;
   IF (V11343 >= -5 AND V11343 <= -1) THEN V11343 = .;
   IF (V11344 >= -5 AND V11344 <= -1) THEN V11344 = .;
   IF (V11345 >= -5 AND V11345 <= -1) THEN V11345 = .;
   IF (V11346 >= -5 AND V11346 <= -1) THEN V11346 = .;
   IF (V11347 >= -5 AND V11347 <= -1) THEN V11347 = .;
   IF (V11348 >= -5 AND V11348 <= -1) THEN V11348 = .;
   IF (V11349 >= -5 AND V11349 <= -1) THEN V11349 = .;
   IF (V11350 >= -5 AND V11350 <= -1) THEN V11350 = .;
   IF (V11351 >= -5 AND V11351 <= -1) THEN V11351 = .;
   IF (V11352 >= -5 AND V11352 <= -1) THEN V11352 = .;
   IF (V11353 >= -5 AND V11353 <= -1) THEN V11353 = .;
   IF (V11354 >= -5 AND V11354 <= -1) THEN V11354 = .;
   IF (V11355 >= -5 AND V11355 <= -1) THEN V11355 = .;
   IF (V11356 >= -5 AND V11356 <= -1) THEN V11356 = .;
   IF (V11357 >= -5 AND V11357 <= -1) THEN V11357 = .;
   IF (V11358 >= -5 AND V11358 <= -1) THEN V11358 = .;
   IF (V11359 >= -5 AND V11359 <= -1) THEN V11359 = .;
   IF (V11360 >= -5 AND V11360 <= -1) THEN V11360 = .;
   IF (V11361 >= -5 AND V11361 <= -1) THEN V11361 = .;
   IF (V11362 >= -5 AND V11362 <= -1) THEN V11362 = .;
   IF (V11363 >= -5 AND V11363 <= -1) THEN V11363 = .;
   IF (V11364 >= -5 AND V11364 <= -1) THEN V11364 = .;
   IF (V11365 >= -5 AND V11365 <= -1) THEN V11365 = .;
   IF (V11366 >= -5 AND V11366 <= -1) THEN V11366 = .;
   IF (V11367 >= -5 AND V11367 <= -1) THEN V11367 = .;
   IF (V11368 >= -5 AND V11368 <= -1) THEN V11368 = .;
   IF (V11369 >= -5 AND V11369 <= -1) THEN V11369 = .;
   IF (V11370 >= -5 AND V11370 <= -1) THEN V11370 = .;
   IF (V11371 >= -5 AND V11371 <= -1) THEN V11371 = .;
   IF (V11372 >= -5 AND V11372 <= -1) THEN V11372 = .;
   IF (V11373 >= -5 AND V11373 <= -1) THEN V11373 = .;
   IF (V11374 >= -5 AND V11374 <= -1) THEN V11374 = .;
   IF (V11375 >= -5 AND V11375 <= -1) THEN V11375 = .;
   IF (V11376 >= -5 AND V11376 <= -1) THEN V11376 = .;
   IF (V11377 >= -5 AND V11377 <= -1) THEN V11377 = .;
   IF (V11378 >= -5 AND V11378 <= -1) THEN V11378 = .;
   IF (V11379 >= -5 AND V11379 <= -1) THEN V11379 = .;
   IF (V11380 >= -5 AND V11380 <= -1) THEN V11380 = .;
   IF (V11381 >= -5 AND V11381 <= -1) THEN V11381 = .;
   IF (V11382 >= -5 AND V11382 <= -1) THEN V11382 = .;
   IF (V11383 >= -5 AND V11383 <= -1) THEN V11383 = .;
   IF (V11384 >= -5 AND V11384 <= -1) THEN V11384 = .;
   IF (V11385 >= -5 AND V11385 <= -1) THEN V11385 = .;
   IF (V11386 >= -5 AND V11386 <= -1) THEN V11386 = .;
   IF (V11387 >= -5 AND V11387 <= -1) THEN V11387 = .;
   IF (V11388 >= -5 AND V11388 <= -1) THEN V11388 = .;
   IF (V11389 >= -5 AND V11389 <= -1) THEN V11389 = .;
   IF (V11390 >= -5 AND V11390 <= -1) THEN V11390 = .;
   IF (V11391 >= -5 AND V11391 <= -1) THEN V11391 = .;
   IF (V11392 >= -5 AND V11392 <= -1) THEN V11392 = .;
   IF (V11393 >= -5 AND V11393 <= -1) THEN V11393 = .;
   IF (V11394 >= -5 AND V11394 <= -1) THEN V11394 = .;
   IF (V11395 >= -5 AND V11395 <= -1) THEN V11395 = .;
   IF (V11396 >= -5 AND V11396 <= -1) THEN V11396 = .;
   IF (V11397 >= -5 AND V11397 <= -1) THEN V11397 = .;
   IF (V11398 >= -5 AND V11398 <= -1) THEN V11398 = .;
   IF (V11399 >= -5 AND V11399 <= -1) THEN V11399 = .;
   IF (V11400 >= -5 AND V11400 <= -1) THEN V11400 = .;
   IF (V11401 >= -5 AND V11401 <= -1) THEN V11401 = .;
   IF (V11402 >= -5 AND V11402 <= -1) THEN V11402 = .;
   IF (V11403 >= -5 AND V11403 <= -1) THEN V11403 = .;
   IF (V11404 >= -5 AND V11404 <= -1) THEN V11404 = .;
   IF (V11405 >= -5 AND V11405 <= -1) THEN V11405 = .;
   IF (V11406 >= -5 AND V11406 <= -1) THEN V11406 = .;
   IF (V11407 >= -5 AND V11407 <= -1) THEN V11407 = .;
   IF (V11408 >= -5 AND V11408 <= -1) THEN V11408 = .;
   IF (V11409 >= -5 AND V11409 <= -1) THEN V11409 = .;
   IF (V11410 >= -5 AND V11410 <= -1) THEN V11410 = .;
   IF (V11411 >= -5 AND V11411 <= -1) THEN V11411 = .;
   IF (V11412 >= -5 AND V11412 <= -1) THEN V11412 = .;
   IF (V11413 >= -5 AND V11413 <= -1) THEN V11413 = .;
   IF (V11414 >= -5 AND V11414 <= -1) THEN V11414 = .;
   IF (V11415 >= -5 AND V11415 <= -1) THEN V11415 = .;
   IF (V11416 >= -5 AND V11416 <= -1) THEN V11416 = .;
   IF (V11417 >= -5 AND V11417 <= -1) THEN V11417 = .;
   IF (V11418 >= -5 AND V11418 <= -1) THEN V11418 = .;
   IF (V11419 >= -5 AND V11419 <= -1) THEN V11419 = .;
   IF (V11420 >= -5 AND V11420 <= -1) THEN V11420 = .;
   IF (V11421 >= -5 AND V11421 <= -1) THEN V11421 = .;
   IF (V11422 >= -5 AND V11422 <= -1) THEN V11422 = .;
   IF (V11423 >= -5 AND V11423 <= -1) THEN V11423 = .;
   IF (V11424 >= -5 AND V11424 <= -1) THEN V11424 = .;
   IF (V11425 >= -5 AND V11425 <= -1) THEN V11425 = .;
   IF (V11426 >= -5 AND V11426 <= -1) THEN V11426 = .;
   IF (V11427 >= -5 AND V11427 <= -1) THEN V11427 = .;
   IF (V11428 >= -5 AND V11428 <= -1) THEN V11428 = .;
   IF (V11429 >= -5 AND V11429 <= -1) THEN V11429 = .;
   IF (V11430 >= -5 AND V11430 <= -1) THEN V11430 = .;
   IF (V11431 >= -5 AND V11431 <= -1) THEN V11431 = .;
   IF (V11432 >= -5 AND V11432 <= -1) THEN V11432 = .;
   IF (V11433 >= -5 AND V11433 <= -1) THEN V11433 = .;
   IF (V11434 >= -5 AND V11434 <= -1) THEN V11434 = .;
   IF (V11435 >= -5 AND V11435 <= -1) THEN V11435 = .;
   IF (V11436 >= -5 AND V11436 <= -1) THEN V11436 = .;
   IF (V11437 >= -5 AND V11437 <= -1) THEN V11437 = .;
   IF (V11438 >= -5 AND V11438 <= -1) THEN V11438 = .;
   IF (V11439 >= -5 AND V11439 <= -1) THEN V11439 = .;
   IF (V11440 >= -5 AND V11440 <= -1) THEN V11440 = .;
   IF (V11441 >= -5 AND V11441 <= -1) THEN V11441 = .;
   IF (V11442 >= -5 AND V11442 <= -1) THEN V11442 = .;
   IF (V11443 >= -5 AND V11443 <= -1) THEN V11443 = .;
   IF (V11444 >= -5 AND V11444 <= -1) THEN V11444 = .;
   IF (V11445 >= -5 AND V11445 <= -1) THEN V11445 = .;
   IF (V11446 >= -5 AND V11446 <= -1) THEN V11446 = .;
   IF (V11447 >= -5 AND V11447 <= -1) THEN V11447 = .;
   IF (V11448 >= -5 AND V11448 <= -1) THEN V11448 = .;
   IF (V11449 >= -5 AND V11449 <= -1) THEN V11449 = .;
   IF (V11450 >= -5 AND V11450 <= -1) THEN V11450 = .;
   IF (V11451 >= -5 AND V11451 <= -1) THEN V11451 = .;
   IF (V11452 >= -5 AND V11452 <= -1) THEN V11452 = .;
   IF (V11453 >= -5 AND V11453 <= -1) THEN V11453 = .;
   IF (V11454 >= -5 AND V11454 <= -1) THEN V11454 = .;
   IF (V11455 >= -5 AND V11455 <= -1) THEN V11455 = .;
   IF (V11456 >= -5 AND V11456 <= -1) THEN V11456 = .;
   IF (V11457 >= -5 AND V11457 <= -1) THEN V11457 = .;
   IF (V11458 >= -5 AND V11458 <= -1) THEN V11458 = .;
   IF (V11459 >= -5 AND V11459 <= -1) THEN V11459 = .;
   IF (V11460 >= -5 AND V11460 <= -1) THEN V11460 = .;
   IF (V11461 >= -5 AND V11461 <= -1) THEN V11461 = .;
   IF (V11462 >= -5 AND V11462 <= -1) THEN V11462 = .;
   IF (V11463 >= -5 AND V11463 <= -1) THEN V11463 = .;
   IF (V11464 >= -5 AND V11464 <= -1) THEN V11464 = .;
   IF (V11465 >= -5 AND V11465 <= -1) THEN V11465 = .;
   IF (V11466 >= -5 AND V11466 <= -1) THEN V11466 = .;
   IF (V11467 >= -5 AND V11467 <= -1) THEN V11467 = .;
   IF (V11468 >= -5 AND V11468 <= -1) THEN V11468 = .;
   IF (V11469 >= -5 AND V11469 <= -1) THEN V11469 = .;
   IF (V11470 >= -5 AND V11470 <= -1) THEN V11470 = .;
   IF (V11471 >= -5 AND V11471 <= -1) THEN V11471 = .;
   IF (V11472 >= -5 AND V11472 <= -1) THEN V11472 = .;
   IF (V11473 >= -5 AND V11473 <= -1) THEN V11473 = .;
   IF (V11474 >= -5 AND V11474 <= -1) THEN V11474 = .;
   IF (V11475 >= -5 AND V11475 <= -1) THEN V11475 = .;
   IF (V11476 >= -5 AND V11476 <= -1) THEN V11476 = .;
   IF (V11477 >= -5 AND V11477 <= -1) THEN V11477 = .;
   IF (V11478 >= -5 AND V11478 <= -1) THEN V11478 = .;
   IF (V11479 >= -5 AND V11479 <= -1) THEN V11479 = .;
   IF (V11480 >= -5 AND V11480 <= -1) THEN V11480 = .;
   IF (V11481 >= -5 AND V11481 <= -1) THEN V11481 = .;
   IF (V11482 >= -5 AND V11482 <= -1) THEN V11482 = .;
   IF (V11483 >= -5 AND V11483 <= -1) THEN V11483 = .;
   IF (V11484 >= -5 AND V11484 <= -1) THEN V11484 = .;
   IF (V11485 >= -5 AND V11485 <= -1) THEN V11485 = .;
   IF (V11486 >= -5 AND V11486 <= -1) THEN V11486 = .;
   IF (V11487 >= -5 AND V11487 <= -1) THEN V11487 = .;
   IF (V11488 >= -5 AND V11488 <= -1) THEN V11488 = .;
   IF (V11489 >= -5 AND V11489 <= -1) THEN V11489 = .;
   IF (V11490 >= -5 AND V11490 <= -1) THEN V11490 = .;
   IF (V11491 >= -5 AND V11491 <= -1) THEN V11491 = .;
   IF (V11492 >= -5 AND V11492 <= -1) THEN V11492 = .;
   IF (V11493 >= -5 AND V11493 <= -1) THEN V11493 = .;
   IF (V11494 >= -5 AND V11494 <= -1) THEN V11494 = .;
   IF (V11495 >= -5 AND V11495 <= -1) THEN V11495 = .;
   IF (V11496 >= -5 AND V11496 <= -1) THEN V11496 = .;
   IF (V11497 >= -5 AND V11497 <= -1) THEN V11497 = .;
   IF (V11498 >= -5 AND V11498 <= -1) THEN V11498 = .;
   IF (V11499 >= -5 AND V11499 <= -1) THEN V11499 = .;
   IF (V11500 >= -5 AND V11500 <= -1) THEN V11500 = .;
   IF (V11501 >= -5 AND V11501 <= -1) THEN V11501 = .;
   IF (V11502 >= -5 AND V11502 <= -1) THEN V11502 = .;
   IF (V11503 >= -5 AND V11503 <= -1) THEN V11503 = .;
   IF (V11504 >= -5 AND V11504 <= -1) THEN V11504 = .;
   IF (V11505 >= -5 AND V11505 <= -1) THEN V11505 = .;
   IF (V11506 >= -5 AND V11506 <= -1) THEN V11506 = .;
   IF (V11507 >= -5 AND V11507 <= -1) THEN V11507 = .;
   IF (V11508 >= -5 AND V11508 <= -1) THEN V11508 = .;
   IF (V11509 >= -5 AND V11509 <= -1) THEN V11509 = .;
   IF (V11510 >= -5 AND V11510 <= -1) THEN V11510 = .;
   IF (V11511 >= -5 AND V11511 <= -1) THEN V11511 = .;
   IF (V11512 >= -5 AND V11512 <= -1) THEN V11512 = .;
   IF (V11513 >= -5 AND V11513 <= -1) THEN V11513 = .;
   IF (V11514 >= -5 AND V11514 <= -1) THEN V11514 = .;
   IF (V11515 >= -5 AND V11515 <= -1) THEN V11515 = .;
   IF (V11516 >= -5 AND V11516 <= -1) THEN V11516 = .;
   IF (V11517 >= -5 AND V11517 <= -1) THEN V11517 = .;
   IF (V11518 >= -5 AND V11518 <= -1) THEN V11518 = .;
   IF (V11519 >= -5 AND V11519 <= -1) THEN V11519 = .;
   IF (V11520 >= -5 AND V11520 <= -1) THEN V11520 = .;
   IF (V11521 >= -5 AND V11521 <= -1) THEN V11521 = .;
   IF (V11522 >= -5 AND V11522 <= -1) THEN V11522 = .;
   IF (V11523 >= -5 AND V11523 <= -1) THEN V11523 = .;
   IF (V11524 >= -5 AND V11524 <= -1) THEN V11524 = .;
   IF (V11525 >= -5 AND V11525 <= -1) THEN V11525 = .;
   IF (V11526 >= -5 AND V11526 <= -1) THEN V11526 = .;
   IF (V11527 >= -5 AND V11527 <= -1) THEN V11527 = .;
   IF (V11528 >= -5 AND V11528 <= -1) THEN V11528 = .;
   IF (V11529 >= -5 AND V11529 <= -1) THEN V11529 = .;
   IF (V11530 >= -5 AND V11530 <= -1) THEN V11530 = .;
   IF (V11531 >= -5 AND V11531 <= -1) THEN V11531 = .;
   IF (V11532 >= -5 AND V11532 <= -1) THEN V11532 = .;
   IF (V11533 >= -5 AND V11533 <= -1) THEN V11533 = .;
   IF (V11534 >= -5 AND V11534 <= -1) THEN V11534 = .;
   IF (V11535 >= -5 AND V11535 <= -1) THEN V11535 = .;
   IF (V11536 >= -5 AND V11536 <= -1) THEN V11536 = .;
   IF (V11537 >= -5 AND V11537 <= -1) THEN V11537 = .;
   IF (V11538 >= -5 AND V11538 <= -1) THEN V11538 = .;
   IF (V11539 >= -5 AND V11539 <= -1) THEN V11539 = .;
   IF (V11540 >= -5 AND V11540 <= -1) THEN V11540 = .;
   IF (V11541 >= -5 AND V11541 <= -1) THEN V11541 = .;
   IF (V11542 >= -5 AND V11542 <= -1) THEN V11542 = .;
   IF (V11543 >= -5 AND V11543 <= -1) THEN V11543 = .;
   IF (V11544 >= -5 AND V11544 <= -1) THEN V11544 = .;
   IF (V11545 >= -5 AND V11545 <= -1) THEN V11545 = .;
   IF (V11546 >= -5 AND V11546 <= -1) THEN V11546 = .;
   IF (V11547 >= -5 AND V11547 <= -1) THEN V11547 = .;
   IF (V11548 >= -5 AND V11548 <= -1) THEN V11548 = .;
   IF (V11549 >= -5 AND V11549 <= -1) THEN V11549 = .;
   IF (V11550 >= -5 AND V11550 <= -1) THEN V11550 = .;
   IF (V11551 >= -5 AND V11551 <= -1) THEN V11551 = .;
   IF (V11552 >= -5 AND V11552 <= -1) THEN V11552 = .;
   IF (V11553 >= -5 AND V11553 <= -1) THEN V11553 = .;
   IF (V11554 >= -5 AND V11554 <= -1) THEN V11554 = .;
   IF (V11555 >= -5 AND V11555 <= -1) THEN V11555 = .;
   IF (V11556 >= -5 AND V11556 <= -1) THEN V11556 = .;
   IF (V11557 >= -5 AND V11557 <= -1) THEN V11557 = .;
   IF (V11558 >= -5 AND V11558 <= -1) THEN V11558 = .;
   IF (V11559 >= -5 AND V11559 <= -1) THEN V11559 = .;
   IF (V11560 >= -5 AND V11560 <= -1) THEN V11560 = .;
   IF (V11561 >= -5 AND V11561 <= -1) THEN V11561 = .;
   IF (V11562 >= -5 AND V11562 <= -1) THEN V11562 = .;
   IF (V11563 >= -5 AND V11563 <= -1) THEN V11563 = .;
   IF (V11564 >= -5 AND V11564 <= -1) THEN V11564 = .;
   IF (V11565 >= -5 AND V11565 <= -1) THEN V11565 = .;
   IF (V11566 >= -5 AND V11566 <= -1) THEN V11566 = .;
   IF (V11567 >= -5 AND V11567 <= -1) THEN V11567 = .;
   IF (V11568 >= -5 AND V11568 <= -1) THEN V11568 = .;
   IF (V11569 >= -5 AND V11569 <= -1) THEN V11569 = .;
   IF (V11570 >= -5 AND V11570 <= -1) THEN V11570 = .;
   IF (V11571 >= -5 AND V11571 <= -1) THEN V11571 = .;
   IF (V11572 >= -5 AND V11572 <= -1) THEN V11572 = .;
   IF (V11573 >= -5 AND V11573 <= -1) THEN V11573 = .;
   IF (V11574 >= -5 AND V11574 <= -1) THEN V11574 = .;
   IF (V11575 >= -5 AND V11575 <= -1) THEN V11575 = .;
   IF (V11576 >= -5 AND V11576 <= -1) THEN V11576 = .;
   IF (V11577 >= -5 AND V11577 <= -1) THEN V11577 = .;
   IF (V11578 >= -5 AND V11578 <= -1) THEN V11578 = .;
   IF (V11579 >= -5 AND V11579 <= -1) THEN V11579 = .;
   IF (V11580 >= -5 AND V11580 <= -1) THEN V11580 = .;
   IF (V11581 >= -5 AND V11581 <= -1) THEN V11581 = .;
   IF (V11582 >= -5 AND V11582 <= -1) THEN V11582 = .;
   IF (V11583 >= -5 AND V11583 <= -1) THEN V11583 = .;
   IF (V11584 >= -5 AND V11584 <= -1) THEN V11584 = .;
   IF (V11585 >= -5 AND V11585 <= -1) THEN V11585 = .;
   IF (V11586 >= -5 AND V11586 <= -1) THEN V11586 = .;
   IF (V11587 >= -5 AND V11587 <= -1) THEN V11587 = .;
   IF (V11588 >= -5 AND V11588 <= -1) THEN V11588 = .;
   IF (V11589 >= -5 AND V11589 <= -1) THEN V11589 = .;
   IF (V11590 >= -5 AND V11590 <= -1) THEN V11590 = .;
   IF (V11591 >= -5 AND V11591 <= -1) THEN V11591 = .;
   IF (V11592 >= -5 AND V11592 <= -1) THEN V11592 = .;
   IF (V11593 >= -5 AND V11593 <= -1) THEN V11593 = .;
   IF (V11594 >= -5 AND V11594 <= -1) THEN V11594 = .;
   IF (V11595 >= -5 AND V11595 <= -1) THEN V11595 = .;
   IF (V11596 >= -5 AND V11596 <= -1) THEN V11596 = .;
   IF (V11597 >= -5 AND V11597 <= -1) THEN V11597 = .;
   IF (V11598 >= -5 AND V11598 <= -1) THEN V11598 = .;
   IF (V11599 >= -5 AND V11599 <= -1) THEN V11599 = .;
   IF (V11600 >= -5 AND V11600 <= -1) THEN V11600 = .;
   IF (V11601 >= -5 AND V11601 <= -1) THEN V11601 = .;
   IF (V11602 >= -5 AND V11602 <= -1) THEN V11602 = .;
   IF (V11603 >= -5 AND V11603 <= -1) THEN V11603 = .;
   IF (V11604 >= -5 AND V11604 <= -1) THEN V11604 = .;
   IF (V11605 >= -5 AND V11605 <= -1) THEN V11605 = .;
   IF (V11606 >= -5 AND V11606 <= -1) THEN V11606 = .;
   IF (V11607 >= -5 AND V11607 <= -1) THEN V11607 = .;
   IF (V11608 >= -5 AND V11608 <= -1) THEN V11608 = .;
   IF (V11609 >= -5 AND V11609 <= -1) THEN V11609 = .;
   IF (V11610 >= -5 AND V11610 <= -1) THEN V11610 = .;
   IF (V11611 >= -5 AND V11611 <= -1) THEN V11611 = .;
   IF (V11612 >= -5 AND V11612 <= -1) THEN V11612 = .;
   IF (V11613 >= -5 AND V11613 <= -1) THEN V11613 = .;
   IF (V11614 >= -5 AND V11614 <= -1) THEN V11614 = .;
   IF (V11615 >= -5 AND V11615 <= -1) THEN V11615 = .;
   IF (V11616 >= -5 AND V11616 <= -1) THEN V11616 = .;
   IF (V11617 >= -5 AND V11617 <= -1) THEN V11617 = .;
   IF (V11618 >= -5 AND V11618 <= -1) THEN V11618 = .;
   IF (V11619 >= -5 AND V11619 <= -1) THEN V11619 = .;
   IF (V11620 >= -5 AND V11620 <= -1) THEN V11620 = .;
   IF (V11621 >= -5 AND V11621 <= -1) THEN V11621 = .;
   IF (V11622 >= -5 AND V11622 <= -1) THEN V11622 = .;
   IF (V11623 >= -5 AND V11623 <= -1) THEN V11623 = .;
   IF (V11624 >= -5 AND V11624 <= -1) THEN V11624 = .;
   IF (V11625 >= -5 AND V11625 <= -1) THEN V11625 = .;
   IF (V11626 >= -5 AND V11626 <= -1) THEN V11626 = .;
   IF (V11627 >= -5 AND V11627 <= -1) THEN V11627 = .;
   IF (V11628 >= -5 AND V11628 <= -1) THEN V11628 = .;
   IF (V11629 >= -5 AND V11629 <= -1) THEN V11629 = .;
   IF (V11630 >= -5 AND V11630 <= -1) THEN V11630 = .;
   IF (V11631 >= -5 AND V11631 <= -1) THEN V11631 = .;
   IF (V11632 >= -5 AND V11632 <= -1) THEN V11632 = .;
   IF (V11633 >= -5 AND V11633 <= -1) THEN V11633 = .;
   IF (V11634 >= -5 AND V11634 <= -1) THEN V11634 = .;
   IF (V11635 >= -5 AND V11635 <= -1) THEN V11635 = .;
   IF (V11636 >= -5 AND V11636 <= -1) THEN V11636 = .;
   IF (V11637 >= -5 AND V11637 <= -1) THEN V11637 = .;
   IF (V11638 >= -5 AND V11638 <= -1) THEN V11638 = .;
   IF (V11639 >= -5 AND V11639 <= -1) THEN V11639 = .;
   IF (V11640 >= -5 AND V11640 <= -1) THEN V11640 = .;
   IF (V11641 >= -5 AND V11641 <= -1) THEN V11641 = .;
   IF (V11642 >= -5 AND V11642 <= -1) THEN V11642 = .;
   IF (V11643 >= -5 AND V11643 <= -1) THEN V11643 = .;
   IF (V11644 >= -5 AND V11644 <= -1) THEN V11644 = .;
   IF (V11645 >= -5 AND V11645 <= -1) THEN V11645 = .;
   IF (V11646 >= -5 AND V11646 <= -1) THEN V11646 = .;
   IF (V11647 >= -5 AND V11647 <= -1) THEN V11647 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT V10004 v10004ff. V10005 v10005ff. V10006 v10006ff.
         V10007 v10007ff. V10008 v10008ff. V10009 v10009ff.
         V10010 v10010ff. V10011 v10011ff. V10012 v10012ff.
         V10013 v10013ff. V10014 v10014ff. V10015 v10015ff.
         V10016 v10016ff. V10017 v10017ff. V10018 v10018ff.
         V10019 v10019ff. V10020 v10020ff. V10021 v10021ff.
         V10022 v10022ff. V10023 v10023ff. V10024 v10024ff.
         V10025 v10025ff. V10026 v10026ff. V10027 v10027ff.
         V10028 v10028ff. V10029 v10029ff. V10030 v10030ff.
         V10031 v10031ff. V10032 v10032ff. V10033 v10033ff.
         V10034 v10034ff. V10035 v10035ff. V10036 v10036ff.
         V10037 v10037ff. V10038 v10038ff. V10039 v10039ff.
         V10040 v10040ff. V10041 v10041ff. V10042 v10042ff.
         V10043 v10043ff. V10044 v10044ff. V10045 v10045ff.
         V10046 v10046ff. V10047 v10047ff. V10048 v10048ff.
         V10049 v10049ff. V10050 v10050ff. V10051 v10051ff.
         V10052 v10052ff. V10053 v10053ff. V10054 v10054ff.
         V10055 v10055ff. V10056 v10056ff. V10057 v10057ff.
         V10058 v10058ff. V10059 v10059ff. V10060 v10060ff.
         V10061 v10061ff. V10062 v10062ff. V10063 v10063ff.
         V10064 v10064ff. V10065 v10065ff. V10066 v10066ff.
         V10067 v10067ff. V10068 v10068ff. V10069 v10069ff.
         V10070 v10070ff. V10071 v10071ff. V10072 v10072ff.
         V10073 v10073ff. V10074 v10074ff. V10075 v10075ff.
         V10076 v10076ff. V10077 v10077ff. V10078 v10078ff.
         V10079 v10079ff. V10080 v10080ff. V10081 v10081ff.
         V10082 v10082ff. V10083 v10083ff. V10084 v10084ff.
         V10085 v10085ff. V10086 v10086ff. V10087 v10087ff.
         V10088 v10088ff. V10089 v10089ff. V10090 v10090ff.
         V10091 v10091ff. V10092 v10092ff. V10093 v10093ff.
         V10094 v10094ff. V10095 v10095ff. V10096 v10096ff.
         V10097 v10097ff. V10098 v10098ff. V10099 v10099ff.
         V10100 v10100ff. V10101 v10101ff. V10102 v10102ff.
         V10103 v10103ff. V10104 v10104ff. V10105 v10105ff.
         V10106 v10106ff. V10107 v10107ff. V10108 v10108ff.
         V10109 v10109ff. V10110 v10110ff. V10111 v10111ff.
         V10112 v10112ff. V10113 v10113ff. V10114 v10114ff.
         V10115 v10115ff. V10116 v10116ff. V10117 v10117ff.
         V10118 v10118ff. V10119 v10119ff. V10120 v10120ff.
         V10121 v10121ff. V10122 v10122ff. V10123 v10123ff.
         V10124 v10124ff. V10125 v10125ff. V10126 v10126ff.
         V10127 v10127ff. V10128 v10128ff. V10129 v10129ff.
         V10130 v10130ff. V10131 v10131ff. V10132 v10132ff.
         V10133 v10133ff. V10134 v10134ff. V10135 v10135ff.
         V10136 v10136ff. V10137 v10137ff. V10138 v10138ff.
         V10139 v10139ff. V10140 v10140ff. V10141 v10141ff.
         V10142 v10142ff. V10143 v10143ff. V10144 v10144ff.
         V10145 v10145ff. V10146 v10146ff. V10147 v10147ff.
         V10148 v10148ff. V10149 v10149ff. V10150 v10150ff.
         V10151 v10151ff. V10152 v10152ff. V10153 v10153ff.
         V10154 v10154ff. V10155 v10155ff. V10156 v10156ff.
         V10157 v10157ff. V10158 v10158ff. V10159 v10159ff.
         V10160 v10160ff. V10161 v10161ff. V10162 v10162ff.
         V10163 v10163ff. V10164 v10164ff. V10165 v10165ff.
         V10166 v10166ff. V10167 v10167ff. V10168 v10168ff.
         V10169 v10169ff. V10170 v10170ff. V10171 v10171ff.
         V10172 v10172ff. V10173 v10173ff. V10174 v10174ff.
         V10175 v10175ff. V10176 v10176ff. V10177 v10177ff.
         V10178 v10178ff. V10179 v10179ff. V10180 v10180ff.
         V10181 v10181ff. V10182 v10182ff. V10183 v10183ff.
         V10184 v10184ff. V10185 v10185ff. V10186 v10186ff.
         V10187 v10187ff. V10188 v10188ff. V10189 v10189ff.
         V10190 v10190ff. V10191 v10191ff. V10192 v10192ff.
         V10193 v10193ff. V10194 v10194ff. V10195 v10195ff.
         V10196 v10196ff. V10197 v10197ff. V10198 v10198ff.
         V10199 v10199ff. V10200 v10200ff. V10201 v10201ff.
         V10202 v10202ff. V10203 v10203ff. V10204 v10204ff.
         V10205 v10205ff. V10206 v10206ff. V10207 v10207ff.
         V10208 v10208ff. V10209 v10209ff. V10210 v10210ff.
         V10211 v10211ff. V10212 v10212ff. V10213 v10213ff.
         V10214 v10214ff. V10215 v10215ff. V10216 v10216ff.
         V10217 v10217ff. V10218 v10218ff. V10219 v10219ff.
         V10220 v10220ff. V10221 v10221ff. V10222 v10222ff.
         V10223 v10223ff. V10224 v10224ff. V10225 v10225ff.
         V10226 v10226ff. V10227 v10227ff. V10228 v10228ff.
         V10229 v10229ff. V10230 v10230ff. V10231 v10231ff.
         V10232 v10232ff. V10233 v10233ff. V10234 v10234ff.
         V10235 v10235ff. V10236 v10236ff. V10237 v10237ff.
         V10238 v10238ff. V10239 v10239ff. V10240 v10240ff.
         V10241 v10241ff. V10242 v10242ff. V10243 v10243ff.
         V10244 v10244ff. V10245 v10245ff. V10246 v10246ff.
         V10247 v10247ff. V10248 v10248ff. V10249 v10249ff.
         V10250 v10250ff. V10251 v10251ff. V10252 v10252ff.
         V10253 v10253ff. V10254 v10254ff. V10255 v10255ff.
         V10256 v10256ff. V10257 v10257ff. V10258 v10258ff.
         V10259 v10259ff. V10260 v10260ff. V10261 v10261ff.
         V10262 v10262ff. V10263 v10263ff. V10264 v10264ff.
         V10265 v10265ff. V10266 v10266ff. V10267 v10267ff.
         V10268 v10268ff. V10269 v10269ff. V10270 v10270ff.
         V10271 v10271ff. V10272 v10272ff. V10273 v10273ff.
         V10274 v10274ff. V10275 v10275ff. V10276 v10276ff.
         V10277 v10277ff. V10278 v10278ff. V10279 v10279ff.
         V10280 v10280ff. V10281 v10281ff. V10282 v10282ff.
         V10283 v10283ff. V10284 v10284ff. V10285 v10285ff.
         V10286 v10286ff. V10287 v10287ff. V10288 v10288ff.
         V10289 v10289ff. V10290 v10290ff. V10291 v10291ff.
         V10292 v10292ff. V10293 v10293ff. V10294 v10294ff.
         V10295 v10295ff. V10296 v10296ff. V10297 v10297ff.
         V10298 v10298ff. V10299 v10299ff. V10300 v10300ff.
         V10301 v10301ff. V10302 v10302ff. V10303 v10303ff.
         V10304 v10304ff. V10305 v10305ff. V10306 v10306ff.
         V10307 v10307ff. V10308 v10308ff. V10309 v10309ff.
         V10310 v10310ff. V10311 v10311ff. V10312 v10312ff.
         V10313 v10313ff. V10314 v10314ff. V10315 v10315ff.
         V10316 v10316ff. V10317 v10317ff. V10318 v10318ff.
         V10319 v10319ff. V10320 v10320ff. V10321 v10321ff.
         V10322 v10322ff. V10323 v10323ff. V10324 v10324ff.
         V10325 v10325ff. V10326 v10326ff. V10327 v10327ff.
         V10328 v10328ff. V10329 v10329ff. V10330 v10330ff.
         V10331 v10331ff. V10332 v10332ff. V10333 v10333ff.
         V10334 v10334ff. V10335 v10335ff. V10336 v10336ff.
         V10337 v10337ff. V10338 v10338ff. V10339 v10339ff.
         V10340 v10340ff. V10341 v10341ff. V10342 v10342ff.
         V10343 v10343ff. V10344 v10344ff. V10345 v10345ff.
         V10346 v10346ff. V10347 v10347ff. V10348 v10348ff.
         V10349 v10349ff. V10350 v10350ff. V10351 v10351ff.
         V10352 v10352ff. V10353 v10353ff. V10354 v10354ff.
         V10355 v10355ff. V10356 v10356ff. V10357 v10357ff.
         V10358 v10358ff. V10359 v10359ff. V10360 v10360ff.
         V10361 v10361ff. V10362 v10362ff. V10363 v10363ff.
         V10364 v10364ff. V10365 v10365ff. V10366 v10366ff.
         V10367 v10367ff. V10368 v10368ff. V10369 v10369ff.
         V10370 v10370ff. V10371 v10371ff. V10372 v10372ff.
         V10373 v10373ff. V10374 v10374ff. V10375 v10375ff.
         V10376 v10376ff. V10377 v10377ff. V10378 v10378ff.
         V10379 v10379ff. V10380 v10380ff. V10381 v10381ff.
         V10382 v10382ff. V10383 v10383ff. V10384 v10384ff.
         V10385 v10385ff. V10386 v10386ff. V10387 v10387ff.
         V10388 v10388ff. V10389 v10389ff. V10390 v10390ff.
         V10391 v10391ff. V10392 v10392ff. V10393 v10393ff.
         V10394 v10394ff. V10395 v10395ff. V10396 v10396ff.
         V10397 v10397ff. V10398 v10398ff. V10399 v10399ff.
         V10400 v10400ff. V10401 v10401ff. V10402 v10402ff.
         V10403 v10403ff. V10404 v10404ff. V10405 v10405ff.
         V10406 v10406ff. V10407 v10407ff. V10408 v10408ff.
         V10409 v10409ff. V10410 v10410ff. V10411 v10411ff.
         V10412 v10412ff. V10413 v10413ff. V10414 v10414ff.
         V10415 v10415ff. V10416 v10416ff. V10417 v10417ff.
         V10418 v10418ff. V10419 v10419ff. V10420 v10420ff.
         V10421 v10421ff. V10422 v10422ff. V10423 v10423ff.
         V10424 v10424ff. V10425 v10425ff. V10426 v10426ff.
         V10427 v10427ff. V10428 v10428ff. V10429 v10429ff.
         V10430 v10430ff. V10431 v10431ff. V10432 v10432ff.
         V10433 v10433ff. V10434 v10434ff. V10435 v10435ff.
         V10436 v10436ff. V10437 v10437ff. V10438 v10438ff.
         V10439 v10439ff. V10440 v10440ff. V10441 v10441ff.
         V10442 v10442ff. V10443 v10443ff. V10444 v10444ff.
         V10445 v10445ff. V10446 v10446ff. V10447 v10447ff.
         V10448 v10448ff. V10449 v10449ff. V10450 v10450ff.
         V10451 v10451ff. V10452 v10452ff. V10453 v10453ff.
         V10454 v10454ff. V10455 v10455ff. V10456 v10456ff.
         V10457 v10457ff. V10458 v10458ff. V10459 v10459ff.
         V10460 v10460ff. V10461 v10461ff. V10462 v10462ff.
         V10463 v10463ff. V10464 v10464ff. V10465 v10465ff.
         V10466 v10466ff. V10467 v10467ff. V10468 v10468ff.
         V10469 v10469ff. V10470 v10470ff. V10471 v10471ff.
         V10472 v10472ff. V10473 v10473ff. V10474 v10474ff.
         V10475 v10475ff. V10476 v10476ff. V10477 v10477ff.
         V10478 v10478ff. V10479 v10479ff. V10480 v10480ff.
         V10481 v10481ff. V10482 v10482ff. V10483 v10483ff.
         V10484 v10484ff. V10485 v10485ff. V10486 v10486ff.
         V10487 v10487ff. V10488 v10488ff. V10489 v10489ff.
         V10490 v10490ff. V10491 v10491ff. V10492 v10492ff.
         V10493 v10493ff. V10494 v10494ff. V10495 v10495ff.
         V10496 v10496ff. V10497 v10497ff. V10498 v10498ff.
         V10499 v10499ff. V10500 v10500ff. V10501 v10501ff.
         V10502 v10502ff. V10503 v10503ff. V10504 v10504ff.
         V10505 v10505ff. V10506 v10506ff. V10507 v10507ff.
         V10508 v10508ff. V10509 v10509ff. V10510 v10510ff.
         V10511 v10511ff. V10512 v10512ff. V10513 v10513ff.
         V10514 v10514ff. V10515 v10515ff. V10516 v10516ff.
         V10517 v10517ff. V10518 v10518ff. V10519 v10519ff.
         V10520 v10520ff. V10521 v10521ff. V10522 v10522ff.
         V10523 v10523ff. V10524 v10524ff. V10525 v10525ff.
         V10526 v10526ff. V10527 v10527ff. V10528 v10528ff.
         V10529 v10529ff. V10530 v10530ff. V10531 v10531ff.
         V10532 v10532ff. V10533 v10533ff. V10534 v10534ff.
         V10535 v10535ff. V10536 v10536ff. V10537 v10537ff.
         V10538 v10538ff. V10539 v10539ff. V10540 v10540ff.
         V10541 v10541ff. V10542 v10542ff. V10543 v10543ff.
         V10544 v10544ff. V10545 v10545ff. V10546 v10546ff.
         V10547 v10547ff. V10548 v10548ff. V10549 v10549ff.
         V10550 v10550ff. V10551 v10551ff. V10552 v10552ff.
         V10553 v10553ff. V10554 v10554ff. V10555 v10555ff.
         V10556 v10556ff. V10557 v10557ff. V11004 v11004ff.
         V11005 v11005ff. V11006 v11006ff. V11007 v11007ff.
         V11008 v11008ff. V11009 v11009ff. V11010 v11010ff.
         V11011 v11011ff. V11012 v11012ff. V11013 v11013ff.
         V11014 v11014ff. V11015 v11015ff. V11016 v11016ff.
         V11017 v11017ff. V11018 v11018ff. V11019 v11019ff.
         V11020 v11020ff. V11021 v11021ff. V11022 v11022ff.
         V11023 v11023ff. V11024 v11024ff. V11025 v11025ff.
         V11026 v11026ff. V11027 v11027ff. V11028 v11028ff.
         V11029 v11029ff. V11030 v11030ff. V11031 v11031ff.
         V11032 v11032ff. V11033 v11033ff. V11034 v11034ff.
         V11035 v11035ff. V11036 v11036ff. V11037 v11037ff.
         V11038 v11038ff. V11039 v11039ff. V11040 v11040ff.
         V11041 v11041ff. V11042 v11042ff. V11043 v11043ff.
         V11044 v11044ff. V11045 v11045ff. V11046 v11046ff.
         V11047 v11047ff. V11048 v11048ff. V11049 v11049ff.
         V11050 v11050ff. V11051 v11051ff. V11052 v11052ff.
         V11053 v11053ff. V11054 v11054ff. V11055 v11055ff.
         V11056 v11056ff. V11057 v11057ff. V11058 v11058ff.
         V11059 v11059ff. V11060 v11060ff. V11061 v11061ff.
         V11062 v11062ff. V11063 v11063ff. V11064 v11064ff.
         V11065 v11065ff. V11066 v11066ff. V11067 v11067ff.
         V11068 v11068ff. V11069 v11069ff. V11070 v11070ff.
         V11071 v11071ff. V11072 v11072ff. V11073 v11073ff.
         V11074 v11074ff. V11075 v11075ff. V11076 v11076ff.
         V11077 v11077ff. V11078 v11078ff. V11079 v11079ff.
         V11080 v11080ff. V11081 v11081ff. V11082 v11082ff.
         V11083 v11083ff. V11084 v11084ff. V11085 v11085ff.
         V11086 v11086ff. V11087 v11087ff. V11088 v11088ff.
         V11089 v11089ff. V11090 v11090ff. V11091 v11091ff.
         V11092 v11092ff. V11093 v11093ff. V11094 v11094ff.
         V11095 v11095ff. V11096 v11096ff. V11097 v11097ff.
         V11098 v11098ff. V11099 v11099ff. V11100 v11100ff.
         V11101 v11101ff. V11102 v11102ff. V11103 v11103ff.
         V11104 v11104ff. V11105 v11105ff. V11106 v11106ff.
         V11107 v11107ff. V11108 v11108ff. V11109 v11109ff.
         V11110 v11110ff. V11111 v11111ff. V11112 v11112ff.
         V11113 v11113ff. V11114 v11114ff. V11115 v11115ff.
         V11116 v11116ff. V11117 v11117ff. V11118 v11118ff.
         V11119 v11119ff. V11120 v11120ff. V11121 v11121ff.
         V11122 v11122ff. V11123 v11123ff. V11124 v11124ff.
         V11125 v11125ff. V11126 v11126ff. V11127 v11127ff.
         V11128 v11128ff. V11129 v11129ff. V11130 v11130ff.
         V11131 v11131ff. V11132 v11132ff. V11133 v11133ff.
         V11134 v11134ff. V11135 v11135ff. V11136 v11136ff.
         V11137 v11137ff. V11138 v11138ff. V11139 v11139ff.
         V11140 v11140ff. V11141 v11141ff. V11142 v11142ff.
         V11143 v11143ff. V11144 v11144ff. V11145 v11145ff.
         V11146 v11146ff. V11147 v11147ff. V11148 v11148ff.
         V11149 v11149ff. V11150 v11150ff. V11151 v11151ff.
         V11152 v11152ff. V11153 v11153ff. V11154 v11154ff.
         V11155 v11155ff. V11156 v11156ff. V11157 v11157ff.
         V11158 v11158ff. V11159 v11159ff. V11160 v11160ff.
         V11161 v11161ff. V11162 v11162ff. V11163 v11163ff.
         V11164 v11164ff. V11165 v11165ff. V11166 v11166ff.
         V11167 v11167ff. V11168 v11168ff. V11169 v11169ff.
         V11170 v11170ff. V11171 v11171ff. V11172 v11172ff.
         V11173 v11173ff. V11174 v11174ff. V11175 v11175ff.
         V11176 v11176ff. V11177 v11177ff. V11178 v11178ff.
         V11179 v11179ff. V11180 v11180ff. V11181 v11181ff.
         V11182 v11182ff. V11183 v11183ff. V11184 v11184ff.
         V11185 v11185ff. V11186 v11186ff. V11187 v11187ff.
         V11188 v11188ff. V11189 v11189ff. V11190 v11190ff.
         V11191 v11191ff. V11192 v11192ff. V11193 v11193ff.
         V11194 v11194ff. V11195 v11195ff. V11196 v11196ff.
         V11197 v11197ff. V11198 v11198ff. V11199 v11199ff.
         V11200 v11200ff. V11201 v11201ff. V11202 v11202ff.
         V11203 v11203ff. V11204 v11204ff. V11205 v11205ff.
         V11206 v11206ff. V11207 v11207ff. V11208 v11208ff.
         V11209 v11209ff. V11210 v11210ff. V11211 v11211ff.
         V11212 v11212ff. V11213 v11213ff. V11214 v11214ff.
         V11215 v11215ff. V11216 v11216ff. V11217 v11217ff.
         V11218 v11218ff. V11219 v11219ff. V11220 v11220ff.
         V11221 v11221ff. V11222 v11222ff. V11223 v11223ff.
         V11224 v11224ff. V11225 v11225ff. V11226 v11226ff.
         V11227 v11227ff. V11228 v11228ff. V11229 v11229ff.
         V11230 v11230ff. V11231 v11231ff. V11232 v11232ff.
         V11233 v11233ff. V11234 v11234ff. V11235 v11235ff.
         V11236 v11236ff. V11237 v11237ff. V11238 v11238ff.
         V11239 v11239ff. V11240 v11240ff. V11241 v11241ff.
         V11242 v11242ff. V11243 v11243ff. V11244 v11244ff.
         V11245 v11245ff. V11246 v11246ff. V11247 v11247ff.
         V11248 v11248ff. V11249 v11249ff. V11250 v11250ff.
         V11251 v11251ff. V11252 v11252ff. V11253 v11253ff.
         V11254 v11254ff. V11255 v11255ff. V11256 v11256ff.
         V11257 v11257ff. V11258 v11258ff. V11259 v11259ff.
         V11260 v11260ff. V11261 v11261ff. V11262 v11262ff.
         V11263 v11263ff. V11264 v11264ff. V11265 v11265ff.
         V11266 v11266ff. V11267 v11267ff. V11268 v11268ff.
         V11269 v11269ff. V11270 v11270ff. V11271 v11271ff.
         V11272 v11272ff. V11273 v11273ff. V11274 v11274ff.
         V11275 v11275ff. V11276 v11276ff. V11277 v11277ff.
         V11278 v11278ff. V11279 v11279ff. V11280 v11280ff.
         V11281 v11281ff. V11282 v11282ff. V11283 v11283ff.
         V11284 v11284ff. V11285 v11285ff. V11286 v11286ff.
         V11287 v11287ff. V11288 v11288ff. V11289 v11289ff.
         V11290 v11290ff. V11291 v11291ff. V11292 v11292ff.
         V11293 v11293ff. V11294 v11294ff. V11295 v11295ff.
         V11296 v11296ff. V11297 v11297ff. V11298 v11298ff.
         V11299 v11299ff. V11300 v11300ff. V11301 v11301ff.
         V11302 v11302ff. V11303 v11303ff. V11304 v11304ff.
         V11305 v11305ff. V11306 v11306ff. V11307 v11307ff.
         V11308 v11308ff. V11309 v11309ff. V11310 v11310ff.
         V11311 v11311ff. V11312 v11312ff. V11313 v11313ff.
         V11314 v11314ff. V11315 v11315ff. V11316 v11316ff.
         V11317 v11317ff. V11318 v11318ff. V11319 v11319ff.
         V11320 v11320ff. V11321 v11321ff. V11322 v11322ff.
         V11323 v11323ff. V11324 v11324ff. V11325 v11325ff.
         V11326 v11326ff. V11327 v11327ff. V11328 v11328ff.
         V11329 v11329ff. V11330 v11330ff. V11331 v11331ff.
         V11332 v11332ff. V11333 v11333ff. V11334 v11334ff.
         V11335 v11335ff. V11336 v11336ff. V11337 v11337ff.
         V11338 v11338ff. V11339 v11339ff. V11340 v11340ff.
         V11341 v11341ff. V11342 v11342ff. V11343 v11343ff.
         V11344 v11344ff. V11345 v11345ff. V11346 v11346ff.
         V11347 v11347ff. V11348 v11348ff. V11349 v11349ff.
         V11350 v11350ff. V11351 v11351ff. V11352 v11352ff.
         V11353 v11353ff. V11354 v11354ff. V11355 v11355ff.
         V11356 v11356ff. V11357 v11357ff. V11358 v11358ff.
         V11359 v11359ff. V11360 v11360ff. V11361 v11361ff.
         V11362 v11362ff. V11363 v11363ff. V11364 v11364ff.
         V11365 v11365ff. V11366 v11366ff. V11367 v11367ff.
         V11368 v11368ff. V11369 v11369ff. V11370 v11370ff.
         V11371 v11371ff. V11372 v11372ff. V11373 v11373ff.
         V11374 v11374ff. V11375 v11375ff. V11376 v11376ff.
         V11377 v11377ff. V11378 v11378ff. V11379 v11379ff.
         V11380 v11380ff. V11381 v11381ff. V11382 v11382ff.
         V11383 v11383ff. V11384 v11384ff. V11385 v11385ff.
         V11386 v11386ff. V11387 v11387ff. V11388 v11388ff.
         V11389 v11389ff. V11390 v11390ff. V11391 v11391ff.
         V11392 v11392ff. V11393 v11393ff. V11394 v11394ff.
         V11395 v11395ff. V11396 v11396ff. V11397 v11397ff.
         V11398 v11398ff. V11399 v11399ff. V11400 v11400ff.
         V11401 v11401ff. V11402 v11402ff. V11403 v11403ff.
         V11404 v11404ff. V11405 v11405ff. V11406 v11406ff.
         V11407 v11407ff. V11408 v11408ff. V11409 v11409ff.
         V11410 v11410ff. V11411 v11411ff. V11412 v11412ff.
         V11413 v11413ff. V11414 v11414ff. V11415 v11415ff.
         V11416 v11416ff. V11417 v11417ff. V11418 v11418ff.
         V11419 v11419ff. V11420 v11420ff. V11421 v11421ff.
         V11422 v11422ff. V11423 v11423ff. V11424 v11424ff.
         V11425 v11425ff. V11426 v11426ff. V11427 v11427ff.
         V11428 v11428ff. V11429 v11429ff. V11430 v11430ff.
         V11431 v11431ff. V11432 v11432ff. V11433 v11433ff.
         V11434 v11434ff. V11435 v11435ff. V11436 v11436ff.
         V11437 v11437ff. V11438 v11438ff. V11439 v11439ff.
         V11440 v11440ff. V11441 v11441ff. V11442 v11442ff.
         V11443 v11443ff. V11444 v11444ff. V11445 v11445ff.
         V11446 v11446ff. V11447 v11447ff. V11448 v11448ff.
         V11449 v11449ff. V11450 v11450ff. V11451 v11451ff.
         V11452 v11452ff. V11453 v11453ff. V11454 v11454ff.
         V11455 v11455ff. V11456 v11456ff. V11457 v11457ff.
         V11458 v11458ff. V11459 v11459ff. V11460 v11460ff.
         V11461 v11461ff. V11462 v11462ff. V11463 v11463ff.
         V11464 v11464ff. V11465 v11465ff. V11466 v11466ff.
         V11467 v11467ff. V11468 v11468ff. V11469 v11469ff.
         V11470 v11470ff. V11471 v11471ff. V11472 v11472ff.
         V11473 v11473ff. V11474 v11474ff. V11475 v11475ff.
         V11476 v11476ff. V11477 v11477ff. V11478 v11478ff.
         V11479 v11479ff. V11480 v11480ff. V11481 v11481ff.
         V11482 v11482ff. V11483 v11483ff. V11484 v11484ff.
         V11485 v11485ff. V11486 v11486ff. V11487 v11487ff.
         V11488 v11488ff. V11489 v11489ff. V11490 v11490ff.
         V11491 v11491ff. V11492 v11492ff. V11493 v11493ff.
         V11494 v11494ff. V11495 v11495ff. V11496 v11496ff.
         V11497 v11497ff. V11498 v11498ff. V11499 v11499ff.
         V11500 v11500ff. V11501 v11501ff. V11502 v11502ff.
         V11503 v11503ff. V11504 v11504ff. V11505 v11505ff.
         V11506 v11506ff. V11507 v11507ff. V11508 v11508ff.
         V11509 v11509ff. V11510 v11510ff. V11511 v11511ff.
         V11512 v11512ff. V11513 v11513ff. V11514 v11514ff.
         V11515 v11515ff. V11516 v11516ff. V11517 v11517ff.
         V11518 v11518ff. V11519 v11519ff. V11520 v11520ff.
         V11521 v11521ff. V11522 v11522ff. V11523 v11523ff.
         V11524 v11524ff. V11525 v11525ff. V11526 v11526ff.
         V11527 v11527ff. V11528 v11528ff. V11529 v11529ff.
         V11530 v11530ff. V11531 v11531ff. V11532 v11532ff.
         V11533 v11533ff. V11534 v11534ff. V11535 v11535ff.
         V11536 v11536ff. V11537 v11537ff. V11538 v11538ff.
         V11539 v11539ff. V11540 v11540ff. V11541 v11541ff.
         V11542 v11542ff. V11543 v11543ff. V11544 v11544ff.
         V11545 v11545ff. V11546 v11546ff. V11547 v11547ff.
         V11548 v11548ff. V11549 v11549ff. V11550 v11550ff.
         V11551 v11551ff. V11552 v11552ff. V11553 v11553ff.
         V11554 v11554ff. V11555 v11555ff. V11556 v11556ff.
         V11557 v11557ff. V11558 v11558ff. V11559 v11559ff.
         V11560 v11560ff. V11561 v11561ff. V11562 v11562ff.
         V11563 v11563ff. V11564 v11564ff. V11565 v11565ff.
         V11566 v11566ff. V11567 v11567ff. V11568 v11568ff.
         V11569 v11569ff. V11570 v11570ff. V11571 v11571ff.
         V11572 v11572ff. V11573 v11573ff. V11574 v11574ff.
         V11575 v11575ff. V11576 v11576ff. V11577 v11577ff.
         V11578 v11578ff. V11579 v11579ff. V11580 v11580ff.
         V11581 v11581ff. V11582 v11582ff. V11583 v11583ff.
         V11584 v11584ff. V11585 v11585ff. V11586 v11586ff.
         V11587 v11587ff. V11588 v11588ff. V11589 v11589ff.
         V11590 v11590ff. V11591 v11591ff. V11592 v11592ff.
         V11593 v11593ff. V11594 v11594ff. V11595 v11595ff.
         V11596 v11596ff. V11597 v11597ff. V11598 v11598ff.
         V11599 v11599ff. V11600 v11600ff. V11601 v11601ff.
         V11602 v11602ff. V11603 v11603ff. V11604 v11604ff.
         V11605 v11605ff. V11606 v11606ff. V11607 v11607ff.
         V11608 v11608ff. V11609 v11609ff. V11610 v11610ff.
         V11611 v11611ff. V11612 v11612ff. V11613 v11613ff.
         V11614 v11614ff. V11615 v11615ff. V11616 v11616ff.
         V11617 v11617ff. V11618 v11618ff. V11619 v11619ff.
         V11620 v11620ff. V11621 v11621ff. V11622 v11622ff.
         V11623 v11623ff. V11624 v11624ff. V11625 v11625ff.
         V11626 v11626ff. V11627 v11627ff. V11628 v11628ff.
         V11629 v11629ff. V11630 v11630ff. V11631 v11631ff.
         V11632 v11632ff. V11633 v11633ff. V11634 v11634ff.
         V11635 v11635ff. V11636 v11636ff. V11637 v11637ff.
         V11638 v11638ff. V11639 v11639ff. V11640 v11640ff.
         V11641 v11641ff. V11642 v11642ff. V11643 v11643ff.
         V11644 v11644ff. V11645 v11645ff. V11646 v11646ff.
         V11647 v11647ff.  ;
*/

RUN ;
